@@ -332,23 +332,17 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
   if ( mKeyUsage & SMIMEKeys )
     mSMIMEBackend = Kleo::CryptoBackendFactory::instance()->smime();
 
-  QSize dialogSize( 580, 400 );
-  if ( kapp ) {
-    KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
-
-    KConfigGroup dialogConfig( KGlobal::config(), "Key Selection Dialog" );
-    dialogSize = dialogConfig.readSizeEntry( "Dialog size", &dialogSize );
-  }
-  resize( dialogSize );
-
   mCheckSelectionTimer = new QTimer( this );
   mStartSearchTimer = new QTimer( this );
 
   QFrame *page = makeMainWidget();
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
-  if ( !text.isEmpty() )
-    topLayout->addWidget( new QLabel( text, page ) );
+  if ( !text.isEmpty() ) {
+    QLabel* textLabel = new QLabel( text, page );
+    textLabel->setAlignment( textLabel->alignment() | Qt::WordBreak );
+    topLayout->addWidget( textLabel );
+  }
 
   QHBoxLayout * hlay = new QHBoxLayout( topLayout ); // inherits spacing
   QLineEdit * le = new QLineEdit( page );
@@ -401,6 +395,16 @@ void Kleo::KeySelectionDialog::init( bool rememberChoice, bool extendedSelection
            this, SLOT(slotRereadKeys()) );
 
   slotRereadKeys();
+  topLayout->activate();
+
+  if ( kapp ) {
+    KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
+    QSize dialogSize( sizeHint() );
+
+    KConfigGroup dialogConfig( KGlobal::config(), "Key Selection Dialog" );
+    dialogSize = dialogConfig.readSizeEntry( "Dialog size", &dialogSize );
+    resize( dialogSize );
+  }
 }
 
 Kleo::KeySelectionDialog::~KeySelectionDialog() {
