@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -39,6 +39,7 @@ class QListView;
 class QTextEdit;
 class QToolButton;
 
+class KActiveLabel;
 class KComboBox;
 class KLineEdit;
 class KListView;
@@ -59,6 +60,7 @@ class AddressEditWidget : public QWidget
     KABC::Address::List addresses();
     void setAddresses( const KABC::Addressee &addr,
                        const KABC::Address::List &list );
+    void updateAddressee( const KABC::Addressee &addr );
 
     void updateTypeCombo( const KABC::Address::List&, KComboBox* );
     KABC::Address currentAddress( KComboBox*, int );
@@ -77,7 +79,7 @@ class AddressEditWidget : public QWidget
     AddressTypeCombo *mTypeCombo;
 
     QPushButton *mEditButton;
-    QLabel *mAddressField;
+    KActiveLabel *mAddressField;
 
     KABC::Address::List mAddressList;
     KABC::Addressee mAddressee;
