@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -33,6 +33,7 @@
 #include <qtooltip.h>
 
 #include <kabc/resource.h>
+#include <kabc/stdaddressbook.h>
 #include <kaccelmanager.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -55,7 +56,6 @@
 
 #include "addresseditwidget.h"
 #include "advancedcustomfields.h"
-#include "core.h"
 #include "emaileditwidget.h"
 #include "imeditwidget.h"
 #include "kabprefs.h"
@@ -66,9 +66,8 @@
 
 #include "addresseeeditorwidget.h"
 
-AddresseeEditorWidget::AddresseeEditorWidget( KAB::Core *core, bool isExtension,
-                                              QWidget *parent, const char *name )
-  : AddresseeEditorBase( core, isExtension, parent, name ),
+AddresseeEditorWidget::AddresseeEditorWidget( QWidget *parent, const char *name )
+  : AddresseeEditorBase( parent, name ),
     mBlockSignals( false ), mReadOnly( false )
 {
   kdDebug(5720) << "AddresseeEditorWidget()" << endl;
@@ -384,7 +383,7 @@ void AddresseeEditorWidget::setupTab2()
   label->setBuddy( mNicknameEdit );
   layout->addWidget( mNicknameEdit, 4, 2 );
 
-  label = new QLabel( i18n( "Spouse's name:" ), tab2 );
+  label = new QLabel( i18n( "Partner's name:" ), tab2 );
   layout->addWidget( label, 5, 1 );
   mSpouseEdit = new KPIM::AddresseeLineEdit( tab2 );
   connect( mSpouseEdit, SIGNAL( textChanged( const QString& ) ),
@@ -456,7 +455,7 @@ void AddresseeEditorWidget::setupAdditionalTabs()
     }
 
     KAB::ContactEditorWidget *widget
-              = manager->factory( i )->createWidget( core()->addressBook(),
+              = manager->factory( i )->createWidget( KABC::StdAddressBook::self( true ),
                                                      page );
     if ( widget )
       page->addWidget( widget );
@@ -478,7 +477,7 @@ void AddresseeEditorWidget::setupCustomFieldsTabs()
       continue;
 
     ContactEditorTabPage *page = new ContactEditorTabPage( mTabWidget );
-    AdvancedCustomFields *wdg = new AdvancedCustomFields( *it, core()->addressBook(), page );
+    AdvancedCustomFields *wdg = new AdvancedCustomFields( *it, KABC::StdAddressBook::self( true ), page );
     if ( wdg ) {
       mTabPages.insert( wdg->pageIdentifier(), page );
       mTabWidget->addTab( page, wdg->pageTitle() );
@@ -530,6 +529,10 @@ void AddresseeEditorWidget::load()
 
   mRoleEdit->setText( mAddressee.role() );
   mOrgEdit->setText( mAddressee.organization() );
+  mDepartmentEdit->setText( mAddressee.department() );
+  // compatibility with older versions
+  if ( mAddressee.department().isEmpty() )
+    mDepartmentEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Department" ) );
   mURLEdit->setURL( mAddressee.url() );
   mURLEdit->home( false );
   mBlogEdit->setURL( mAddressee.custom( "KADDRESSBOOK", "BlogFeed" ) );
@@ -552,7 +555,6 @@ void AddresseeEditorWidget::load()
   mSpouseEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-SpousesName" ) );
   mManagerEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-ManagersName" ) );
   mAssistantEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-AssistantsName" ) );
-  mDepartmentEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Department" ) );
   mOfficeEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Office" ) );
   mProfessionEdit->setText( mAddressee.custom( "KADDRESSBOOK", "X-Profession" ) );
   mTitleEdit->setText( mAddressee.title() );
@@ -573,8 +575,21 @@ void AddresseeEditorWidget::save()
 
   mAddressee.setRole( mRoleEdit->text() );
   mAddressee.setOrganization( mOrgEdit->text() );
-  mAddressee.setUrl( KURL( mURLEdit->text().stripWhiteSpace() ) );
-  mAddressee.insertCustom( "KADDRESSBOOK", "BlogFeed", mBlogEdit->text() );
+  mAddressee.setDepartment( mDepartmentEdit->text() );
+
+  QString homepage = mURLEdit->text().stripWhiteSpace();
+  if ( homepage.isEmpty() )
+     mAddressee.setUrl( KURL() );
+  else {
+     if( !homepage.startsWith("http") )
+       homepage = "http://" + homepage;
+     mAddressee.setUrl( KURL( homepage ) );
+  }
+  if ( !mBlogEdit->text().isEmpty() )
+    mAddressee.insertCustom( "KADDRESSBOOK", "BlogFeed", mBlogEdit->text() );
+  else
+    mAddressee.removeCustom( "KADDRESSBOOK", "BlogFeed" );
+
   mAddressee.setNote( mNoteEdit->text() );
   if ( mBirthdayPicker->date().isValid() )
     mAddressee.setBirthday( QDateTime( mBirthdayPicker->date() ) );
@@ -604,10 +619,6 @@ void AddresseeEditorWidget::save()
   else
     mAddressee.removeCustom( "KADDRESSBOOK", "X-AssistantsName" );
 
-  if ( !mDepartmentEdit->text().isEmpty() )
-    mAddressee.insertCustom( "KADDRESSBOOK", "X-Department", mDepartmentEdit->text() );
-  else
-    mAddressee.removeCustom( "KADDRESSBOOK", "X-Department" );
   if ( !mOfficeEdit->text().isEmpty() )
     mAddressee.insertCustom( "KADDRESSBOOK", "X-Office", mOfficeEdit->text() );
   else
@@ -701,6 +712,8 @@ void AddresseeEditorWidget::organizationTextChanged( const QString &text )
 
   nameBoxChanged();
 
+  mAddressEditWidget->updateAddressee( mAddressee );
+
   emitModified();
 }
 
@@ -723,6 +736,8 @@ void AddresseeEditorWidget::nameBoxChanged()
     mFormattedNameLabel->setText( NameEditDialog::formattedName( mAddressee, mFormattedNameType ) );
     mAddressee.setFormattedName( NameEditDialog::formattedName( mAddressee, mFormattedNameType ) );
   }
+
+  mAddressEditWidget->updateAddressee( mAddressee );
 }
 
 void AddresseeEditorWidget::nameButtonClicked()
@@ -768,8 +783,7 @@ void AddresseeEditorWidget::selectCategories()
   }
 
   mCategorySelectDialog->setSelected( QStringList::split( ",", mCategoryEdit->text() ) );
-  mCategorySelectDialog->show();
-  mCategorySelectDialog->raise();
+  mCategorySelectDialog->exec();
 }
 
 void AddresseeEditorWidget::categoriesSelected( const QStringList &list )
@@ -785,26 +799,17 @@ void AddresseeEditorWidget::editCategories()
              mCategorySelectDialog, SLOT( updateCategoryConfig() ) );
   }
 
-  mCategoryEditDialog->show();
-  mCategoryEditDialog->raise();
+  mCategoryEditDialog->exec();
 }
 
 void AddresseeEditorWidget::emitModified()
 {
+  if ( mBlockSignals )
+    return;
+
   mDirty = true;
 
-  if ( !mBlockSignals ) {
-    KABC::Addressee::List list;
-
-    save();
-    list.append( mAddressee );
-
-    // I hate these hacks...
-    if ( !isExtension() )
-      mDirty = true;
-
-    emit modified( list );
-  }
+  emit modified();
 }
 
 void AddresseeEditorWidget::dateChanged( const QDate& )
@@ -823,16 +828,6 @@ void AddresseeEditorWidget::pageChanged( QWidget *wdg )
     KAcceleratorManager::manage( wdg );
 }
 
-QString AddresseeEditorWidget::title() const
-{
-  return i18n( "Contact Editor" );
-}
-
-QString AddresseeEditorWidget::identifier() const
-{
-  return "contact_editor";
-}
-
 void AddresseeEditorWidget::setInitialFocus()
 {
   mNameEdit->setFocus();
