@@ -111,8 +111,6 @@ KABCore::KABCore( KXMLGUIClient *client, bool readWrite, QWidget *parent,
   }
   mAddressBook->setErrorHandler( new KABC::GuiErrorHandler( mWidget ) );
 
-  mAddressBook->addCustomField( i18n( "Department" ), KABC::Field::Organization,
-                                "X-Department", "KADDRESSBOOK" );
   mAddressBook->addCustomField( i18n( "Profession" ), KABC::Field::Organization,
                                 "X-Profession", "KADDRESSBOOK" );
   mAddressBook->addCustomField( i18n( "Assistant's Name" ), KABC::Field::Organization,
@@ -293,7 +291,7 @@ QWidget *KABCore::widget() const
 KAboutData *KABCore::createAboutData()
 {
   KAboutData *about = new KAboutData( "kaddressbook", I18N_NOOP( "KAddressBook" ),
-                                      "3.5.6", I18N_NOOP( "The KDE Address Book" ),
+                                      "3.5.7", I18N_NOOP( "The KDE Address Book" ),
                                       KAboutData::License_GPL_V2,
                                       I18N_NOOP( "(c) 1997-2005, The KDE PIM Team" ) );
   about->addAuthor( "Tobias Koenig", I18N_NOOP( "Current maintainer" ), "tokoe@kde.org" );
@@ -649,9 +647,9 @@ void KABCore::importVCard( const KURL &url )
   mXXPortManager->importVCard( url );
 }
 
-void KABCore::importVCard( const QString &vCardURL )
+void KABCore::importVCardFromData( const QString &vCard )
 {
-  mXXPortManager->importVCard( vCardURL );
+  mXXPortManager->importVCardFromData( vCard );
 }
 
 void KABCore::editContact( const QString &uid )
@@ -797,8 +795,7 @@ void KABCore::extensionModified( const KABC::Addressee::List &list )
       mCommandHistory->blockSignals( false );
     }
 
-    mModified = true;
-    mActionSave->setEnabled( true );
+    setModified(true);
   }
 }
 
@@ -965,14 +962,24 @@ void KABCore::delayedAddressBookChanged()
 
 void KABCore::addressBookChanged()
 {
+  const QStringList selectedUids = mViewManager->selectedUids();
+
   mAddressBookChangedTimer->stop();
 
   if ( mJumpButtonBar )
     mJumpButtonBar->updateButtons();
 
   mSearchManager->reload();
+
   mViewManager->setSelected( QString::null, false );
-  setContactSelected( QString::null );
+
+  QString uid = QString::null;
+  if ( !selectedUids.isEmpty() ) {
+    uid = selectedUids.first();
+    mViewManager->setSelected( uid, true );
+  }
+
+  setContactSelected( uid );
 
   updateCategories();
 }
@@ -1030,6 +1037,7 @@ void KABCore::initGUI()
 
   QHBoxLayout *detailsPageLayout = new QHBoxLayout( mDetailsPage, 0, 0 );
   mDetails = new KPIM::AddresseeView( mDetailsPage );
+  mDetails->setVScrollBarMode( QScrollView::Auto );
   detailsPageLayout->addWidget( mDetails );
 
   connect( mDetails, SIGNAL( addressClicked( const QString&) ),
