@@ -47,7 +47,8 @@ class KAddressbookPart: public KParts::ReadOnlyPart, virtual public KAddressBook
 
   public slots:
     virtual void addEmail( QString addr );
-    virtual void importVCard( const QString& vCardURL );
+    virtual void importVCard( const KURL& url );
+    virtual void importVCardFromData( const QString& vCard );
     virtual ASYNC showContactEditor( QString uid );
     virtual void newContact();
     virtual QString getNameByPhone( QString phone );
