@@ -1,7 +1,7 @@
 /*
  *  mainwindow.cpp  -  main application window
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -381,7 +381,7 @@ void MainWindow::initActions()
 	connect(mActionRedo->popupMenu(), SIGNAL(activated(int)), SLOT(slotRedoItem(int)));
 	connect(Undo::instance(), SIGNAL(changed(const QString&, const QString&)), SLOT(slotUndoStatus(const QString&, const QString&)));
 	connect(mListView, SIGNAL(findActive(bool)), SLOT(slotFindActive(bool)));
-	Preferences::connect(SIGNAL(preferencesChanged()), this, SLOT(updateTrayIconAction()));
+	Preferences::connect(SIGNAL(preferencesChanged()), this, SLOT(slotPrefsChanged()));
 	connect(theApp(), SIGNAL(trayIconToggled()), SLOT(updateTrayIconAction()));
 
 	// Set menu item states
@@ -389,9 +389,7 @@ void MainWindow::initActions()
 	mActionShowTime->setChecked(mShowTime);
 	mActionShowTimeTo->setChecked(mShowTimeTo);
 	mActionShowExpired->setChecked(mShowExpired);
-	if (!Preferences::expiredKeepDays())
-		mActionShowExpired->setEnabled(false);
-	updateTrayIconAction();         // set the correct text for this action
+	slotPrefsChanged();         // set the correct text for this action
 	mActionUndo->setEnabled(Undo::haveUndo());
 	mActionRedo->setEnabled(Undo::haveRedo());
 	mActionFindNext->setEnabled(false);
@@ -689,10 +687,12 @@ void MainWindow::slotDelete()
 	// Copy the events to be deleted, in case any are deleted by being
 	// triggered while the confirmation prompt is displayed.
 	QValueList<KAEvent> events;
+	QValueList<KAEvent> origEvents;
 	for (QValueList<EventListViewItemBase*>::Iterator iit = items.begin();  iit != items.end();  ++iit)
 	{
 		AlarmListViewItem* item = (AlarmListViewItem*)(*iit);
 		events.append(item->event());
+		origEvents.append(item->event());
 	}
 	if (Preferences::confirmAlarmDeletion())
 	{
@@ -730,7 +730,7 @@ void MainWindow::slotDelete()
 	if (!AlarmCalendar::activeCalendar()->endUpdate())      // save the calendars now
 		warnErr = events.count();
 	AlarmCalendar::expiredCalendar()->endUpdate();
-	Undo::saveDeletes(events);
+	Undo::saveDeletes(origEvents);
 
 	if (warnErr)
 		KAlarm::displayUpdateError(this, KAlarm::UPDATE_FAILED, KAlarm::ERR_DELETE, warnErr);
@@ -933,6 +933,15 @@ void MainWindow::slotToggleTrayIcon()
 	theApp()->displayTrayIcon(!theApp()->trayIconDisplayed(), this);
 }
 
+/******************************************************************************
+* Called when the user preferences have changed.
+*/
+void MainWindow::slotPrefsChanged()
+{
+	mActionShowExpired->setEnabled(Preferences::expiredKeepDays());
+	updateTrayIconAction();
+}
+
 /******************************************************************************
 * Called when the system tray icon is created or destroyed.
 * Set the system tray icon menu text according to whether or not the system
@@ -1023,8 +1032,13 @@ void MainWindow::initUndoMenu(KPopupMenu* menu, Undo::Type type)
 	for (QValueList<int>::ConstIterator it = ids.begin();  it != ids.end();  ++it)
 	{
 		int id = *it;
-		menu->insertItem(i18n("Undo [action]: message", "%1 %2: %3")
-		                       .arg(action).arg(Undo::actionText(type, id)).arg(Undo::description(type, id)), id);
+		QString actText = Undo::actionText(type, id);
+		QString descrip = Undo::description(type, id);
+		QString text = descrip.isEmpty()
+//		             ? i18n("Undo/Redo [action]", "%1 %2").arg(action).arg(actText)
+		             ? QString("%1 %2").arg(action).arg(actText)
+		             : i18n("Undo [action]: message", "%1 %2: %3").arg(action).arg(actText).arg(descrip);
+		menu->insertItem(text, id);
 	}
 }
 
@@ -1069,8 +1083,7 @@ void MainWindow::slotResetDaemon()
 */
 void MainWindow::slotPreferences()
 {
-	KAlarmPrefDlg prefDlg;
-	prefDlg.exec();
+	KAlarmPrefDlg::display();
 }
 
 /******************************************************************************
