@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2007 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,9 @@
 #include <kiconloader.h>
 #include <kcolorcombo.h>
 #include <kstdguiitem.h>
+#ifdef Q_WS_X11
+#include <kwin.h>
+#endif
 #include <kdebug.h>
 
 #include <kalarmd/kalarmd.h>
@@ -92,9 +95,31 @@ static QString xtermCommands[] = {
 = Class KAlarmPrefDlg
 =============================================================================*/
 
-KAlarmPrefDlg::KAlarmPrefDlg()
-	: KDialogBase(IconList, i18n("Preferences"), Help | Default | Ok | Apply | Cancel, Ok, 0, "PrefDlg", true, true)
+KAlarmPrefDlg* KAlarmPrefDlg::mInstance = 0;
+
+void KAlarmPrefDlg::display()
 {
+	if (!mInstance)
+	{
+		mInstance = new KAlarmPrefDlg;
+		mInstance->show();
+	}
+	else
+	{
+#ifdef Q_WS_X11
+		KWin::WindowInfo info = KWin::windowInfo(mInstance->winId(), NET::WMGeometry | NET::WMDesktop);
+		KWin::setCurrentDesktop(info.desktop());
+#endif
+		mInstance->showNormal();   // un-minimise it if necessary
+		mInstance->raise();
+		mInstance->setActiveWindow();
+	}
+}
+
+KAlarmPrefDlg::KAlarmPrefDlg()
+	: KDialogBase(IconList, i18n("Preferences"), Help | Default | Ok | Apply | Cancel, Ok, 0, "PrefDlg", false, true)
+{
+	setWFlags(Qt::WDestructiveClose);
 	setIconListAllVisible(true);
 
 	QVBox* frame = addVBoxPage(i18n("General"), i18n("General"), DesktopIcon("misc"));
@@ -118,6 +143,7 @@ KAlarmPrefDlg::KAlarmPrefDlg()
 
 KAlarmPrefDlg::~KAlarmPrefDlg()
 {
+	mInstance = 0;
 }
 
 // Restore all defaults in the options...
@@ -576,10 +602,9 @@ EmailPrefTab::EmailPrefTab(QVBox* frame)
 	box->setFixedHeight(box->sizeHint().height());
 	QWhatsThis::add(box,
 	      i18n("Choose how to send email when an email alarm is triggered.\n"
-	           "KMail: The email is added to KMail's outbox if KMail is running. If not, "
-	           "a KMail composer window is displayed to enable you to send the email.\n"
+	           "KMail: The email is sent automatically via KMail. KMail is started first if necessary.\n"
 	           "Sendmail: The email is sent automatically. This option will only work if "
-	           "your system is configured to use 'sendmail' or a sendmail compatible mail transport agent."));
+	           "your system is configured to use sendmail or a sendmail compatible mail transport agent."));
 
 	box = new QHBox(mPage);   // this is to allow left adjustment
 	mEmailCopyToKMail = new QCheckBox(i18n("Co&py sent emails into KMail's %1 folder").arg(KAMail::i18n_sent_mail()), box);
