@@ -59,6 +59,19 @@ extern "C" {
 #include <kasciistricmp.h>
 #include <kasciistringtools.h>
 
+#ifdef HAVE_LIBSASL2
+static sasl_callback_t callbacks[] = {
+    { SASL_CB_ECHOPROMPT, NULL, NULL },
+    { SASL_CB_NOECHOPROMPT, NULL, NULL },
+    { SASL_CB_GETREALM, NULL, NULL },
+    { SASL_CB_USER, NULL, NULL },
+    { SASL_CB_AUTHNAME, NULL, NULL },
+    { SASL_CB_PASS, NULL, NULL },
+    { SASL_CB_CANON_USER, NULL, NULL },
+    { SASL_CB_LIST_END, NULL, NULL }
+};
+#endif
+
 imapParser::imapParser ()
 {
   sentQueue.setAutoDelete (false);
@@ -114,7 +127,9 @@ imapParser::sendCommand (imapCommand * aCmd)
            || command == "LISTRIGHTS"
            || command == "MYRIGHTS"
            || command == "GETANNOTATION"
-           || command == "NAMESPACE")
+           || command == "NAMESPACE"
+           || command == "GETQUOTAROOT"
+           || command == "GETQUOTA")
   {
     lastResults.clear ();
   }
@@ -220,7 +235,7 @@ imapParser::clientAuthenticate ( KIO::SlaveBase *slave, KIO::AuthInfo &ai,
   result = sasl_client_new( "imap", /* FIXME: with cyrus-imapd, even imaps' digest-uri
                                        must be 'imap'. I don't know if it's good or bad. */
                        aFQDN.latin1(),
-                       0, 0, 0, 0, &conn );
+                       0, 0, callbacks, 0, &conn );
 
   if ( result != SASL_OK ) {
     kdDebug(7116) << "sasl_client_new failed with: " << result << endl;
@@ -430,6 +445,16 @@ imapParser::parseUntagged (parseString & result)
       parseAnnotation (result);
     }
     break;
+  case 'Q': // QUOTA or QUOTAROOT
+    if ( what.size() > 5 && qstrncmp(what, "QUOTAROOT", what.size()) == 0)
+    {
+      parseQuotaRoot( result );
+    }
+    else if (qstrncmp(what, "QUOTA", what.size()) == 0)
+    {
+      parseQuota( result );
+    }
+
   default:
     //better be a number
     {
@@ -663,7 +688,7 @@ void imapParser::parseList (parseString & result)
 
 void imapParser::parseLsub (parseString & result)
 {
-  imapList this_one (result.cstr());
+  imapList this_one (result.cstr(), *this);
   listResponses.append (this_one);
 }
 
@@ -707,6 +732,48 @@ void imapParser::parseAnnotation (parseString & result)
   }
 }
 
+
+void imapParser::parseQuota (parseString & result)
+{
+  // quota_response  ::= "QUOTA" SP astring SP quota_list
+  // quota_list      ::= "(" #quota_resource ")"
+  // quota_resource  ::= atom SP number SP number
+  QCString root = parseOneWordC( result );
+  if ( root.isEmpty() ) {
+    lastResults.append( "" );
+  } else {
+    lastResults.append( root );
+  }
+  if (result.isEmpty() || result[0] != '(')
+    return;
+  result.pos++;
+  skipWS (result);
+  QStringList triplet;
+  int outlen = 1;
+  while ( outlen && !result.isEmpty() && result[0] != ')' ) {
+    QCString word = parseLiteralC (result, false, false, &outlen);
+    triplet.append(word);
+  }
+  lastResults.append( triplet.join(" ") );
+}
+
+void imapParser::parseQuotaRoot (parseString & result)
+{
+  //    quotaroot_response
+  //         ::= "QUOTAROOT" SP astring *(SP astring)
+  parseOneWordC (result); // skip mailbox name
+  skipWS (result);
+  if ( result.isEmpty() )
+    return;
+  QStringList roots;
+  int outlen = 1;
+  while ( outlen && !result.isEmpty() ) {
+    QCString word = parseLiteralC (result, false, false, &outlen);
+    roots.append (word);
+  }
+  lastResults.append( roots.join(" ") );
+}
+
 void imapParser::parseMyRights (parseString & result)
 {
   parseOneWordC (result); // skip mailbox name
@@ -729,7 +796,7 @@ void imapParser::parseStatus (parseString & inWords)
   lastStatus = imapInfo ();
 
   parseLiteralC(inWords);       // swallow the box
-  if (inWords[0] != '(')
+  if (inWords.isEmpty() || inWords[0] != '(')
     return;
 
   inWords.pos++;
@@ -776,7 +843,7 @@ void imapParser::parseAddressList (parseString & inWords, QPtrList<mailAddress>&
 {
   if (inWords[0] != '(')
   {
-    parseOneWord (inWords);     // parse NIL
+    parseOneWordC (inWords);     // parse NIL
   }
   else
   {
@@ -894,7 +961,7 @@ mailHeader * imapParser::parseEnvelope (parseString & inWords)
 // caller must clean up the dictionary items
 QAsciiDict < QString > imapParser::parseDisposition (parseString & inWords)
 {
-  QByteArray disposition;
+  QCString disposition;
   QAsciiDict < QString > retVal (17, false);
 
   // return value is a shallow copy
@@ -903,7 +970,7 @@ QAsciiDict < QString > imapParser::parseDisposition (parseString & inWords)
   if (inWords[0] != '(')
   {
     //disposition only
-    disposition = parseOneWord (inWords);
+    disposition = parseOneWordC (inWords);
   }
   else
   {
@@ -911,8 +978,7 @@ QAsciiDict < QString > imapParser::parseDisposition (parseString & inWords)
     skipWS (inWords);
 
     //disposition
-    disposition = parseOneWord (inWords);
-
+    disposition = parseOneWordC (inWords);
     retVal = parseParameters (inWords);
     if (inWords[0] != ')')
       return retVal;
@@ -922,7 +988,7 @@ QAsciiDict < QString > imapParser::parseDisposition (parseString & inWords)
 
   if (!disposition.isEmpty ())
   {
-    retVal.insert ("content-disposition", new QString(b2c(disposition)));
+    retVal.insert ("content-disposition", new QString(disposition));
   }
 
   return retVal;
@@ -940,7 +1006,7 @@ QAsciiDict < QString > imapParser::parseParameters (parseString & inWords)
   if (inWords[0] != '(')
   {
     //better be NIL
-    parseOneWord (inWords);
+    parseOneWordC (inWords);
   }
   else
   {
@@ -949,7 +1015,9 @@ QAsciiDict < QString > imapParser::parseParameters (parseString & inWords)
 
     while (!inWords.isEmpty () && inWords[0] != ')')
     {
-      retVal.insert (parseLiteralC(inWords), new QString(parseLiteralC(inWords)));
+      QCString l1 = parseLiteralC(inWords);
+      QCString l2 = parseLiteralC(inWords);
+      retVal.insert (l1, new QString(l2));
     }
 
     if (inWords[0] != ')')
@@ -1058,6 +1126,7 @@ mimeHeader * imapParser::parseSimplePart (parseString & inWords,
                                        *(it.current ()));
         ++it;
       }
+
       parameters.clear ();
     }
 
@@ -1074,7 +1143,6 @@ mimeHeader * imapParser::parseSimplePart (parseString & inWords,
     else
       parseLiteralC(inWords);
   }
-
   if (inWords[0] == ')')
     inWords.pos++;
   skipWS (inWords);
@@ -1098,7 +1166,7 @@ mimeHeader * imapParser::parseBodyStructure (parseString & inWords,
   if (inWords[0] != '(')
   {
     // skip ""
-    parseOneWord (inWords);
+    parseOneWordC (inWords);
     return 0;
   }
   inWords.pos++;
@@ -1142,7 +1210,7 @@ mimeHeader * imapParser::parseBodyStructure (parseString & inWords,
     }
 
     // fetch subtype
-    subtype = parseOneWord (inWords);
+    subtype = parseOneWordC (inWords);
 
     localPart->setType ("MULTIPART/" + b2c(subtype));
 
@@ -1215,11 +1283,11 @@ void imapParser::parseBody (parseString & inWords)
   // see if we got a part specifier
   if (inWords[0] == '[')
   {
-    QByteArray specifier;
-    QByteArray label;
+    QCString specifier;
+    QCString label;
     inWords.pos++;
 
-    specifier = parseOneWord (inWords, TRUE);
+    specifier = parseOneWordC (inWords, TRUE);
 
     if (inWords[0] == '(')
     {
@@ -1227,7 +1295,7 @@ void imapParser::parseBody (parseString & inWords)
 
       while (!inWords.isEmpty () && inWords[0] != ')')
       {
-        label = parseOneWord (inWords);
+        label = parseOneWordC (inWords);
       }
 
       if (inWords[0] == ')')
@@ -1238,7 +1306,7 @@ void imapParser::parseBody (parseString & inWords)
     skipWS (inWords);
 
     // parse the header
-    if (qstrncmp(specifier, "0", specifier.size()) == 0)
+    if (specifier == "0")
     {
       mailHeader *envelope = 0;
       if (lastHandled)
@@ -1262,12 +1330,12 @@ void imapParser::parseBody (parseString & inWords)
 
       }
     }
-    else if (qstrncmp(specifier, "HEADER.FIELDS", specifier.size()) == 0)
+    else if (specifier == "HEADER.FIELDS")
     {
       // BODY[HEADER.FIELDS (References)] {n}
       //kdDebug(7116) << "imapParser::parseBody - HEADER.FIELDS: "
       // << QCString(label.data(), label.size()+1) << endl;
-      if (qstrncmp(label, "REFERENCES", label.size()) == 0)
+      if (label == "REFERENCES")
       {
        mailHeader *envelope = 0;
        if (lastHandled)
@@ -1296,8 +1364,7 @@ void imapParser::parseBody (parseString & inWords)
     }
     else
     {
-      QCString spec(specifier.data(), specifier.size()+1);
-      if (spec.find(".MIME") != -1)
+      if (specifier.find(".MIME") != -1)
       {
         mailHeader *envelope = new mailHeader;
         QString theHeader = parseLiteralC(inWords, false);
@@ -1602,10 +1669,10 @@ void imapParser::parseNamespace (parseString & result)
     {
       // drop NIL
       ++ns;
-      parseOneWord( result );
+      parseOneWordC( result );
     } else {
       // drop whatever it is
-      parseOneWord( result );
+      parseOneWordC( result );
     }
   }
   if ( !delimEmpty.isEmpty() ) {
@@ -1745,10 +1812,15 @@ imapParser::parseURL (const KURL & _url, QString & _box, QString & _section,
   {
     QString temp = (*it);
 
-    // if we have a '/' separator we'll just nuke it
     int pt = temp.find ('/');
     if (pt > 0)
-      temp.truncate(pt);
+    {
+      if (temp.findRev ('"', pt) == -1 || temp.find('"', pt) == -1)
+      {
+        // if we have non-quoted '/' separator we'll just nuke it
+        temp.truncate(pt);
+      }
+    }
     if (temp.find ("section=", 0, false) == 0)
       _section = temp.right (temp.length () - 8);
     else if (temp.find ("type=", 0, false) == 0)
@@ -1773,7 +1845,7 @@ imapParser::parseURL (const KURL & _url, QString & _box, QString & _section,
     if (!_box.isEmpty () && _box[_box.length () - 1] == '/')
       _box.truncate(_box.length() - 1);
   }
-  kdDebug(7116) << "URL: box= " << _box << ", section= " << _section << ", type= " 
+  kdDebug(7116) << "URL: box= " << _box << ", section= " << _section << ", type= "
     << _type << ", uid= " << _uid << ", validity= " << _validity << ", info= " << _info << endl;
 }
 
