@@ -431,9 +431,9 @@ void AccountDialog::makeLocalAccountPage()
   topLayout->addWidget( mLocal.intervalLabel, 7, 0 );
   mLocal.intervalSpin = new KIntNumInput( page );
   mLocal.intervalLabel->setBuddy( mLocal.intervalSpin );
-  mLocal.intervalSpin->setRange( 1, 10000, 1, FALSE );
+  mLocal.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, FALSE );
   mLocal.intervalSpin->setSuffix( i18n(" min") );
-  mLocal.intervalSpin->setValue( 1 );
+  mLocal.intervalSpin->setValue( defaultmailcheckintervalmin );
   topLayout->addWidget( mLocal.intervalSpin, 7, 1 );
 
   label = new QLabel( i18n("&Destination folder:"), page );
@@ -524,9 +524,9 @@ void AccountDialog::makeMaildirAccountPage()
   mMaildir.intervalLabel = new QLabel( i18n("Check inter&val:"), page );
   topLayout->addWidget( mMaildir.intervalLabel, 6, 0 );
   mMaildir.intervalSpin = new KIntNumInput( page );
-  mMaildir.intervalSpin->setRange( 1, 10000, 1, FALSE );
+  mMaildir.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, FALSE );
   mMaildir.intervalSpin->setSuffix( i18n(" min") );
-  mMaildir.intervalSpin->setValue( 1 );
+  mMaildir.intervalSpin->setValue( defaultmailcheckintervalmin );
   mMaildir.intervalLabel->setBuddy( mMaildir.intervalSpin );
   topLayout->addWidget( mMaildir.intervalSpin, 6, 1 );
 
@@ -721,9 +721,9 @@ void AccountDialog::makePopAccountPage()
   mPop.intervalLabel = new QLabel( i18n("Chec&k interval:"), page1 );
   grid->addWidget( mPop.intervalLabel, 13, 0 );
   mPop.intervalSpin = new KIntNumInput( page1 );
-  mPop.intervalSpin->setRange( 1, 10000, 1, FALSE );
+  mPop.intervalSpin->setRange( GlobalSettings::self()->minimumCheckInterval(), 10000, 1, FALSE );
   mPop.intervalSpin->setSuffix( i18n(" min") );
-  mPop.intervalSpin->setValue( 1 );
+  mPop.intervalSpin->setValue( defaultmailcheckintervalmin );
   mPop.intervalLabel->setBuddy( mPop.intervalSpin );
   grid->addWidget( mPop.intervalSpin, 13, 1 );
 
@@ -1032,9 +1032,8 @@ void AccountDialog::makeImapAccountPage( bool connected )
   mImap.intervalLabel = new QLabel( i18n("Check inter&val:"), page1 );
   grid->addWidget( mImap.intervalLabel, row, 0 );
   mImap.intervalSpin = new KIntNumInput( page1 );
-  const int kioskMinimumImapCheckInterval = GlobalSettings::minimumImapCheckInterval();
-  mImap.intervalSpin->setRange( kioskMinimumImapCheckInterval, 10000, 1, FALSE );
-  mImap.intervalSpin->setValue( 1 );
+  mImap.intervalSpin->setRange( GlobalSettings::minimumCheckInterval(), 60, 1, FALSE );
+  mImap.intervalSpin->setValue( defaultmailcheckintervalmin );
   mImap.intervalSpin->setSuffix( i18n( " min" ) );
   mImap.intervalLabel->setBuddy( mImap.intervalSpin );
   grid->addWidget( mImap.intervalSpin, row, 1 );
@@ -1142,7 +1141,8 @@ void AccountDialog::setupSettings()
     else if (acctLocal->lockType() == lock_none)
       mLocal.lockNone->setChecked(true);
 
-    mLocal.intervalSpin->setValue( QMAX(1, interval) );
+    if ( interval <= 0 ) mLocal.intervalSpin->setValue( defaultmailcheckintervalmin );
+    else mLocal.intervalSpin->setValue( interval );
     mLocal.intervalCheck->setChecked( interval >= 1 );
 #if 0
     mLocal.resourceCheck->setChecked( mAccount->resource() );
@@ -1180,7 +1180,8 @@ void AccountDialog::setupSettings()
     mPop.filterOnServerCheck->setChecked( ap.filterOnServer() );
     mPop.filterOnServerSizeSpin->setValue( ap.filterOnServerCheckSize() );
     mPop.intervalCheck->setChecked( interval >= 1 );
-    mPop.intervalSpin->setValue( QMAX(1, interval) );
+    if ( interval <= 0 ) mPop.intervalSpin->setValue( defaultmailcheckintervalmin );
+    else mPop.intervalSpin->setValue( interval );
 #if 0
     mPop.resourceCheck->setChecked( mAccount->resource() );
 #endif
@@ -1232,14 +1233,13 @@ void AccountDialog::setupSettings()
     mImap.loadOnDemandCheck->setChecked( ai.loadOnDemand() );
     mImap.listOnlyOpenCheck->setChecked( ai.listOnlyOpenFolders() );
     mImap.storePasswordCheck->setChecked( ai.storePasswd() );
-    mImap.intervalCheck->setChecked( interval >= 1 );
-    mImap.intervalSpin->setValue( QMAX(1, interval) );
 #if 0
     mImap.resourceCheck->setChecked( ai.resource() );
 #endif
     mImap.includeInCheck->setChecked( !ai.checkExclude() );
     mImap.intervalCheck->setChecked( interval >= 1 );
-    mImap.intervalSpin->setValue( QMAX(1, interval) );
+    if ( interval <= 0 ) mImap.intervalSpin->setValue( defaultmailcheckintervalmin );
+    else mImap.intervalSpin->setValue( interval );
     QString trashfolder = ai.trash();
     if (trashfolder.isEmpty())
       trashfolder = kmkernel->trashFolder()->idString();
@@ -1285,10 +1285,9 @@ void AccountDialog::setupSettings()
     mImap.locallySubscribedFoldersCheck->setChecked( ai.onlyLocallySubscribedFolders() );
     mImap.storePasswordCheck->setChecked( ai.storePasswd() );
     mImap.intervalCheck->setChecked( interval >= 1 );
-    mImap.intervalSpin->setValue( QMAX(1, interval) );
+    if ( interval <= 0 ) mImap.intervalSpin->setValue( defaultmailcheckintervalmin );
+    else mImap.intervalSpin->setValue( interval );
     mImap.includeInCheck->setChecked( !ai.checkExclude() );
-    mImap.intervalCheck->setChecked( interval >= 1 );
-    mImap.intervalSpin->setValue( QMAX(1, interval) );
     QString trashfolder = ai.trash();
     if (trashfolder.isEmpty())
       trashfolder = kmkernel->trashFolder()->idString();
@@ -1325,7 +1324,8 @@ void AccountDialog::setupSettings()
     mMaildir.nameEdit->setFocus();
     mMaildir.locationEdit->setEditText( acctMaildir->location() );
 
-    mMaildir.intervalSpin->setValue( QMAX(1, interval) );
+    if ( interval <= 0 ) mMaildir.intervalSpin->setValue( defaultmailcheckintervalmin );
+    else mMaildir.intervalSpin->setValue( interval );
     mMaildir.intervalCheck->setChecked( interval >= 1 );
 #if 0
     mMaildir.resourceCheck->setChecked( mAccount->resource() );
