@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *  In addition, as a special exception, the copyright holders give
  *  permission to link the code of this program with any edition of
@@ -44,11 +44,11 @@
 #include "kmacctcachedimap.h"
 #include "kmmsgdict.h"
 #include "maildirjob.h"
+#include "util.h"
 
 #include <kio/scheduler.h>
 #include <kio/job.h>
 
-#include <kmessagebox.h>
 #include <klocale.h>
 #include <kdebug.h>
 
@@ -270,7 +270,7 @@ void CachedImapJob::slotGetNextMessage(KIO::Job * job)
 
       // Convert CR/LF to LF.
       size_t dataSize = (*it).data.size();
-      dataSize = FolderStorage::crlf2lf( (*it).data.data(), dataSize ); // always <=
+      dataSize = Util::crlf2lf( (*it).data.data(), dataSize ); // always <=
       (*it).data.resize( dataSize );
 
       mMsg->setComplete( true );
@@ -280,6 +280,11 @@ void CachedImapJob::slotGetNextMessage(KIO::Job * job)
       mMsg->setTransferInProgress( false );
       int index = 0;
       mFolder->addMsgInternal( mMsg, true, &index );
+
+      if ( kmkernel->iCalIface().isResourceFolder( mFolder->folder() ) ) {
+        mFolder->setStatus( index, KMMsgStatusRead, false );
+      }
+
       emit messageRetrieved( mMsg );
       if ( index > 0 ) mFolder->unGetMsg( index );
     } else {
@@ -290,9 +295,11 @@ void CachedImapJob::slotGetNextMessage(KIO::Job * job)
     mSentBytes += size;
     emit progress( mSentBytes, mTotalBytes );
     mAccount->removeJob(it);
-  }
+  } else
+    mFolder->quiet( true );
 
   if( mMsgsForDownload.isEmpty() ) {
+    mFolder->quiet( false );
     delete this;
     return;
   }
@@ -344,7 +351,7 @@ void CachedImapJob::slotPutNextMessage()
     // Find the message with this serial number
     int i = 0;
     KMFolder* aFolder = 0;
-    kmkernel->msgDict()->getLocation( serNum, &aFolder, &i );
+    KMMsgDict::instance()->getLocation( serNum, &aFolder, &i );
     if( mFolder->folder() != aFolder )
       // This message was moved or something
       continue;
@@ -521,7 +528,13 @@ void CachedImapJob::slotAddNextSubfolder( KIO::Job * job )
   KMFolderCachedImap *folder = mFolderList.front();
   mFolderList.pop_front();
   KURL url = mAccount->getUrl();
-  url.setPath(mFolder->imapPath() + folder->folder()->name());
+  QString path = mAccount->createImapPath( mFolder->imapPath(), 
+      folder->folder()->name() );
+  if ( !folder->imapPathForCreation().isEmpty() ) {
+    // the folder knows it's namespace
+    path = folder->imapPathForCreation();
+  }
+  url.setPath( path );
 
   // Associate the jobData with the parent folder, not with the child
   // This is necessary in case of an error while creating the subfolder,
@@ -561,7 +574,8 @@ void CachedImapJob::slotDeleteNextFolder( KIO::Job *job )
     return;
   }
 
-  QString folderPath = mFoldersOrMessages.front(); mFoldersOrMessages.pop_front();
+  QString folderPath = mFoldersOrMessages.front();
+  mFoldersOrMessages.pop_front();
   KURL url = mAccount->getUrl();
   url.setPath(folderPath);
   ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
