@@ -78,7 +78,7 @@ FolderStorage::FolderStorage( KMFolder* folder, const char* aName )
   mNoContent      = false;
   mNoChildren     = false;
   mRDict = 0;
-  mDirtyTimer = new QTimer(this);
+  mDirtyTimer = new QTimer(this, "mDirtyTimer");
   connect(mDirtyTimer, SIGNAL(timeout()),
 	  this, SLOT(updateIndex()));
 
@@ -98,6 +98,14 @@ FolderStorage::~FolderStorage()
 }
 
 
+void FolderStorage::close( const char * owner, bool aForced )
+{
+  if (mOpenCount <= 0) return;
+  if (mOpenCount > 0) mOpenCount--;
+  if (mOpenCount > 0 && !aForced) return;
+    reallyDoClose( owner );
+}
+
 //-----------------------------------------------------------------------------
 QString FolderStorage::dotEscape(const QString& aStr)
 {
@@ -200,7 +208,7 @@ void FolderStorage::quiet(bool beQuiet)
      * a timer is created when a folder is checked
      */
     if ( !mEmitChangedTimer) {
-      mEmitChangedTimer= new QTimer( this );
+      mEmitChangedTimer= new QTimer( this, "mEmitChangedTimer" );
       connect( mEmitChangedTimer, SIGNAL( timeout() ),
       this, SLOT( slotEmitChangedTimer() ) );
     }
