@@ -145,9 +145,6 @@ public:
   */
   virtual KMMessage* readTemporaryMsg(int idx);
 
-  /** Read a message and return a referece to a string */
-  virtual QCString& getMsgString(int idx, QCString& mDest) = 0;
-
   /** Read a message and returns a DwString */
   virtual DwString getDwString(int idx) = 0;
 
@@ -200,9 +197,9 @@ public:
     return addMsg(msg, index_return);
   }
 
-  /** 
-   * Adds the given messages to the folder. Behaviour is identical 
-   * to addMsg(msg) 
+  /**
+   * Adds the given messages to the folder. Behaviour is identical
+   * to addMsg(msg)
    */
   virtual int addMsg( QPtrList<KMMessage>&, QValueList<int>& index_return );
 
@@ -251,7 +248,7 @@ public:
     call close() first.
     Returns zero on success and an error code equal to the c-library
     fopen call otherwise (errno). */
-  virtual int open() = 0;
+  virtual int open(const char *owner) = 0;
 
   /** Check folder for permissions
     Returns zero if readable and writable. */
@@ -259,7 +256,8 @@ public:
 
   /** Close folder. If force is TRUE the files are closed even if
     others still use it (e.g. other mail reader windows). */
-  virtual void close(bool force=FALSE) = 0;
+  void close(const char * owner, bool force=FALSE);
+  virtual void reallyDoClose(const char * owner) = 0;
 
   /** Try releasing @p folder if possible, something is attempting an exclusive access to it.
       Currently used for KMFolderSearch and the background tasks like expiry. */
@@ -360,7 +358,7 @@ public:
   virtual void setStatus(QValueList<int>& ids, KMMsgStatus status, bool toggle=false);
 
   void removeJobs();
-  
+
   /** Escape a leading dot */
   static QString dotEscape(const QString&);
 
@@ -386,7 +384,10 @@ public:
   bool compactable() const { return mCompactable; }
 
   /// Set the type of contents held in this folder (mail, calendar, etc.)
-  virtual void setContentsType( KMail::FolderContentsType type );
+  // If quiet is true, the KMailIcalIface is not informed of the changed. That's usefull
+  // for folder that are being copied around, should retain their type, but not cause
+  // conflicts on copy because events are identical in two folders.
+  virtual void setContentsType( KMail::FolderContentsType type, bool quiet = false );
   /// @return the type of contents held in this folder (mail, calendar, etc.)
   KMail::FolderContentsType contentsType() const { return mContentsType; }
 
@@ -403,7 +404,7 @@ public:
   virtual void search( const KMSearchPattern*, Q_UINT32 serNum );
 
   /** Returns true if this folder can be moved */
-  virtual bool isMoveable() const;  
+  virtual bool isMoveable() const;
 
 signals:
   /** Emitted when the status, name, or associated accounts of this
@@ -418,9 +419,12 @@ signals:
       emmitted first. */
   void expunged( KMFolder* );
 
+  /** Emitted when the folder was closed and ticket owners have to reopen */
+  void closed( KMFolder* );
+  
   /** Emitted when the serial numbers of this folder were invalidated. */
   void invalidated( KMFolder * );
-  
+
   /** Emitted when the name of the folder changes. */
   void nameChanged();
 
@@ -467,7 +471,7 @@ signals:
    * The matching serial numbers are included
    * If @p complete is true the search is done
    */
-  void searchResult( KMFolder*, QValueList<Q_UINT32>, 
+  void searchResult( KMFolder*, QValueList<Q_UINT32>,
                      const KMSearchPattern*, bool complete );
 
   /**
@@ -488,7 +492,7 @@ public slots:
   /** Add a copy of the message to the folder after it has been retrieved
       from an IMAP server */
   virtual void reallyAddCopyOfMsg(KMMessage* aMsg);
-  
+
   /** Emit changed signal if mQuite <=0 */
   void slotEmitChangedTimer();
 
@@ -552,7 +556,7 @@ friend class KMMsgDict;
   /** Replaces the serial number for the message @p msg at index @p idx with
    * @p sernum */
   void replaceMsgSerNum( unsigned long sernum, KMMsgBase* msg, int idx );
-  
+
    /** Called when serial numbers for a folder are invalidated,
   invalidates/recreates data structures dependent on the
   serial numbers for this folder */
@@ -567,7 +571,7 @@ friend class KMMsgDict;
     At the time of the call the folder has already been closed, and
     the various index files deleted.  Returns 0 on success. */
   virtual int expungeContents() = 0;
-  
+
   /** Read index file and fill the message-info list mMsgList. */
   virtual bool readIndex() = 0;
   virtual KMMsgBase* takeIndexEntry( int idx ) = 0;
@@ -587,7 +591,7 @@ friend class KMMsgDict;
   bool mDirty :1;
   /** TRUE if the files of the folder are locked (writable) */
   bool mFilesLocked :1;
-  
+
   /** number of unread messages, -1 if not yet set */
   int mUnreadMsgs, mGuessedUnreadMsgs;
   int mTotalMsgs;
