@@ -527,6 +527,40 @@ namespace KMail {
       userHTML = "&nbsp;";
     }
 
+    if( photoURL.isEmpty() ) {
+      // no photo, look for a Face header
+      QString faceheader = message->headerField( "Face" );
+      if ( !faceheader.isEmpty() ) {
+        QImage faceimage;
+
+        kdDebug( 5006 ) << "Found Face: header" << endl;
+
+        QCString facestring = faceheader.utf8();
+        // Spec says header should be less than 998 bytes
+        // Face: is 5 characters
+        if ( facestring.length() < 993 ) {
+          QByteArray facearray;
+          KCodecs::base64Decode(facestring, facearray);
+
+          QImage faceimage;
+          if ( faceimage.loadFromData( facearray, "png" ) ) {
+            // Spec says image must be 48x48 pixels
+            if ( (48 == faceimage.width()) && (48 == faceimage.height()) ) {
+              photoURL = imgToDataUrl( faceimage );
+              photoWidth = 48;
+              photoHeight = 48;
+            } else {
+              kdDebug( 5006 ) << "Face: header image is" << faceimage.width() << "by" << faceimage.height() <<"not 48x48 Pixels" << endl;
+            }
+          } else {
+            kdDebug( 5006 ) << "Failed to load decoded png from Face: header" << endl;
+          }
+        } else {
+          kdDebug( 5006 ) << "Face: header too long at " << facestring.length() << endl;
+        }
+      }
+    }
+
     if( photoURL.isEmpty() )
     {
       // no photo, look for a X-Face header
@@ -625,30 +659,50 @@ namespace KMail {
     // to line
     if ( strategy->showHeader( "to" ) )
       headerStr.append(QString("<tr><th>%1</th>\n"
-                   "<td>%2</td></tr>\n")
-                            .arg(i18n("To: "))
-                            .arg(KMMessage::emailAddrAsAnchor(message->to(),FALSE)));
+                               "<td>%2</td></tr>\n")
+                       .arg(i18n("To: "))
+                       .arg(KMMessage::emailAddrAsAnchor(message->to(),FALSE)));
 
     // cc line, if any
     if ( strategy->showHeader( "cc" ) && !message->cc().isEmpty())
       headerStr.append(QString("<tr><th>%1</th>\n"
-                   "<td>%2</td></tr>\n")
-                              .arg(i18n("CC: "))
-                              .arg(KMMessage::emailAddrAsAnchor(message->cc(),FALSE)));
+                               "<td>%2</td></tr>\n")
+                       .arg(i18n("CC: "))
+                       .arg(KMMessage::emailAddrAsAnchor(message->cc(),FALSE)));
 
     // Bcc line, if any
     if ( strategy->showHeader( "bcc" ) && !message->bcc().isEmpty())
       headerStr.append(QString("<tr><th>%1</th>\n"
-                   "<td>%2</td></tr>\n")
-                              .arg(i18n("BCC: "))
-                              .arg(KMMessage::emailAddrAsAnchor(message->bcc(),FALSE)));
+                               "<td>%2</td></tr>\n")
+                       .arg(i18n("BCC: "))
+                       .arg(KMMessage::emailAddrAsAnchor(message->bcc(),FALSE)));
 
     if ( strategy->showHeader( "date" ) )
       headerStr.append(QString("<tr><th>%1</th>\n"
-                   "<td dir=\"%2\">%3</td></tr>\n")
-                            .arg(i18n("Date: "))
-                    .arg( directionOf( message->dateStr() ) )
-                            .arg(strToHtml(dateString)));
+                               "<td dir=\"%2\">%3</td></tr>\n")
+                       .arg(i18n("Date: "))
+                       .arg( directionOf( message->dateStr() ) )
+                       .arg(strToHtml(dateString)));
+
+    if ( GlobalSettings::self()->showUserAgent() ) {
+      if ( strategy->showHeader( "user-agent" ) ) {
+        if ( !message->headerField("User-Agent").isEmpty() ) {
+          headerStr.append(QString("<tr><th>%1</th>\n"
+                                   "<td>%2</td></tr>\n")
+                           .arg(i18n("User-Agent: "))
+                           .arg( strToHtml( message->headerField("User-Agent") ) ) );
+        }
+      }
+
+      if ( strategy->showHeader( "x-mailer" ) ) {
+        if ( !message->headerField("X-Mailer").isEmpty() ) {
+          headerStr.append(QString("<tr><th>%1</th>\n"
+                                   "<td>%2</td></tr>\n")
+                           .arg(i18n("X-Mailer: "))
+                           .arg( strToHtml( message->headerField("X-Mailer") ) ) );
+        }
+      }
+    }
 
     // FIXME: Show status in synthetic header style field.  Decide whether this or current in brackets style is best and remove one.
     /*    if( strategy->showHeader( "status" ) )
