@@ -5,6 +5,7 @@
 
 #include "accountmanager.h"
 using KMail::AccountManager;
+#include "globalsettings.h"
 #include "kmacctfolder.h"
 #include "kmfoldermgr.h"
 #include "kmfiltermgr.h"
@@ -98,6 +99,7 @@ KMAccount::KMAccount(AccountManager* aOwner, const QString& aName, uint id)
 void KMAccount::init() {
   mTrash = kmkernel->trashFolder()->idString();
   mExclude = false;
+  // when creating a new account, mail checking interval shall be default
   mInterval = 0;
   mNewInFolder.clear();
 }
@@ -142,6 +144,7 @@ void KMAccount::readConfig(KConfig& config)
   QString folderName;
   mFolder = 0;
   folderName = config.readEntry("Folder");
+  // if check-interval has been deleted from kmailrc, it shall be default
   setCheckInterval(config.readNumEntry("check-interval", 0));
   setTrash(config.readEntry("trash", kmkernel->trashFolder()->idString()));
   setCheckExclude(config.readBoolEntry("check-exclude", false));
@@ -289,6 +292,13 @@ void KMAccount::setCheckInterval(int aInterval)
   // Don't call installTimer from here! See #117935.
 }
 
+int KMAccount::checkInterval() const
+{
+  if ( mInterval <= 0 )
+    return mInterval;
+  return QMAX( mInterval, GlobalSettings::self()->minimumCheckInterval() );
+}
+
 //----------------------------------------------------------------------------
 void KMAccount::deleteFolderJobs()
 {
@@ -324,14 +334,14 @@ void KMAccount::installTimer()
   if (mInterval <= 0) return;
   if(!mTimer)
   {
-    mTimer = new QTimer();
+    mTimer = new QTimer(0, "mTimer");
     connect(mTimer,SIGNAL(timeout()),SLOT(mailCheck()));
   }
   else
   {
     mTimer->stop();
   }
-  mTimer->start(mInterval*60000);
+  mTimer->start( checkInterval() * 60000 );
 }
 
 
@@ -449,7 +459,7 @@ void KMAccount::checkDone( bool newmail, CheckStatus status )
   // Reset the timeout for automatic mailchecking. The user might have
   // triggered the check manually.
   if (mTimer)
-    mTimer->start(mInterval*60000);
+    mTimer->start( checkInterval() * 60000 );
   if ( mMailCheckProgressItem ) {
     // set mMailCheckProgressItem = 0 before calling setComplete() to prevent
     // a race condition
