@@ -28,7 +28,10 @@ class KMMsgBase;
 class KMReaderWin;
 class partNode;
 namespace KIO { class Job; }
-namespace KMail { class Composer; }
+namespace KMail {
+  class Composer;
+  class FolderJob;
+}
 namespace GpgME { class Error; }
 namespace Kleo { class SpecialJob; }
 
@@ -284,6 +287,17 @@ private:
   virtual Result execute();
 };
 
+class KDE_EXPORT KMUseTemplateCommand : public KMCommand
+{
+  Q_OBJECT
+
+public:
+  KMUseTemplateCommand( QWidget *parent, KMMessage *msg );
+
+private:
+  virtual Result execute();
+};
+
 class KDE_EXPORT KMShowMsgSrcCommand : public KMCommand
 {
   Q_OBJECT
@@ -522,6 +536,57 @@ private:
   virtual Result execute();
 };
 
+class KDE_EXPORT KMCustomReplyToCommand : public KMCommand
+{
+  Q_OBJECT
+
+public:
+  KMCustomReplyToCommand( QWidget *parent, KMMessage *msg,
+                          const QString &selection,
+                          const QString &tmpl );
+
+private:
+  virtual Result execute();
+
+private:
+  QString mSelection;
+  QString mTemplate;
+};
+
+class KDE_EXPORT KMCustomReplyAllToCommand : public KMCommand
+{
+  Q_OBJECT
+
+public:
+  KMCustomReplyAllToCommand( QWidget *parent, KMMessage *msg,
+                          const QString &selection,
+                          const QString &tmpl );
+
+private:
+  virtual Result execute();
+
+private:
+  QString mSelection;
+  QString mTemplate;
+};
+
+class KDE_EXPORT KMCustomForwardCommand : public KMCommand
+{
+  Q_OBJECT
+
+public:
+  KMCustomForwardCommand( QWidget *parent, const QPtrList<KMMsgBase> &msgList,
+                          uint identity, const QString &tmpl );
+  KMCustomForwardCommand( QWidget *parent, KMMessage * msg,
+                          uint identity, const QString &tmpl );
+
+private:
+  virtual Result execute();
+
+  uint mIdentity;
+  QString mTemplate;
+};
+
 class KDE_EXPORT KMPrintCommand : public KMCommand
 {
   Q_OBJECT
@@ -586,7 +651,7 @@ public:
 
 private:
   virtual Result execute();
-
+  QValueList<Q_UINT32> serNumList;
   KMFilter *mFilter;
 };
 
@@ -671,18 +736,16 @@ public:
   KMCopyCommand( KMFolder* destFolder, KMMessage *msg );
 
 protected slots:
-  void slotMsgAdded( KMFolder*, Q_UINT32 );
+  void slotJobFinished( KMail::FolderJob *job );
 
-  void slotFolderComplete();
+  void slotFolderComplete( KMFolderImap*, bool success );
 
 private:
   virtual Result execute();
 
   KMFolder *mDestFolder;
   QPtrList<KMMsgBase> mMsgList;
-  // List of serial numbers that need to be loaded
-  // Ticked off as they come in via msgAdded signals.
-  QValueList<Q_UINT32> mWaitingForMsgs;
+  QValueList<KMail::FolderJob*> mPendingJobs;
 };
 
 namespace KPIM {
@@ -707,7 +770,7 @@ protected:
   // Needed for KMDeleteCommand for "move to trash"
   KMMoveCommand( Q_UINT32 sernum );
   void setDestFolder( KMFolder* folder ) { mDestFolder = folder; }
-  void addMsg( KMMsgBase *msg ) { mMsgList.append( msg ); }
+  void addMsg( KMMsgBase *msg ) { mSerNumList.append( msg->getMsgSerNum() ); }
   QValueVector<KMFolder*> mOpenedFolders;
 
 private:
@@ -715,7 +778,7 @@ private:
   void completeMove( Result result );
 
   KMFolder *mDestFolder;
-  QPtrList<KMMsgBase> mMsgList;
+  QValueList<Q_UINT32> mSerNumList;
   // List of serial numbers that have to be transferred to a host.
   // Ticked off as they come in via msgAdded signals.
   QValueList<Q_UINT32> mLostBoys;
@@ -795,7 +858,7 @@ class KDE_EXPORT KMMailingListCommand : public KMCommand
 {
   Q_OBJECT
 public:
-  KMMailingListCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListCommand( QWidget *parent, KMFolder *folder );
 private:
   virtual Result execute();
 private slots:
@@ -810,7 +873,7 @@ class KDE_EXPORT KMMailingListPostCommand : public KMMailingListCommand
 {
   Q_OBJECT
 public:
-  KMMailingListPostCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListPostCommand( QWidget *parent, KMFolder *folder );
 protected:
   virtual KURL::List urls() const;
 };
@@ -819,7 +882,7 @@ class KDE_EXPORT KMMailingListSubscribeCommand : public KMMailingListCommand
 {
   Q_OBJECT
 public:
-  KMMailingListSubscribeCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListSubscribeCommand( QWidget *parent, KMFolder *folder );
 protected:
   virtual KURL::List urls() const;
 };
@@ -828,7 +891,7 @@ class KDE_EXPORT KMMailingListUnsubscribeCommand : public KMMailingListCommand
 {
   Q_OBJECT
 public:
-  KMMailingListUnsubscribeCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListUnsubscribeCommand( QWidget *parent, KMFolder *folder );
 protected:
   virtual KURL::List urls() const;
 };
@@ -837,7 +900,7 @@ class KDE_EXPORT KMMailingListArchivesCommand : public KMMailingListCommand
 {
   Q_OBJECT
 public:
-  KMMailingListArchivesCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListArchivesCommand( QWidget *parent, KMFolder *folder );
 protected:
   virtual KURL::List urls() const;
 };
@@ -846,7 +909,7 @@ class KDE_EXPORT KMMailingListHelpCommand : public KMMailingListCommand
 {
   Q_OBJECT
 public:
-  KMMailingListHelpCommand( QWidget *parent, KMFolder *parent );
+  KMMailingListHelpCommand( QWidget *parent, KMFolder *folder );
 protected:
   virtual KURL::List urls() const;
 };
