@@ -111,6 +111,7 @@ public: // mailserviceimpl
    * From MailComposerIface
    */
   void send(int how);
+  void addAttachmentsAndSend(const KURL::List &urls, const QString &comment, int how);
   void addAttachment(KURL url,QString comment);
   void addAttachment(const QString &name,
                     const QCString &cte,
@@ -253,6 +254,7 @@ private slots:
   void slotPrint();
   void slotAttachFile();
   void slotInsertRecentFile(const KURL&);
+  void slotAttachedFile(const KURL&);
 public slots: // kmkernel, callback
   void slotSendNow();
 private slots:
@@ -284,6 +286,7 @@ private slots:
   void slotPasteAsAttachment();
   void slotAddQuotes();
   void slotRemoveQuotes();
+  void slotAttachPNGImageData(const QByteArray &image);
 
   void slotMarkAll();
 
@@ -453,7 +456,7 @@ private slots:
   void alignmentChanged( int );
 
 public: // kmkernel, attachmentlistview
-  void addAttach(const KURL url);
+  bool addAttach(const KURL url);
 
 public: // kmcommand
   /**
@@ -461,12 +464,6 @@ public: // kmcommand
    */
   void addAttach(const KMMessagePart* msgPart);
 
-private:
-  /**
-   * Add an image from the clipboard as attachment
-   */
-  void addImageFromClipboard();
-
 private:
   const KPIM::Identity & identity() const;
   uint identityUid() const;
@@ -475,6 +472,7 @@ private:
 
 signals:
   void applyChangesDone( bool );
+  void attachmentAdded( const KURL&, bool success );
 
 private:
   /**
@@ -756,6 +754,9 @@ private:
 
   QStringList mFolderNames;
   QValueList<QGuardedPtr<KMFolder> > mFolderList;
+  QMap<KIO::Job*, KURL> mAttachJobs;
+  KURL::List mAttachFilesPending;
+  int mAttachFilesSend;
 
 private:
   // helper method for slotInsert(My)PublicKey()
@@ -779,7 +780,7 @@ private slots:
 
   void slotContinueDoSend( bool );
   void slotContinuePrint( bool );
-  void slotContinueAutoSave( bool );
+  void slotContinueAutoSave();
 
   void slotEncryptChiasmusToggled( bool );
 
@@ -838,6 +839,15 @@ private:
 
   QPopupMenu *mActNowMenu;
   QPopupMenu *mActLaterMenu;
+
+  /** If the message in this composer has a cursor position set (for
+   *   instance because it comes from a template containing %CURSOR)
+   *   then we need to preserve that cursor position even when auto-
+   *   appending (or prepending) the signature during composer setup.
+   *   Set to true *once* (and only in setMsg() at that) to avoid
+   *   accidentally moving the cursor.
+   */
+  bool mPreserveUserCursorPosition;
 };
 
 #endif
