@@ -60,6 +60,8 @@ void KMEdit::contentsDragEnterEvent(QDragEnterEvent *e)
 {
     if (e->provides(MailListDrag::format()))
         e->accept(true);
+    else if (e->provides("image/png"))
+        e->accept();
     else
         return KEdit::contentsDragEnterEvent(e);
 }
@@ -68,6 +70,8 @@ void KMEdit::contentsDragMoveEvent(QDragMoveEvent *e)
 {
     if (e->provides(MailListDrag::format()))
         e->accept();
+    else if (e->provides("image/png"))
+        e->accept();
     else
         return KEdit::contentsDragMoveEvent(e);
 }
@@ -164,6 +168,9 @@ void KMEdit::contentsDropEvent(QDropEvent *e)
                                          identity, mComposer);
         command->start();
     }
+    else if( e->provides("image/png") ) {
+        emit attachPNGImageData(e->encodedData("image/png"));
+    }
     else if( KURLDrag::canDecode( e ) ) {
         KURL::List urlList;
         if( KURLDrag::decode( e, urlList ) ) {
@@ -195,7 +202,7 @@ void KMEdit::contentsDropEvent(QDropEvent *e)
           kdDebug(5006) << "KMEdit::contentsDropEvent, unable to add dropped object" << endl;
     }
     else {
-        return KEdit::contentsDropEvent(e);
+        KEdit::contentsDropEvent(e);
     }
 }
 
