@@ -62,7 +62,8 @@ using KMail::RenameJob;
 #include <assert.h>
 
 KMFolderImap::KMFolderImap(KMFolder* folder, const char* aName)
-  : KMFolderMbox(folder, aName)
+  : KMFolderMbox(folder, aName),
+    mUploadAllFlags( false )
 {
   mContentState = imapNoInformation;
   mSubfolderState = imapNoInformation;
@@ -106,21 +107,13 @@ KMFolderImap::~KMFolderImap()
 
 
 //-----------------------------------------------------------------------------
-void KMFolderImap::close(const char *owner, bool aForced)
+void KMFolderImap::reallyDoClose(const char *owner)
 {
-  if (mOpenCount > 0) mOpenCount--;
-  if (mOpenCount == 0 && isSelected() && !aForced) {
+  if ( isSelected() ) {
       kdWarning(5006) << "Trying to close the selected folder " << label() <<
         " - ignoring! " << kdBacktrace() << endl;
-      mOpenCount++;
       return;
   }
-  if (mOpenCount > 0 && !aForced) {
-    // The inherited close will decrement again, so we have to adjust.
-    mOpenCount++;
-    KMFolderMbox::close(owner, aForced);
-    return;
-  }
 
   // FIXME is this still needed?
   if (account())
@@ -136,9 +129,7 @@ void KMFolderImap::close(const char *owner, bool aForced)
 
   mCheckingValidity = false;
 
-  // The inherited close will decrement again, so we have to adjust.
-  mOpenCount++;
-  KMFolderMbox::close(owner, aForced);
+  KMFolderMbox::reallyDoClose(owner);
 }
 
 KMFolder* KMFolderImap::trashFolder() const
@@ -218,6 +209,7 @@ void KMFolderImap::readConfig()
   }
   mNoContent = config->readBoolEntry("NoContent", FALSE);
   mReadOnly = config->readBoolEntry("ReadOnly", FALSE);
+  mUploadAllFlags = config->readBoolEntry( "UploadAllFlags", true );
 
   KMFolderMbox::readConfig();
 }
@@ -232,6 +224,7 @@ void KMFolderImap::writeConfig()
   config->writeEntry("ImapPath", mImapPath);
   config->writeEntry("NoContent", mNoContent);
   config->writeEntry("ReadOnly", mReadOnly);
+  config->writeEntry( "UploadAllFlags", mUploadAllFlags );
   KMFolderMbox::writeConfig();
 }
 
@@ -549,8 +542,6 @@ void KMFolderImap::copyMsg(QPtrList<KMMessage>& msgList)
     QPtrList<KMMessage> temp_msgs = splitMessageList(*it, msgList);
 
     ImapJob *job = new ImapJob(temp_msgs, *it, ImapJob::tCopyMessage, this);
-    connect(job, SIGNAL(messageCopied(QPtrList<KMMessage>)),
-            SLOT(addMsgQuiet(QPtrList<KMMessage>)));
     connect(job, SIGNAL(result(KMail::FolderJob*)),
             SLOT(slotCopyMsgResult(KMail::FolderJob*)));
     job->start();
@@ -1132,6 +1123,7 @@ void KMFolderImap::slotCheckValidityResult(KIO::Job * job)
       // we notice when this changes
       account()->handleJobError( job, i18n("Error while querying the server status.") );
     }
+    kdDebug() << "error in slotCheckValidityResult\n";
     mContentState = imapNoInformation;
     emit folderComplete(this, FALSE);
     close("checkvalidity");
@@ -1212,6 +1204,7 @@ void KMFolderImap::getFolder(bool force)
   mGuessedUnreadMsgs = -1;
   if (mNoContent)
   {
+    kdDebug() << "getFolder " << force << " " << mContentState << endl;
     mContentState = imapFinished;
     emit folderComplete(this, true);
     return;
@@ -1260,6 +1253,7 @@ void KMFolderImap::reallyGetFolder(const QString &startUid)
       mMailCheckProgressItem->setStatus( i18n("Retrieving messages") );
     url.setPath(imapPath() + ";UID=" + startUid
       + ":*;SECTION=ENVELOPE");
+    kdDebug() << folder()->name() << " download " << url << endl;
     KIO::SimpleJob *newJob = KIO::get(url, FALSE, FALSE);
     KIO::Scheduler::assignJobToSlave(account()->slave(), newJob);
     ImapAccountBase::jobData jd( url.url(), folder() );
@@ -1319,6 +1313,8 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
         // be considered correct.
         if (!mReadOnly)
           flagsToStatus( msgBase, serverFlags, false );
+        else
+          seenFlagToStatus( msgBase, serverFlags, false );
         idx++;
         uid = (*it).items.remove(uid);
         if ( msgBase->getMsgSerNum() > 0 ) {
@@ -1369,6 +1365,7 @@ void KMFolderImap::slotListFolderResult(KIO::Job * job)
     KURL url = account()->getUrl();
     url.setPath(imapPath() + ";UID=" + *i + ";SECTION=ENVELOPE");
     KIO::SimpleJob *newJob = KIO::get(url, FALSE, FALSE);
+    kdDebug() << folder()->name() << " download " << url << endl;
     jd.url = url.url();
     KIO::Scheduler::assignJobToSlave(account()->slave(), newJob);
     account()->insertJob(newJob, jd);
@@ -1443,8 +1440,6 @@ void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg)
     msg->setStatus( KMMsgStatusFlag );
   if ( (flags & 2) && (oldStatus & KMMsgStatusReplied) == 0 )
     msg->setStatus( KMMsgStatusReplied );
-  if ( (flags & 1) && (oldStatus & KMMsgStatusOld) == 0 )
-    msg->setStatus( KMMsgStatusOld );
 
   // Toggle flags if they changed
 //  if ( ( (flags & 4) > 0 ) != ( (oldStatus & KMMsgStatusFlag) > 0 ) )
@@ -1454,10 +1449,21 @@ void KMFolderImap::flagsToStatus(KMMsgBase *msg, int flags, bool newMsg)
 //  if ( ( (flags & 1) > 0 ) != ( (oldStatus & KMMsgStatusOld) > 0 ) )
 //    msg->toggleStatus( KMMsgStatusOld );
 
+  seenFlagToStatus( msg, flags, newMsg );
+}
+
+void KMFolderImap::seenFlagToStatus(KMMsgBase * msg, int flags, bool newMsg)
+{
+  if ( !msg ) return;
+
+  const KMMsgStatus oldStatus = msg->status();
+  if ( (flags & 1) && (oldStatus & KMMsgStatusOld) == 0 )
+    msg->setStatus( KMMsgStatusOld );
+
   // In case the message does not have the seen flag set, override our local
   // notion that it is read. Otherwise the count of unread messages and the
   // number of messages which actually show up as read can go out of sync.
-  if (msg->isOfUnknownStatus() || !(flags&1) ) {
+  if ( msg->isOfUnknownStatus() || (!(flags&1) && !(oldStatus&(KMMsgStatusNew|KMMsgStatusUnread)) ) ) {
     if (newMsg) {
       if ( (oldStatus & KMMsgStatusNew) == 0 )
         msg->setStatus( KMMsgStatusNew );
@@ -1871,11 +1877,20 @@ void KMFolderImap::setStatus(int idx, KMMsgStatus status, bool toggle)
   setStatus(ids, status, toggle);
 }
 
-void KMFolderImap::setStatus(QValueList<int>& ids, KMMsgStatus status, bool toggle)
+void KMFolderImap::setStatus(QValueList<int>& _ids, KMMsgStatus status, bool toggle)
 {
   open( "setstatus" );
-  FolderStorage::setStatus(ids, status, toggle);
-  if (mReadOnly) return;
+  FolderStorage::setStatus(_ids, status, toggle);
+  QValueList<int> ids;
+  if ( mUploadAllFlags ) {
+    kdDebug(5006) << k_funcinfo << "Migrating all flags to the server" << endl;
+    ids.clear();
+    for ( int i = 0; i < count(); ++i )
+      ids << i;
+    mUploadAllFlags = false;
+  } else {
+    ids = _ids;
+  }
 
   /* The status has been already set in the local index. Update the flags on
    * the server. To avoid doing that for each message individually, group them
@@ -1887,6 +1902,38 @@ void KMFolderImap::setStatus(QValueList<int>& ids, KMMsgStatus status, bool togg
    * this method with a list of uids. The 2 important mails need to get the string
    * \SEEN \FLAGGED while the others need to get just \SEEN. Build sets for each
    * of those and sort them, so the server can handle them efficiently. */
+
+  if ( mReadOnly ) { // mUserRights is not available here
+    // FIXME duplicated code in KMFolderCachedImap
+    QValueList<ulong> seenUids, unseenUids;
+    for ( QValueList<int>::ConstIterator it = ids.constBegin(); it != ids.constEnd(); ++it ) {
+      KMMessage *msg = 0;
+      bool unget = !isMessage(*it);
+      msg = getMsg(*it);
+      if (!msg) continue;
+      if ( msg->status() & KMMsgStatusOld || msg->status() & KMMsgStatusRead )
+        seenUids.append( msg->UID() );
+      else
+        unseenUids.append( msg->UID() );
+      if (unget) unGetMsg(*it);
+    }
+    if ( !seenUids.isEmpty() ) {
+      QStringList sets = KMFolderImap::makeSets( seenUids, true );
+      for( QStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
+        QString imappath = imapPath() + ";UID=" + ( *it );
+        account()->setImapSeenStatus( folder(), imappath, true );
+      }
+    }
+    if ( !unseenUids.isEmpty() ) {
+      QStringList sets = KMFolderImap::makeSets( unseenUids, true );
+      for( QStringList::Iterator it = sets.begin(); it != sets.end(); ++it ) {
+        QString imappath = imapPath() + ";UID=" + ( *it );
+        account()->setImapSeenStatus( folder(), imappath, false );
+      }
+    }
+    return;
+  }
+
   QMap< QString, QStringList > groups;
   for ( QValueList<int>::Iterator it = ids.begin(); it != ids.end(); ++it ) {
     KMMessage *msg = 0;
@@ -1908,11 +1955,13 @@ void KMFolderImap::setStatus(QValueList<int>& ids, KMMsgStatus status, bool togg
        account()->setImapStatus(folder(), imappath, flags);
      }
   }
+  kdDebug() << folder()->name() << " setStatus " << mContentState << endl;
   if ( mContentState == imapListingInProgress ) {
     // we're currently get'ing this folder
     // to make sure that we get the latest flags abort the current listing and
     // create a new one
     kdDebug(5006) << "Set status during folder listing, restarting listing." << endl;
+    kdDebug() << "disconnct slotListFolderResult\n";
     disconnect(this, SLOT(slotListFolderResult(KIO::Job *)));
     quiet( false );
     reallyGetFolder( QString::null );
@@ -2372,6 +2421,7 @@ void KMFolderImap::setImapPath( const QString& path )
 
 void KMFolderImap::finishMailCheck( const char *dbg, imapState state )
 {
+  kdDebug() << folder()->name() << " finishMailCheck " << dbg << " " << state << endl;
   quiet( false );
   mContentState = state;
   emit folderComplete( this, mContentState == imapFinished );
