@@ -131,10 +131,8 @@ public:
   /** Remove the IMAP folder on the server and if successful also locally */
   virtual void remove();
 
-  /** Close folder. If force is TRUE the files are closed even if
-    others still use it (e.g. other mail reader windows). This also
-    cancels all pending jobs. */
-  virtual void close(const char *owner, bool force=FALSE);
+  /** Closes and cancels all pending jobs. */
+  virtual void reallyDoClose(const char *owner);
 
   /** Automatically expunge deleted messages when leaving the folder */
   bool autoExpunge();
@@ -192,7 +190,7 @@ public:
   /**
    * Change the status of several messages indicated by @p ids
    */
-  virtual void setStatus(QValueList<int>& ids, KMMsgStatus status, bool toggle);
+  virtual void setStatus(QValueList<int>& _ids, KMMsgStatus status, bool toggle);
 
   /** generates sets of uids */
   static QStringList makeSets( QValueList<ulong>&, bool sort = true);
@@ -374,6 +372,12 @@ public slots:
    */
   static void flagsToStatus(KMMsgBase *msg, int flags, bool newMsg = TRUE);
 
+  /**
+   * Convert IMAP seen flag to a message status.
+   * @param newMsg specifies whether unseen messages are new or unread
+   */
+  static void seenFlagToStatus( KMMsgBase *msg, int flags, bool newMsg = true );
+
   /**
    * Connected to the result signal of the copy/move job
    */
@@ -526,6 +530,12 @@ private:
   ProgressItem *mAddMessageProgressItem;
   // to-be-added folders
   QStringList mFoldersPendingCreation;
+
+  // push all flags to the server instead of just the changed once
+  // when doing a flag change the next time
+  // this is needed for migrating local flags from the time where we didn't
+  // have the ability to store them on the server
+  bool mUploadAllFlags;
 };
 
 #endif // kmfolderimap_h
