@@ -36,7 +36,7 @@ using KMail::MaildirJob;
 #include <unistd.h>
 #include <assert.h>
 #include <limits.h>
-#include <unistd.h>
+#include <ctype.h>
 #include <fcntl.h>
 
 #ifndef MAX_LINE
@@ -58,7 +58,7 @@ KMFolderMaildir::KMFolderMaildir(KMFolder* folder, const char* name)
 //-----------------------------------------------------------------------------
 KMFolderMaildir::~KMFolderMaildir()
 {
-  if (mOpenCount>0) close(true);
+  if (mOpenCount>0) close("~foldermaildir", true);
   if (kmkernel->undoStack()) kmkernel->undoStack()->folderDestroyed( folder() );
 }
 
@@ -96,7 +96,7 @@ int KMFolderMaildir::canAccess()
 }
 
 //-----------------------------------------------------------------------------
-int KMFolderMaildir::open()
+int KMFolderMaildir::open(const char *)
 {
   int rc = 0;
 
@@ -219,22 +219,8 @@ int KMFolderMaildir::create()
 
 
 //-----------------------------------------------------------------------------
-void KMFolderMaildir::close(bool aForced)
+void KMFolderMaildir::reallyDoClose(const char *)
 {
-  if (mOpenCount <= 0) return;
-  if (mOpenCount > 0) mOpenCount--;
-
-  if (mOpenCount > 0 && !aForced) return;
-
-#if 0 // removed hack that prevented closing system folders (see kmail-devel discussion about mail expiring)
-  if ( (folder() != kmkernel->inboxFolder())
-       && folder()->isSystemFolder() && !aForced)
-  {
-     mOpenCount = 1;
-     return;
-  }
-#endif
-
   if (mAutoCreateIndex)
   {
       updateIndex();
@@ -405,7 +391,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
   if ( !uidHeader.isEmpty() && stripUid )
     aMsg->removeHeaderField( "X-UID" );
 
-  msgText = aMsg->asString();
+  msgText = aMsg->asString(); // TODO use asDwString instead
   len = msgText.length();
 
   // Re-add the uid so that the take can make use of it, in case the
@@ -426,7 +412,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
   tmp_file += filename;
 
   if (!KPIM::kCStringToFile(msgText, tmp_file, false, false, false))
-    kmkernel->emergencyExit( i18n("Message could not be added to the folder, possibly disk space is low.") ); 
+    kmkernel->emergencyExit( i18n("Message could not be added to the folder, possibly disk space is low.") );
 
   QFile file(tmp_file);
   size = msgText.length();
@@ -434,7 +420,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
   if (!isOpened())
   {
     opened = true;
-    rc = open();
+    rc = open("maildir");
     kdDebug(5006) << "KMFolderMaildir::addMsg-open: " << rc << " of folder: " << label() << endl;
     if (rc) return rc;
   }
@@ -445,7 +431,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
   if (moveInternal(tmp_file, new_loc, filename, aMsg->status()).isNull())
   {
     file.remove();
-    if (opened) close();
+    if (opened) close("maildir");
     return -1;
   }
 
@@ -477,10 +463,10 @@ if( fileD0.open( IO_WriteOnly ) ) {
   }
   ++mTotalMsgs;
 
-  if ( aMsg->attachmentState() == KMMsgAttachmentUnknown && 
+  if ( aMsg->attachmentState() == KMMsgAttachmentUnknown &&
        aMsg->readyToShow() )
     aMsg->updateAttachmentState();
-  
+
   // store information about the position in the folder file in the message
   aMsg->setParent(folder());
   aMsg->setMsgSize(size);
@@ -543,7 +529,7 @@ if( fileD0.open( IO_WriteOnly ) ) {
   emitMsgAddedSignals(idx);
   needsCompact = true;
 
-  if (opened) close();
+  if (opened) close("maildir" );
 /*
 QFile fileD1( "testdat_xx-kmfoldermaildir-1" );
 if( fileD1.open( IO_WriteOnly ) ) {
@@ -593,29 +579,6 @@ DwString KMFolderMaildir::getDwString(int idx)
 }
 
 
-QCString& KMFolderMaildir::getMsgString(int idx, QCString& mDest)
-{
-  KMMsgInfo* mi = (KMMsgInfo*)mMsgList[idx];
-
-  assert(mi!=0);
-
-  QString abs_file(location() + "/cur/");
-  abs_file += mi->fileName();
-
-  if (QFile::exists(abs_file) == false)
-  {
-    kdDebug(5006) << "The " << abs_file << " file doesn't exist!" << endl;
-    return mDest;
-  }
-
-  QFileInfo fi( abs_file );
-  mDest.resize(fi.size()+2);
-  mDest = KPIM::kFileToString(abs_file, false, false);
-  size_t newMsgSize = KMail::Util::crlf2lf( mDest.data(), fi.size() );
-  mDest[newMsgSize] = '\0';
-  return mDest;
-}
-
 void KMFolderMaildir::readFileHeaderIntern(const QString& dir, const QString& file, KMMsgStatus status)
 {
   // we keep our current directory to restore it later
@@ -653,6 +616,7 @@ void KMFolderMaildir::readFileHeaderIntern(const QString& dir, const QString& fi
   QCString dateStr, fromStr, toStr, subjStr;
   QCString xmarkStr, replyToIdStr, msgIdStr, referencesStr;
   QCString statusStr, replyToAuxIdStr, uidStr;
+  QCString contentTypeStr, charset;
 
   // iterate through this file until done
   while (!atEof)
@@ -725,6 +689,29 @@ void KMFolderMaildir::readFileHeaderIntern(const QString& dir, const QString& fi
           status |= KMMsgStatusFlag;
       }
 
+      contentTypeStr = contentTypeStr.stripWhiteSpace();
+      charset = "";
+      if ( !contentTypeStr.isEmpty() )
+      {
+        int cidx = contentTypeStr.find( "charset=" );
+        if ( cidx != -1 ) {
+          charset = contentTypeStr.mid( cidx + 8 );
+          if ( !charset.isEmpty() && ( charset[0] == '"' ) ) {
+            charset = charset.mid( 1 );
+          }
+          cidx = 0;
+          while ( (unsigned int) cidx < charset.length() ) {
+            if ( charset[cidx] == '"' || ( !isalnum(charset[cidx]) &&
+                 charset[cidx] != '-' && charset[cidx] != '_' ) )
+              break;
+            ++cidx;
+          }
+          charset.truncate( cidx );
+          // kdDebug() << "KMFolderMaildir::readFileHeaderIntern() charset found: " <<
+          //              charset << " from " << contentTypeStr << endl;
+        }
+      }
+
       KMMsgInfo *mi = new KMMsgInfo(folder());
       mi->init( subjStr.stripWhiteSpace(),
                 fromStr.stripWhiteSpace(),
@@ -734,7 +721,7 @@ void KMFolderMaildir::readFileHeaderIntern(const QString& dir, const QString& fi
                 replyToIdStr, replyToAuxIdStr, msgIdStr,
 				file.local8Bit(),
                 KMMsgEncryptionStateUnknown, KMMsgSignatureStateUnknown,
-                KMMsgMDNStateUnknown, f.size() );
+                KMMsgMDNStateUnknown, charset, f.size() );
 
       dateStr = dateStr.stripWhiteSpace();
       if (!dateStr.isEmpty())
@@ -823,6 +810,11 @@ void KMFolderMaildir::readFileHeaderIntern(const QString& dir, const QString& fi
       uidStr = QCString(line+6);
       lastStr = &uidStr;
     }
+    else if (strncasecmp(line, "Content-Type:", 13) == 0)
+    {
+      contentTypeStr = QCString(line+13);
+      lastStr = &contentTypeStr;
+    }
 
   }
 
