@@ -39,10 +39,10 @@
 #include <kprocess.h>
 #include <kconfig.h>
 
-#include <ctype.h>
 #include <stdio.h>
 #include <errno.h>
 #include <assert.h>
+#include <ctype.h>
 #include <unistd.h>
 
 #ifdef HAVE_FCNTL_H
@@ -256,24 +256,8 @@ int KMFolderMbox::create()
 
 
 //-----------------------------------------------------------------------------
-void KMFolderMbox::close(const char *owner, bool aForced)
+void KMFolderMbox::reallyDoClose(const char *owner)
 {
-  if (!aForced)
-     assert(mOpenCount >= 0);
-
-  if (mOpenCount <= 0 || !mStream) { mOpenCount = 0; return; }
-  if (mOpenCount > 0) mOpenCount--;
-  if (mOpenCount > 0 && !aForced) { assert(mStream); return; }
-
-#if 0 // removed hack that prevented closing system folders (see kmail-devel discussion about mail expiring)
-  if ( (folder() != kmkernel->inboxFolder())
-        && folder()->isSystemFolder() && !aForced )
-  {
-      mOpenCount = 1;
-      return;
-  }
-#endif
-
   if (mAutoCreateIndex)
   {
       if (KMFolderIndex::IndexOk != indexStatus()) {
