@@ -60,8 +60,7 @@ public:
   /** Returns the type of this folder */
   virtual KMFolderType folderType() const { return KMFolderTypeMbox; }
 
-  /** Read a message and return a referece to a string */
-  virtual QCString& getMsgString(int idx, QCString& mDest);
+  /** Read a message and return it as a string */
   DwString getDwString(int idx);
 
   /** Add the given message to the folder. Usually the message
@@ -77,11 +76,10 @@ public:
     call close() first.
     Returns zero on success and an error code equal to the c-library
     fopen call otherwise (errno). */
-  virtual int open();
+  virtual int open(const char *owner);
 
-  /** Close folder. If force is TRUE the files are closed even if
-    others still use it (e.g. other mail reader windows). */
-  virtual void close(bool force=FALSE);
+  /** @reimpl */
+  virtual void reallyDoClose(const char *owner);
 
   virtual int canAccess();
 
@@ -109,7 +107,7 @@ public:
 
   void setProcmailLockFileName( const QString& );
 
-  static QCString escapeFrom( const QCString & str );
+  static QByteArray escapeFrom( const DwString & str );
 
   virtual IndexStatus indexStatus();
 
