@@ -80,7 +80,7 @@ KMSearch::KMSearch(QObject * parent, const char * name)
     mFoundCount = 0;
     mSearchCount = 0;
 
-    mProcessNextBatchTimer = new QTimer();
+    mProcessNextBatchTimer = new QTimer(0, "mProcessNextBatchTimer");
     connect(mProcessNextBatchTimer, SIGNAL(timeout()), this, SLOT(slotProcessNextBatch()));
 }
 
@@ -146,6 +146,15 @@ bool KMSearch::inScope(KMFolder* folder) const
 
 void KMSearch::start()
 {
+    //close all referenced folders
+    QValueListIterator<QGuardedPtr<KMFolder> > fit;
+    for (fit = mFolders.begin(); fit != mFolders.end(); ++fit) {
+        if (!(*fit))
+            continue;
+        (*fit)->close("kmsearch");
+    }
+    mFolders.clear();
+
     if ( running() )
         return;
 
@@ -220,7 +229,7 @@ void KMSearch::stop()
             }
             folder->storage()->search( 0 );
             mSearchCount += folder->count();
-            folder->close();
+            folder->close("kmsearch");
         }
     }
     mRemainingFolders = -1;
@@ -248,7 +257,7 @@ void KMSearch::slotProcessNextBatch()
         if ( folder )
         {
             mLastFolder = folder->label();
-            folder->open();
+            folder->open("kmsearch");
             mOpenedFolders.append( folder );
             connect( folder->storage(),
                 SIGNAL( searchResult( KMFolder*, QValueList<Q_UINT32>, const KMSearchPattern*, bool ) ),
@@ -286,7 +295,7 @@ void KMSearch::slotSearchFolderResult( KMFolder* folder,
                                         const KMSearchPattern*, bool ) ) );
       --mRemainingFolders;
       mSearchCount += folder->count();
-      folder->close();
+      folder->close("kmsearch");
       mOpenedFolders.remove( folder );
       if ( mRemainingFolders <= 0 )
       {
@@ -358,7 +367,7 @@ KMFolderSearch::KMFolderSearch(KMFolder* folder, const char* name)
     connect(kmkernel->dimapFolderMgr(), SIGNAL(msgHeaderChanged(KMFolder*,int)),
             this, SLOT(propagateHeaderChanged(KMFolder*,int)));
 
-  mExecuteSearchTimer = new QTimer();
+  mExecuteSearchTimer = new QTimer(0, "mExecuteSearchTimer");
   connect(mExecuteSearchTimer, SIGNAL(timeout()),
           this, SLOT(executeSearch()));
 }
@@ -369,7 +378,7 @@ KMFolderSearch::~KMFolderSearch()
     delete mSearch;
     mSearch = 0;
     if (mOpenCount > 0)
-        close(TRUE);
+        close("~foldersearch", TRUE);
 }
 
 void KMFolderSearch::setSearch(KMSearch *search)
@@ -403,7 +412,7 @@ void KMFolderSearch::setSearch(KMSearch *search)
     /* TODO There is KMFolder::cleared signal now. Adjust. */
     if (mSearch)
         mSearch->start();
-    open(); // will be closed in searchFinished
+    open("foldersearch"); // will be closed in searchFinished
 }
 
 void KMFolderSearch::executeSearch()
@@ -423,7 +432,7 @@ void KMFolderSearch::searchFinished(bool success)
 {
     if (!success)
         mSerNums.clear();
-    close();
+    close("foldersearch");
 }
 
 void KMFolderSearch::addSerNum(Q_UINT32 serNum)
@@ -435,7 +444,7 @@ void KMFolderSearch::addSerNum(Q_UINT32 serNum)
     KMMsgDict::instance()->getLocation(serNum, &aFolder, &idx);
     assert(aFolder && (idx != -1));
     if(mFolders.findIndex(aFolder) == -1) {
-        aFolder->open();
+        aFolder->open("foldersearch");
         // Exceptional case, for when folder has invalid ids
         if (mInvalid)
             return;
@@ -477,13 +486,6 @@ void KMFolderSearch::removeSerNum(Q_UINT32 serNum)
     }
 }
 
-QCString& KMFolderSearch::getMsgString(int idx, QCString& mDest)
-{
-    KMFolder *folder = getMsgBase(idx)->parent();
-    assert(folder);
-    return folder->getMsgString(folder->find(getMsgBase(idx)), mDest);
-}
-
 int KMFolderSearch::addMsg(KMMessage*, int* index_return)
 {
     //Not supported search folder can't own messages
@@ -499,7 +501,7 @@ bool KMFolderSearch::readSearch()
     return mSearch->read(location());
 }
 
-int KMFolderSearch::open()
+int KMFolderSearch::open(const char *)
 {
     mOpenCount++;
     kmkernel->jobScheduler()->notifyOpeningFolder( folder() );
@@ -537,12 +539,8 @@ void KMFolderSearch::sync()
     }
 }
 
-void KMFolderSearch::close(bool force)
+void KMFolderSearch::reallyDoClose(const char *)
 {
-    if (mOpenCount <= 0) return;
-    if (mOpenCount > 0) mOpenCount--;
-    if (mOpenCount > 0 && !force) return;
-
     if (mAutoCreateIndex) {
         if (mSearch)
             mSearch->write(location());
@@ -557,7 +555,7 @@ void KMFolderSearch::close(bool force)
     for (fit = mFolders.begin(); fit != mFolders.end(); ++fit) {
         if (!(*fit))
             continue;
-        (*fit)->close();
+        (*fit)->close("foldersearch");
     }
     mFolders.clear();
 
@@ -852,7 +850,7 @@ bool KMFolderSearch::readIndex()
         }
         mSerNums.push_back(serNum);
         if(mFolders.findIndex(folder) == -1) {
-            folder->open();
+            folder->open("foldersearch");
             if (mInvalid) //exceptional case for when folder has invalid ids
                 return false;
             mFolders.append(folder);
@@ -910,7 +908,16 @@ KMMsgInfo* KMFolderSearch::setIndexEntry(int idx, KMMessage *msg)
 
 void KMFolderSearch::clearIndex(bool, bool)
 {
-    mSerNums.clear();
+  //close all referenced folders
+  QValueListIterator<QGuardedPtr<KMFolder> > fit;
+  for (fit = mFolders.begin(); fit != mFolders.end(); ++fit) {
+    if (!(*fit))
+      continue;
+    (*fit)->close("foldersearch");
+  }
+  mFolders.clear();
+
+  mSerNums.clear();
 }
 
 void KMFolderSearch::truncateIndex()
@@ -925,7 +932,7 @@ void KMFolderSearch::examineAddedMessage(KMFolder *aFolder, Q_UINT32 serNum)
     if (!search()->inScope(aFolder))
         return;
     if (!mTempOpened) {
-        open();
+        open( "foldersearch" );
         mTempOpened = true;
     }
 
@@ -937,7 +944,7 @@ void KMFolderSearch::examineAddedMessage(KMFolder *aFolder, Q_UINT32 serNum)
     KMMsgDict::instance()->getLocation(serNum, &folder, &idx);
     assert(folder && (idx != -1));
     assert(folder == aFolder);
-    folder->open();
+    folder->open("examineAddedMessage");
 
     // if we are already checking this folder, refcount
     if ( mFoldersCurrentlyBeingSearched.contains( folder ) ) {
@@ -952,6 +959,7 @@ void KMFolderSearch::examineAddedMessage(KMFolder *aFolder, Q_UINT32 serNum)
       mFoldersCurrentlyBeingSearched.insert( folder, 1 );
     }
     folder->storage()->search( search()->searchPattern(), serNum );
+    folder->close("examineAddedMessage");
 }
 
 void KMFolderSearch::slotSearchExamineMsgDone( KMFolder* folder,
@@ -962,6 +970,7 @@ void KMFolderSearch::slotSearchExamineMsgDone( KMFolder* folder,
     if ( search()->searchPattern() != pattern ) return;
     kdDebug(5006) << folder->label() << ": serNum " << serNum
      << " matches?" << matches << endl;
+    folder->open("SearchExamineMsgDone");
 
     if ( mFoldersCurrentlyBeingSearched.contains( folder ) ) {
       unsigned int count = mFoldersCurrentlyBeingSearched[folder];
@@ -979,7 +988,7 @@ void KMFolderSearch::slotSearchExamineMsgDone( KMFolder* folder,
     } else {
       Q_ASSERT( 0 ); // Can't happen (TM)
     }
-    folder->close();
+    folder->close("SearchExamineMsgDone");
 
     if ( !matches ) {
         QValueVector<Q_UINT32>::const_iterator it;
@@ -1009,7 +1018,7 @@ void KMFolderSearch::examineRemovedMessage(KMFolder *folder, Q_UINT32 serNum)
     if (!search()->inScope(folder))
         return;
     if (!mTempOpened) {
-        open();
+        open("foldersearch");
         mTempOpened = true;
     }
 
@@ -1027,7 +1036,7 @@ void KMFolderSearch::examineChangedMessage(KMFolder *aFolder, Q_UINT32 serNum, i
     if (!search()->inScope(aFolder))
         return;
     if (!mTempOpened) {
-        open();
+        open("foldersearch");
         mTempOpened = true;
     }
     QValueVector<Q_UINT32>::const_iterator it;
@@ -1046,7 +1055,7 @@ void KMFolderSearch::examineInvalidatedFolder(KMFolder *folder)
     if (!search()->inScope(folder))
         return;
     if (mTempOpened) {
-        close();
+        close("foldersearch");
         mTempOpened = false;
     }
 
@@ -1063,7 +1072,7 @@ void KMFolderSearch::examineInvalidatedFolder(KMFolder *folder)
         return;
 
     if (!mTempOpened) {
-        open();
+        open("foldersearch");
         mTempOpened = true;
     }
     mExecuteSearchTimer->start(0, true);
@@ -1086,7 +1095,7 @@ void KMFolderSearch::propagateHeaderChanged(KMFolder *aFolder, int idx)
     if (!search()->inScope(aFolder))
         return;
     if (!mTempOpened) {
-        open();
+        open("foldersearch");
         mTempOpened = true;
     }
 
@@ -1100,7 +1109,7 @@ void KMFolderSearch::propagateHeaderChanged(KMFolder *aFolder, int idx)
         ++pos;
     }
     // let's try if the message matches our search
-    aFolder->open();
+    aFolder->open("foldersearch");
 
     // if we are already checking this folder, refcount
     if ( mFoldersCurrentlyBeingSearched.contains( aFolder ) ) {
