@@ -267,7 +267,7 @@ bool KMFolderTreeItem::acceptDrag(QDropEvent* e) const
     return false; // nothing can be dragged into search folders
 
   if ( e->provides( KPIM::MailListDrag::format() ) ) {
-    if ( !mFolder || mFolder->isReadOnly() ||
+    if ( !mFolder || mFolder->moveInProgress() || mFolder->isReadOnly() ||
         (mFolder->noContent() && childCount() == 0) ||
         (mFolder->noContent() && isOpen()) ) {
       return false;
@@ -331,6 +331,8 @@ void KMFolderTreeItem::assignShortcut()
 KMFolderTree::KMFolderTree( KMMainWidget *mainWidget, QWidget *parent,
                             const char *name )
   : KFolderTree( parent, name )
+  , mUpdateTimer( 0, "mUpdateTimer" )
+  , autoopen_timer( 0, "autoopen_timer" )
 {
   oldSelected = 0;
   oldCurrent = 0;
@@ -339,7 +341,7 @@ KMFolderTree::KMFolderTree( KMMainWidget *mainWidget, QWidget *parent,
   mReloading = false;
   mCutFolder = false;
 
-  mUpdateCountTimer= new QTimer( this );
+  mUpdateCountTimer= new QTimer( this, "mUpdateCountTimer" );
 
   setDragEnabled( true );
   addAcceptableDropMimetype(MailListDrag::format(), false);
@@ -379,6 +381,9 @@ void KMFolderTree::connectSignals()
   connect(kmkernel->folderMgr(), SIGNAL(folderRemoved(KMFolder*)),
           this, SLOT(slotFolderRemoved(KMFolder*)));
 
+  connect(kmkernel->folderMgr(), SIGNAL(folderMoveOrCopyOperationFinished()),
+	  this, SLOT(slotFolderMoveOrCopyOperationFinished()));
+
   connect(kmkernel->imapFolderMgr(), SIGNAL(changed()),
           this, SLOT(doFolderListChanged()));
 
@@ -774,11 +779,20 @@ void KMFolderTree::slotAccountRemoved(KMAccount *)
   doFolderSelected( firstChild() );
 }
 
+//-----------------------------------------------------------------------------
+void KMFolderTree::slotFolderMoveOrCopyOperationFinished()
+{
+  setDragEnabled( true );
+}
 //-----------------------------------------------------------------------------
 void KMFolderTree::slotFolderRemoved(KMFolder *aFolder)
 {
   KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>
     (indexOfFolder(aFolder));
+  if ( oldCurrent == fti )
+    oldCurrent = 0;
+  if ( oldSelected == fti )
+    oldSelected = 0;
   if (!fti || !fti->folder()) return;
   if (fti == currentItem())
   {
@@ -787,6 +801,11 @@ void KMFolderTree::slotFolderRemoved(KMFolder *aFolder)
     doFolderSelected( qlvi );
   }
   removeFromFolderToItemMap( aFolder );
+
+  if ( dropItem == fti ) { // The removed item is the dropItem
+    dropItem = 0; // it becomes invalid
+  }
+
   delete fti;
   updateCopyActions();
 }
@@ -1378,6 +1397,9 @@ void KMFolderTree::contentsDragEnterEvent( QDragEnterEvent *e )
     dropItem = i;
     autoopen_timer.start( autoopenTime );
   }
+  else
+    dropItem = 0;
+
   e->accept( acceptDrag(e) );
 }
 
@@ -1443,6 +1465,20 @@ void KMFolderTree::contentsDropEvent( QDropEvent *e )
 
     QListViewItem *item = itemAt( contentsToViewport(e->pos()) );
     KMFolderTreeItem *fti = static_cast<KMFolderTreeItem*>(item);
+    // Check that each pointer is not null
+    for ( QValueList<QGuardedPtr<KMFolder> >::ConstIterator it = mCopySourceFolders.constBegin();
+	  it != mCopySourceFolders.constEnd(); ++it ) {
+      if ( ! (*it) ) {
+	fti = 0;
+	break;
+      }
+    }
+    if (fti && mCopySourceFolders.count() == 1)
+    {
+      KMFolder *source = mCopySourceFolders.first();
+      // if we are dragging to ourselves or to our parent, set fti to 0 so nothing is done
+      if (source == fti->folder() || source->parent()->owner() == fti->folder()) fti = 0;
+    }
     if (fti && acceptDrag(e) && ( fti != oldSelected || e->source() != mMainWidget->headers()->viewport() ) )
     {
       int action = -1;
@@ -1937,6 +1973,9 @@ void KMFolderTree::moveOrCopyFolder( QValueList<QGuardedPtr<KMFolder> > sources,
 {
   kdDebug(5006) << k_funcinfo << "source: " << sources << " destination: " << destination << " move: " << move << endl;
 
+  // Disable drag during copy operation since it prevents from many crashes
+  setDragEnabled( false );
+
   KMFolderDir* parent = &(kmkernel->folderMgr()->dir());
   if ( destination )
     parent = destination->createChildFolder();
@@ -2023,6 +2062,12 @@ void KMFolderTree::moveOrCopyFolder( QValueList<QGuardedPtr<KMFolder> > sources,
     }
   }
 
+  // de-select moved source folders (can cause crash due to unGetMsg() in KMHeaders)
+  if ( move ) {
+    doFolderSelected( indexOfFolder( destination ), false );
+    oldCurrent = currentItem();
+  }
+
   // do the actual move/copy
   for ( QValueList<QGuardedPtr<KMFolder> >::ConstIterator it = sources.constBegin(); it != sources.constEnd(); ++it ) {
     KMFolder* source = *it;
