@@ -523,14 +523,16 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
       msgPart->setTypeStr( attachType );
       msgPart->setSubtypeStr( attachSubType );
       msgPart->setParameter( attachParamAttr, attachParamValue );
-      msgPart->setContentDisposition( attachContDisp );
+       if( ! GlobalSettings::self()->exchangeCompatibleInvitations() ) {
+        msgPart->setContentDisposition( attachContDisp );
+      }
       if( !attachCharset.isEmpty() ) {
         // kdDebug(5006) << "KMKernel::openComposer set attachCharset to "
         // << attachCharset << endl;
         msgPart->setCharset( attachCharset );
       }
       // Don't show the composer window, if the automatic sending is checked
-      KConfigGroup options(  config(), "Groupware" );
+      KConfigGroup options( config(), "Groupware" );
       iCalAutoSend = options.readBoolEntry( "AutomaticSending", true );
     }
   }
@@ -866,7 +868,7 @@ int KMKernel::dcopAddMessage( const QString & foldername,const KURL & msgUrl,
 
         int i;
 
-        mAddMsgCurrentFolder->open();
+        mAddMsgCurrentFolder->open("dcopadd");
         for( i=0; i<mAddMsgCurrentFolder->count(); i++) {
           KMMsgBase *mb = mAddMsgCurrentFolder->getMsgBase(i);
 	  QString id = mb->msgIdMD5();
@@ -885,7 +887,7 @@ int KMKernel::dcopAddMessage( const QString & foldername,const KURL & msgUrl,
             mAddMessageMsgIds.append(id);
           }
         }
-        mAddMsgCurrentFolder->close();
+        mAddMsgCurrentFolder->close("dcopadd");
       }
 
       QString msgId = msg->msgIdMD5();
@@ -1101,7 +1103,7 @@ bool KMKernel::showMail( Q_UINT32 serialNumber, QString /* messageId */ )
     KMMsgDict::instance()->getLocation(serialNumber, &folder, &idx);
     if (!folder || (idx == -1))
       return false;
-    folder->open();
+    folder->open("showmail");
     KMMsgBase *msgBase = folder->getMsgBase(idx);
     if (!msgBase)
       return false;
@@ -1118,7 +1120,7 @@ bool KMKernel::showMail( Q_UINT32 serialNumber, QString /* messageId */ )
 
     if (unGet)
       folder->unGetMsg(idx);
-    folder->close();
+    folder->close("showmail");
     return true;
   }
 
@@ -1132,7 +1134,7 @@ QString KMKernel::getFrom( Q_UINT32 serialNumber )
   KMMsgDict::instance()->getLocation(serialNumber, &folder, &idx);
   if (!folder || (idx == -1))
     return QString::null;
-  folder->open();
+  folder->open("getFrom");
   KMMsgBase *msgBase = folder->getMsgBase(idx);
   if (!msgBase)
     return QString::null;
@@ -1141,7 +1143,7 @@ QString KMKernel::getFrom( Q_UINT32 serialNumber )
   QString result = msg->from();
   if (unGet)
     folder->unGetMsg(idx);
-  folder->close();
+  folder->close("getFrom");
   return result;
 }
 
@@ -1163,7 +1165,7 @@ QString KMKernel::debugSernum( Q_UINT32 serialNumber )
     // different folder
     if (folder && (idx != -1)) {
       // everything is ok
-      folder->open();
+      folder->open("debugser");
       msg = folder->getMsgBase( idx );
       if (msg) {
 	res.append( QString( " subject %s,\n sender %s,\n date %s.\n" )
@@ -1173,7 +1175,7 @@ QString KMKernel::debugSernum( Q_UINT32 serialNumber )
       } else {
 	res.append( QString( "Invalid serial number." ) );
       }
-      folder->close();
+      folder->close("debugser");
     } else {
       res.append( QString( "Invalid serial number." ) );
     }
@@ -1335,7 +1337,7 @@ void KMKernel::recoverDeadLetters()
     return;
 
   KMFolder folder( 0, pathName + "autosave", KMFolderTypeMaildir, false /* no index */ );
-  const int rc = folder.open();
+  const int rc = folder.open("recover");
   if ( rc ) {
     perror( "cannot open autosave folder" );
     return;
@@ -1351,7 +1353,7 @@ void KMKernel::recoverDeadLetters()
       win->show();
     }
   }
-  folder.close();
+  folder.close("recover");
 }
 
 //-----------------------------------------------------------------------------
@@ -1395,7 +1397,7 @@ void KMKernel::initFolders(KConfig* cfg)
    * the index on each start to be on the save side. */
   //if ( the_outboxFolder->folderType() == KMFolderTypeMaildir )
   //  unlink( QFile::encodeName( the_outboxFolder->indexLocation() ) );
-  the_outboxFolder->open();
+  the_outboxFolder->open("kmkernel");
 
   the_sentFolder = the_folderMgr->findOrCreate(cfg->readEntry("sentFolder", I18N_NOOP("sent-mail")));
   if (the_sentFolder->canAccess() != 0) {
@@ -1422,7 +1424,7 @@ void KMKernel::initFolders(KConfig* cfg)
   the_draftsFolder->setSystemFolder( TRUE );
   if ( the_draftsFolder->userWhoField().isEmpty() )
     the_draftsFolder->setUserWhoField( QString::null );
-  the_draftsFolder->open();
+  the_draftsFolder->open("kmkernel");
 
   the_templatesFolder =
     the_folderMgr->findOrCreate( cfg->readEntry( "templatesFolder",
@@ -1433,7 +1435,7 @@ void KMKernel::initFolders(KConfig* cfg)
   the_templatesFolder->setSystemFolder( TRUE );
   if ( the_templatesFolder->userWhoField().isEmpty() )
     the_templatesFolder->setUserWhoField( QString::null );
-  the_templatesFolder->open();
+  the_templatesFolder->open("kmkernel");
 }
 
 
@@ -1462,6 +1464,9 @@ void KMKernel::init()
     kdDebug(5006) << k_funcinfo << "foldersPath (after transferMail): '" << foldersPath << "'" << endl;
   }
 
+  // moved up here because KMMessage::stripOffPrefixes is used below
+  KMMessage::readConfig();
+
   the_undoStack     = new UndoStack(20);
   the_folderMgr     = new KMFolderMgr(foldersPath);
   the_imapFolderMgr = new KMFolderMgr( KMFolderImap::cacheLocation(), KMImapDir);
@@ -1477,8 +1482,6 @@ void KMKernel::init()
   the_popFilterMgr     = new KMFilterMgr(true);
   the_filterActionDict = new KMFilterActionDict;
 
-  // moved up here because KMMessage::stripOffPrefixes is used below -ta
-  KMMessage::readConfig();
   initFolders(cfg);
   the_acctMgr->readConfig();
   the_filterMgr->readConfig();
@@ -1519,7 +1522,7 @@ void KMKernel::init()
   connect( the_searchFolderMgr, SIGNAL( folderRemoved(KMFolder*) ),
            this, SIGNAL( folderRemoved(KMFolder*) ) );
 
-  mBackgroundTasksTimer = new QTimer( this );
+  mBackgroundTasksTimer = new QTimer( this, "mBackgroundTasksTimer" );
   connect( mBackgroundTasksTimer, SIGNAL( timeout() ), this, SLOT( slotRunBackgroundTasks() ) );
 #ifdef DEBUG_SCHEDULER // for debugging, see jobscheduler.h
   mBackgroundTasksTimer->start( 10000, true ); // 10s minute, singleshot
@@ -1581,7 +1584,7 @@ void KMKernel::cleanupImapFolders()
     imapAcct = static_cast<KMAcctImap*>(acct);
     fld->setAccount(imapAcct);
     imapAcct->setImapFolder(fld);
-    fld->close();
+    fld->close( "kernel", true );
   }
   the_imapFolderMgr->quiet(false);
 
@@ -1612,7 +1615,7 @@ void KMKernel::cleanupImapFolders()
     cachedImapAcct = static_cast<KMAcctCachedImap*>(acct);
     cfld->setAccount(cachedImapAcct);
     cachedImapAcct->setImapFolder(cfld);
-    cfld->close();
+    cfld->close("kmkernel");
   }
   the_dimapFolderMgr->quiet( false );
 }
@@ -1676,7 +1679,7 @@ void KMKernel::cleanup(void)
 
   if (the_trashFolder) {
 
-    the_trashFolder->close(TRUE);
+    the_trashFolder->close("kmkernel", TRUE);
 
     if (config->readBoolEntry("empty-trash-on-exit", true))
     {
@@ -1695,7 +1698,7 @@ void KMKernel::cleanup(void)
   {
     folder = *folders.at(i);
     if (!folder || folder->isDir()) continue;
-    folder->close(TRUE);
+    folder->close("kmkernel", TRUE);
   }
   strList.clear();
   folders.clear();
@@ -1704,7 +1707,7 @@ void KMKernel::cleanup(void)
   {
     folder = *folders.at(i);
     if (!folder || folder->isDir()) continue;
-    folder->close(TRUE);
+    folder->close("kmkernel", TRUE);
   }
 
   delete the_msgIndex;
@@ -1952,6 +1955,15 @@ void KMKernel::slotShowConfigurationDialog()
              this, SLOT( slotConfigChanged() ) );
   }
 
+  if( KMKernel::getKMMainWidget() == 0 )
+  {
+    // ensure that there is a main widget available
+    // as parts of the configure dialog (identity) rely on this
+    // and this slot can be called when there is only a KMComposeWin showing
+    KMMainWin * win = new KMMainWin;
+    win->show();
+  }
+
   if( mConfigureDialog->isHidden() )
     mConfigureDialog->show();
   else
