@@ -121,6 +121,17 @@ void KMReaderMainWin::showMsg( const QString & encoding, KMMessage *msg )
   mMsg = msg;
   menuBar()->show();
   toolBar( "mainToolBar" )->show();
+
+  connect ( msg->parent(), SIGNAL( destroyed( QObject* ) ), this, SLOT( slotFolderRemoved( QObject* ) ) );
+
+}
+
+void KMReaderMainWin::slotFolderRemoved( QObject* folderPtr )
+{
+  assert(mMsg);
+  assert(folderPtr == mMsg->parent());
+  if( mMsg && folderPtr == mMsg->parent() )
+    mMsg->setParent( 0 );
 }
 
 //-----------------------------------------------------------------------------
@@ -132,13 +143,13 @@ void KMReaderMainWin::slotTrashMsg()
   KMMsgDict::instance()->getLocation( mMsg->getMsgSerNum(), &parent, &index );
   if ( parent && !parent->isTrash() ) {
     // open the folder (ref counted)
-    parent->open();
+    parent->open("trashmsg");
     KMMessage *msg = parent->getMsg( index );
     if (msg) {
       KMDeleteMsgCommand *command = new KMDeleteMsgCommand( parent, msg );
       command->start();
     }
-    parent->close();
+    parent->close("trashmsg");
   }
   close();
 }
