@@ -509,7 +509,10 @@ KMReaderWin::KMReaderWin(QWidget *aParent,
     mSelectEncodingAction( 0 ),
     mToggleFixFontAction( 0 ),
     mHtmlWriter( 0 ),
-    mSavedRelativePosition( 0 )
+    mSavedRelativePosition( 0 ),
+    updateReaderWinTimer( 0, "updateReaderWinTimer" ),
+    mResizeTimer( 0, "mResizeTimer" ),
+    mDelayedMarkTimer( 0, "mDelayedMarkTimer" )
 {
   mSplitterSizes << 180 << 100;
   mMimeTreeMode = 1;
@@ -636,13 +639,13 @@ void KMReaderWin::createActions( KActionCollection * ac ) {
   mSelectEncodingAction->setItems( encodings );
   mSelectEncodingAction->setCurrentItem( 0 );
 
-  mMailToComposeAction = new KAction( i18n("New Message To..."), 0, this,
-                                      SLOT(slotMailtoCompose()), ac,
+  mMailToComposeAction = new KAction( i18n("New Message To..."), "mail_new",
+                                      0, this, SLOT(slotMailtoCompose()), ac,
                                       "mailto_compose" );
-  mMailToReplyAction = new KAction( i18n("Reply To..."), 0, this,
-				    SLOT(slotMailtoReply()), ac,
+  mMailToReplyAction = new KAction( i18n("Reply To..."), "mail_reply",
+                                    0, this, SLOT(slotMailtoReply()), ac,
 				    "mailto_reply" );
-  mMailToForwardAction = new KAction( i18n("Forward To..."),
+  mMailToForwardAction = new KAction( i18n("Forward To..."), "mail_forward",
                                       0, this, SLOT(slotMailtoForward()), ac,
                                       "mailto_forward" );
   mAddAddrBookAction = new KAction( i18n("Add to Address Book"),
@@ -1096,7 +1099,7 @@ void KMReaderWin::setOverrideEncoding( const QString & encoding )
     }
     else {
       QStringList encodings = mSelectEncodingAction->items();
-      int i = 0;
+      uint i = 0;
       for ( QStringList::const_iterator it = encodings.begin(), end = encodings.end(); it != end; ++it, ++i ) {
         if ( KGlobal::charsets()->encodingForName( *it ) == encoding ) {
           mSelectEncodingAction->setCurrentItem( i );
@@ -1354,7 +1357,7 @@ void KMReaderWin::displayAboutPage()
 	     "<p style='margin-bottom: 0px'>&nbsp; &nbsp; The KMail Team</p>")
     .arg(KMAIL_VERSION) // KMail version
     .arg("help:/kmail/index.html") // KMail help:// URL
-    .arg("http://kmail.kde.org/") // KMail homepage URL
+    .arg("http://kontact.kde.org/kmail/") // KMail homepage URL
     .arg("1.8").arg("3.4"); // prior KMail and KDE version
 
   QString featureItems;
@@ -1407,7 +1410,7 @@ void KMReaderWin::updateReaderWin()
 
   htmlWriter()->reset();
 
-  KMFolder* folder;
+  KMFolder* folder = 0;
   if (message(&folder))
   {
     if ( mShowColorbar )
@@ -1504,7 +1507,14 @@ void KMReaderWin::parseMsg(KMMessage* aMsg)
 
   assert(aMsg!=0);
 
-  delete mRootNode;
+  aMsg->setIsBeingParsed( true );
+
+  if ( mRootNode && !mRootNode->processed() )
+  {
+    kdWarning() << "The root node is not yet processed! Danger!\n";
+    return;
+  } else
+    delete mRootNode;
   mRootNode = partNode::fromMessage( aMsg );
   const QCString mainCntTypeStr = mRootNode->typeString() + '/' + mRootNode->subTypeString();
 
@@ -1614,13 +1624,13 @@ kdDebug(5006) << "KMReaderWin  -  composing unencrypted message" << endl;
       unencryptedMessage->setParent( 0 );
       // because this did not work:
       /*
-      DwMessage dwMsg( DwString( aMsg->asString() ) );
+      DwMessage dwMsg( aMsg->asDwString() );
       dwMsg.Body() = DwBody( DwString( resultString.data() ) );
       dwMsg.Body().Parse();
       KMMessage* unencryptedMessage = new KMMessage( &dwMsg );
       */
-kdDebug(5006) << "KMReaderWin  -  resulting message:" << unencryptedMessage->asString() << endl;
-kdDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
+      //kdDebug(5006) << "KMReaderWin  -  resulting message:" << unencryptedMessage->asString() << endl;
+      kdDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
       aMsg->setUnencryptedMsg( unencryptedMessage );
       emitReplaceMsgByUnencryptedVersion = true;
     }
@@ -1642,6 +1652,8 @@ kdDebug(5006) << "KMReaderWin  -  attach unencrypted message to aMsg" << endl;
     showHideMimeTree( rootNodeCntType == DwMime::kTypeText &&
 		      rootNodeCntSubtype == DwMime::kSubtypePlain );
   }
+
+  aMsg->setIsBeingParsed( false );
 }
 
 
@@ -1670,21 +1682,10 @@ QString KMReaderWin::writeMessagePartToTempFile( KMMessagePart* aMsgPart,
     fileName = aMsgPart->name();
 
   //--- Sven's save attachments to /tmp start ---
-  KTempFile *tempFile = new KTempFile( QString::null,
-                                       "." + QString::number( aPartNum ) );
-  tempFile->setAutoDelete( true );
-  QString fname = tempFile->name();
-  delete tempFile;
+  QString fname = createTempDir( QString::number( aPartNum ) );
+  if ( fname.isEmpty() )
+    return QString();
 
-  if( ::access( QFile::encodeName( fname ), W_OK ) != 0 )
-    // Not there or not writable
-    if( ::mkdir( QFile::encodeName( fname ), 0 ) != 0
-        || ::chmod( QFile::encodeName( fname ), S_IRWXU ) != 0 )
-      return QString::null; //failed create
-
-  assert( !fname.isNull() );
-
-  mTempDirs.append( fname );
   // strip off a leading path
   int slashPos = fileName.findRev( '/' );
   if( -1 != slashPos )
@@ -1710,6 +1711,24 @@ QString KMReaderWin::writeMessagePartToTempFile( KMMessagePart* aMsgPart,
   return fname;
 }
 
+QString KMReaderWin::createTempDir( const QString &param )
+{
+  KTempFile *tempFile = new KTempFile( QString::null, "." + param );
+  tempFile->setAutoDelete( true );
+  QString fname = tempFile->name();
+  delete tempFile;
+
+  if( ::access( QFile::encodeName( fname ), W_OK ) != 0 )
+    // Not there or not writable
+    if( ::mkdir( QFile::encodeName( fname ), 0 ) != 0
+        || ::chmod( QFile::encodeName( fname ), S_IRWXU ) != 0 )
+      return QString::null; //failed create
+
+  assert( !fname.isNull() );
+
+  mTempDirs.append( fname );
+  return fname;
+}
 
 //-----------------------------------------------------------------------------
 void KMReaderWin::showVCard( KMMessagePart * msgPart ) {
@@ -2080,16 +2099,18 @@ void KMReaderWin::setMsgPart( KMMessagePart* aMsgPart, bool aHTML,
   } else {
     htmlWriter()->begin( mCSSHelper->cssDefinitions( isFixedFont() ) );
     htmlWriter()->queue( mCSSHelper->htmlHead( isFixedFont() ) );
+    htmlWriter()->queue( "<pre>" );
 
     QString str = aMsgPart->bodyDecoded();
     // A QString cannot handle binary data. So if it's shorter than the
     // attachment, we assume the attachment is binary:
     if( str.length() < (unsigned) aMsgPart->decodedSize() ) {
-      str += QString::fromLatin1("\n") + i18n("[KMail: Attachment contains binary data. Trying to show first character.]",
+      str.prepend( i18n("[KMail: Attachment contains binary data. Trying to show first character.]",
           "[KMail: Attachment contains binary data. Trying to show first %n characters.]",
-          str.length());
+          str.length()) + QChar('\n') );
     }
-    htmlWriter()->write( QStyleSheet::escape( str ) );
+    htmlWriter()->queue( QStyleSheet::escape( str ) );
+    htmlWriter()->queue( "</pre>" );
     htmlWriter()->queue("</body></html>");
     htmlWriter()->flush();
     mMainWindow->setCaption(i18n("View Attachment: %1").arg(pname));
