@@ -1,8 +1,6 @@
 /*
-    knaccountmanager.cpp
-
     KNode, the KDE newsreader
-    Copyright (c) 1999-2004 the KNode authors.
+    Copyright (c) 1999-2005 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -11,7 +9,7 @@
     (at your option) any later version.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #include <stdlib.h>
@@ -23,6 +21,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
+#include <kwallet.h>
 
 #include "kngroupmanager.h"
 #include "knnntpaccount.h"
@@ -32,16 +31,17 @@
 #include "knaccountmanager.h"
 #include "knfoldermanager.h"
 
+KWallet::Wallet* KNAccountManager::mWallet = 0;
+bool KNAccountManager::mWalletOpenFailed = false;
 
 KNAccountManager::KNAccountManager(KNGroupManager *gm, QObject * parent, const char * name)
-  : QObject(parent, name), gManager(gm), c_urrentAccount(0)
+  : QObject(parent, name), gManager(gm), c_urrentAccount(0),
+  mAsyncOpening( false )
 {
-  accList=new QPtrList<KNNntpAccount>;
-  accList->setAutoDelete(true);
-  s_mtp=new KNServerInfo();
+  s_mtp = new KNServerInfo();
   s_mtp->setType(KNServerInfo::STsmtp);
   s_mtp->setId(0);
-  KConfig *conf=knGlobals.config();
+  KConfig *conf = knGlobals.config();
   conf->setGroup("MAILSERVER");
   s_mtp->readConf(conf);
 
@@ -51,15 +51,21 @@ KNAccountManager::KNAccountManager(KNGroupManager *gm, QObject * parent, const c
 
 KNAccountManager::~KNAccountManager()
 {
-  delete accList;
+  QValueList<KNNntpAccount*>::Iterator it;
+  for ( it = mAccounts.begin(); it != mAccounts.end(); ++it )
+    delete (*it);
+  mAccounts.clear();
   delete s_mtp;
+  delete mWallet;
+  mWallet = 0;
 }
 
 
 void KNAccountManager::prepareShutdown()
 {
-  for(KNNntpAccount *a=accList->first(); a; a=accList->next())
-    a->saveInfo();
+  QValueList<KNNntpAccount*>::Iterator it;
+  for ( it = mAccounts.begin(); it != mAccounts.end(); ++it )
+    (*it)->saveInfo();
 }
 
 
@@ -76,9 +82,9 @@ void KNAccountManager::loadAccounts()
 
   QStringList::Iterator it;
   for(it = entries.begin(); it != entries.end(); ++it) {
-    a=new KNNntpAccount();
-    if (a->readInfo(dir+(*it)+"/info")) {
-      accList->append(a);
+    a = new KNNntpAccount();
+    if (a->readInfo(dir+(*it) + "/info")) {
+      mAccounts.append(a);
       gManager->loadGroups(a);
       emit accountAdded(a);
     } else {
@@ -89,25 +95,21 @@ void KNAccountManager::loadAccounts()
 }
 
 
-KNNntpAccount* KNAccountManager::account(int i)
+KNNntpAccount* KNAccountManager::account( int id )
 {
-  KNNntpAccount *ret=0;
-  if(i>0)
-  {
-    for(KNNntpAccount *a=accList->first(); a; a=accList->next()) {
-      if(a->id()==i) {
-        ret=a;
-        break;
-      }
-    }
-  }
-  return ret;
+  if ( id <= 0 )
+    return 0;
+  QValueList<KNNntpAccount*>::ConstIterator it;
+  for ( it = mAccounts.begin(); it != mAccounts.end(); ++it )
+    if ( (*it)->id() == id )
+      return *it;
+  return 0;
 }
 
 
 void KNAccountManager::setCurrentAccount(KNNntpAccount *a)
 {
-  c_urrentAccount=a;
+  c_urrentAccount = a;
 }
 
 
@@ -132,7 +134,7 @@ bool KNAccountManager::newAccount(KNNntpAccount *a)
 
   dir = locateLocal("data",QString("knode/nntp.%1/").arg(a->id()));
   if (!dir.isNull()) {
-    accList->append(a);
+    mAccounts.append(a);
     emit(accountAdded(a));
     return true;
   } else {
@@ -149,23 +151,20 @@ bool KNAccountManager::removeAccount(KNNntpAccount *a)
   if(!a) a=c_urrentAccount;
   if(!a) return false;
 
-  QPtrList<KNGroup> *lst;
+  QValueList<KNGroup*> lst;
   if(knGlobals.folderManager()->unsentForAccount(a->id()) > 0) {
     KMessageBox::sorry(knGlobals.topWidget, i18n("This account cannot be deleted since there are some unsent messages for it."));
   }
   else if(KMessageBox::warningContinueCancel(knGlobals.topWidget, i18n("Do you really want to delete this account?"),"",KGuiItem(i18n("&Delete"),"editdelete"))==KMessageBox::Continue) {
-    lst=new QPtrList<KNGroup>;
-    lst->setAutoDelete(false);
-    gManager->getGroupsOfAccount(a, lst);
-    for(KNGroup *g=lst->first(); g; g=lst->next()) {
-      if(g->isLocked()) {
+    lst = gManager->groupsOfAccount( a );
+    for ( QValueList<KNGroup*>::Iterator it = lst.begin(); it != lst.end(); ++it ) {
+      if ( (*it)->isLocked() ) {
         KMessageBox::sorry(knGlobals.topWidget, i18n("At least one group of this account is currently in use.\nThe account cannot be deleted at the moment."));
         return false;
       }
     }
-    for(KNGroup *g=lst->first(); g; g=lst->next())
-      gManager->unsubscribeGroup(g);
-    delete lst;
+    for ( QValueList<KNGroup*>::Iterator it = lst.begin(); it != lst.end(); ++it )
+      gManager->unsubscribeGroup( (*it) );
 
     QDir dir(a->path());
     if (dir.exists()) {
@@ -184,7 +183,7 @@ bool KNAccountManager::removeAccount(KNNntpAccount *a)
     if(c_urrentAccount==a) setCurrentAccount(0);
 
     emit(accountRemoved(a));
-    accList->removeRef(a);      // finally delete a
+    mAccounts.remove( a );  // finally delete a
     return true;
   }
 
@@ -211,15 +210,96 @@ void KNAccountManager::accountRenamed(KNNntpAccount *a)
 }
 
 
+KNNntpAccount* KNAccountManager::first() const
+{
+  if ( mAccounts.isEmpty() )
+    return 0;
+  return mAccounts.first();
+}
+
+
+void KNAccountManager::loadPasswordsAsync()
+{
+  if ( !mWallet && !mWalletOpenFailed ) {
+    if ( knGlobals.top )
+      mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
+                                    knGlobals.topWidget->topLevelWidget()->winId(),
+                                    Wallet::Asynchronous );
+    else
+      mWallet = Wallet::openWallet( Wallet::NetworkWallet(), 0, Wallet::Asynchronous );
+    if ( mWallet ) {
+      connect( mWallet, SIGNAL(walletOpened(bool)), SLOT(slotWalletOpened(bool)) );
+      mAsyncOpening = true;
+    }
+    else {
+      mWalletOpenFailed = true;
+      loadPasswords();
+    }
+    return;
+  }
+  if ( mWallet && !mAsyncOpening )
+    loadPasswords();
+}
+
+
 void KNAccountManager::loadPasswords()
 {
-  KNNntpAccount *a;
-  for (a = accList->first(); a; a = accList->next())
-    a->readPassword();
+  s_mtp->readPassword();
+  QValueList<KNNntpAccount*>::Iterator it;
+  for ( it = mAccounts.begin(); it != mAccounts.end(); ++it )
+    (*it)->readPassword();
+  emit passwordsChanged();
+}
+
+
+KWallet::Wallet* KNAccountManager::wallet()
+{
+  if ( mWallet && mWallet->isOpen() )
+    return mWallet;
+
+  if ( !Wallet::isEnabled() || mWalletOpenFailed )
+    return 0;
+
+  delete mWallet;
+  if ( knGlobals.top )
+    mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
+                                  knGlobals.topWidget->topLevelWidget()->winId() );
+  else
+    mWallet = Wallet::openWallet( Wallet::NetworkWallet() );
+
+  if ( !mWallet ) {
+    mWalletOpenFailed = true;
+    return 0;
+  }
+
+  prepareWallet();
+  return mWallet;
+}
+
+
+void KNAccountManager::prepareWallet()
+{
+  if ( !mWallet )
+    return;
+  if ( !mWallet->hasFolder("knode") )
+    mWallet->createFolder( "knode" );
+  mWallet->setFolder( "knode" );
+}
+
+
+void KNAccountManager::slotWalletOpened( bool success )
+{
+  mAsyncOpening = false;
+  if ( !success ) {
+    mWalletOpenFailed = true;
+    delete mWallet;
+    mWallet = 0;
+  } else {
+    prepareWallet();
+  }
+  loadPasswords();
 }
 
 //--------------------------------
 
 #include "knaccountmanager.moc"
-
-// kate: space-indent on; indent-width 2;
