@@ -1,8 +1,6 @@
 /*
-    kncomposer.cpp
-
     KNode, the KDE newsreader
-    Copyright (c) 1999-2004 the KNode authors.
+    Copyright (c) 1999-2005 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -11,7 +9,7 @@
     (at your option) any later version.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #include <qheader.h>
@@ -116,17 +114,17 @@ void KNLineEdit::keyPressEvent(QKeyEvent *e)
     if ((e->key() == Key_Enter || e->key() == Key_Return) &&
         !completionBox()->isVisible())
     {
-        composerView->focusNextPrevEdit(this,TRUE);
+        composerView->focusNextPrevEdit( this, true );
       return;
     }
     if (e->key() == Key_Up)
     {
-        composerView->focusNextPrevEdit(this,FALSE); // Go up
+        composerView->focusNextPrevEdit( this, false ); // Go up
       return;
     }
     if (e->key() == Key_Down)
     {
-        composerView->focusNextPrevEdit(this,TRUE); // Go down
+        composerView->focusNextPrevEdit( this, true ); // Go down
       return;
     }
     // ---sven's Return is same Tab and arrow key navigation end ---
@@ -173,7 +171,6 @@ KNComposer::KNComposer(KNLocalArticle *a, const QString &text, const QString &si
 {
     mSpellingFilter = 0;
     spellLineEdit = false;
-    d_elAttList.setAutoDelete(true);
     m_listAction.setAutoDelete( true );
 
   if(knGlobals.instance)
@@ -401,6 +398,9 @@ KNComposer::~KNComposer()
     delete e_ditorTempfile;
   }
 
+  for ( QValueList<KNAttachment*>::Iterator it = mDeletedAttachments.begin(); it != mDeletedAttachments.end(); ++it )
+    delete (*it);
+
   KConfig *conf = knGlobals.config();
   conf->setGroup("composerWindow_options");
   saveMainWindowSettings(conf);
@@ -779,10 +779,9 @@ bool KNComposer::applyChanges()
     }
   }
 
-  if(!d_elAttList.isEmpty())
-      for(KNAttachment *a=d_elAttList.first(); a; a=d_elAttList.next())
-        if(a->isAttached())
-          a->detach(a_rticle);
+  for ( QValueList<KNAttachment*>::Iterator it = mDeletedAttachments.begin(); it != mDeletedAttachments.end(); ++it )
+    if ( (*it)->isAttached() )
+      (*it)->detach( a_rticle );
 
   text=a_rticle->textContent();
 
@@ -1109,7 +1108,7 @@ void KNComposer::slotRemoveAttachment()
   if(v_iew->a_ttView->currentItem()) {
     AttachmentViewItem *it=static_cast<AttachmentViewItem*>(v_iew->a_ttView->currentItem());
     if(it->attachment->isAttached()) {
-      d_elAttList.append(it->attachment);
+      mDeletedAttachments.append( it->attachment );
       it->attachment=0;
     }
     delete it;
@@ -1835,26 +1834,33 @@ KNComposer::ComposerView::~ComposerView()
 
 void KNComposer::ComposerView::focusNextPrevEdit(const QWidget* aCur, bool aNext)
 {
-  QWidget* cur;
+  QValueList<QWidget*>::Iterator it;
 
-  if (!aCur)
-  {
-    cur=mEdtList.last();
+  if ( !aCur ) {
+    it = --( mEdtList.end() );
+  } else {
+    for ( QValueList<QWidget*>::Iterator it2 = mEdtList.begin(); it2 != mEdtList.end(); ++it2 ) {
+      if ( (*it2) == aCur ) {
+        it = it2;
+        break;
+      }
+    }
+    if ( it == mEdtList.end() )
+      return;
+    if ( aNext )
+      ++it;
+    else {
+      if ( it != mEdtList.begin() )
+        --it;
+      else
+        return;
+    }
   }
-  else
-  {
-    for (cur=mEdtList.first(); aCur!=cur && cur; cur=mEdtList.next())
-      ;
-    if (!cur) return;
-    if (aNext) cur = mEdtList.next();
-    else cur = mEdtList.prev();
-  }
-  if (cur)
-  {
-      if ( cur->isVisible() )
-          cur->setFocus();
-  }
-  else if (aNext) e_dit->setFocus();
+  if ( it != mEdtList.end() ) {
+    if ( (*it)->isVisible() )
+      (*it)->setFocus();
+  } else if ( aNext )
+    e_dit->setFocus();
 }
 
 
@@ -2018,7 +2024,7 @@ bool KNComposer::Editor::eventFilter(QObject*o, QEvent* e)
     {
       deselect();
       m_composerView->focusNextPrevEdit(0, false); //take me up
-      return TRUE;
+      return true;
     }
     // ---sven's Arrow key navigation end ---
 
@@ -2026,7 +2032,7 @@ bool KNComposer::Editor::eventFilter(QObject*o, QEvent* e)
     {
       deselect();
       m_composerView->focusNextPrevEdit(0, false);
-      return TRUE;
+      return true;
     }
   } else if ( e->type() == QEvent::ContextMenu ) {
     QContextMenuEvent *event = (QContextMenuEvent*) e;
@@ -2625,9 +2631,9 @@ void KNComposer::AttachmentPropertiesDlg::accept()
     return;
   }
   else if(n_onTextAsText && m_imeType->text().find("text/", 0, false)!=-1 &&
-       KMessageBox::warningYesNo(this,
+       KMessageBox::warningContinueCancel(this,
        i18n("You have changed the mime-type of this non-textual attachment\nto text. This might cause an error while loading or encoding the file.\nProceed?")
-       ) == KMessageBox::No) return;
+       ) == KMessageBox::Cancel) return;
 
   KDialogBase::accept();
 }
