@@ -167,28 +167,31 @@ KNote::KNote( QDomDocument buildDoc, Journal *j, QWidget *parent, const char *na
     KXMLGUIFactory factory( &builder, this );
     factory.addClient( this );
 
-    m_menu = static_cast<KPopupMenu*>(factory.container( "note_context", this ));
-    m_edit_menu = static_cast<KPopupMenu*>(factory.container( "note_edit", this ));
-    m_tool = static_cast<KToolBar*>(factory.container( "note_tool", this ));
-    m_tool->setIconSize( 10 );
-    m_tool->setFixedHeight( 16 );
-    m_tool->setIconText( KToolBar::IconOnly );
+    m_menu = dynamic_cast<KPopupMenu*>(factory.container( "note_context", this ));
+    m_edit_menu = dynamic_cast<KPopupMenu*>(factory.container( "note_edit", this ));
+    m_tool = dynamic_cast<KToolBar*>(factory.container( "note_tool", this ));
 
-    // if there was just a way of making KComboBox adhere the toolbar height...
-    QObjectList *list = m_tool->queryList( "KComboBox" );
-    QObjectListIt it( *list );
-    while ( it.current() != 0 )
-    {
-        KComboBox *combo = (KComboBox *)it.current();
-        QFont font = combo->font();
-        font.setPointSize( 7 );
-        combo->setFont( font );
-        combo->setFixedHeight( 14 );
-        ++it;
+    if ( m_tool ) {
+      m_tool->setIconSize( 10 );
+      m_tool->setFixedHeight( 16 );
+      m_tool->setIconText( KToolBar::IconOnly );
+
+      // if there was just a way of making KComboBox adhere the toolbar height...
+      QObjectList *list = m_tool->queryList( "KComboBox" );
+      QObjectListIt it( *list );
+      while ( it.current() != 0 )
+      {
+          KComboBox *combo = (KComboBox *)it.current();
+          QFont font = combo->font();
+          font.setPointSize( 7 );
+          combo->setFont( font );
+          combo->setFixedHeight( 14 );
+          ++it;
+      }
+      delete list;
+
+      m_tool->hide();
     }
-    delete list;
-
-    m_tool->hide();
 
     setFocusProxy( m_editor );
 
@@ -372,7 +375,7 @@ KNote::~KNote()
 void KNote::slotKill( bool force )
 {
     if ( !force &&
-         KMessageBox::warningContinueCancel( this, 
+         KMessageBox::warningContinueCancel( this,
              i18n("<qt>Do you really want to delete note <b>%1</b>?</qt>").arg( m_label->text() ),
              i18n("Confirm Delete"), KGuiItem( i18n("&Delete"), "editdelete" ),
              "ConfirmDeleteNote"
@@ -413,7 +416,10 @@ void KNote::saveData()
 void KNote::saveConfig() const
 {
     m_config->setWidth( width() );
-    m_config->setHeight( height() - (m_tool->isHidden() ? 0 : m_tool->height()) );
+    if ( m_tool )
+      m_config->setHeight( height() - (m_tool->isHidden() ? 0 : m_tool->height()) );
+    else
+      m_config->setHeight( 0 );
     m_config->setPosition( pos() );
 
     NETWinInfo wm_client( qt_xdisplay(), winId(), qt_xrootwin(), NET::WMDesktop );
@@ -474,6 +480,80 @@ void KNote::setText( const QString& text )
     saveData();
 }
 
+QColor KNote::fgColor() const
+{
+    return m_config->fgColor();
+}
+
+QColor KNote::bgColor() const
+{
+    return m_config->bgColor();
+}
+
+void KNote::setColor( const QColor& fg, const QColor& bg )
+{
+    m_journal->setCustomProperty( "KNotes", "FgColor", fg.name() );
+    m_journal->setCustomProperty( "KNotes", "BgColor", bg.name() );
+    m_config->setFgColor( fg );
+    m_config->setBgColor( bg );
+
+    m_journal->updated();  // because setCustomProperty() doesn't call it!!
+    emit sigDataChanged();
+    m_config->writeConfig();
+
+    QPalette newpalette = palette();
+    newpalette.setColor( QColorGroup::Background, bg );
+    newpalette.setColor( QColorGroup::Foreground, fg );
+    newpalette.setColor( QColorGroup::Base,       bg ); // text background
+    newpalette.setColor( QColorGroup::Text,       fg ); // text color
+    newpalette.setColor( QColorGroup::Button,     bg );
+    newpalette.setColor( QColorGroup::ButtonText, fg );
+
+//    newpalette.setColor( QColorGroup::Highlight,  bg );
+//    newpalette.setColor( QColorGroup::HighlightedText, fg );
+
+    // the shadow
+    newpalette.setColor( QColorGroup::Midlight, bg.light(150) );
+    newpalette.setColor( QColorGroup::Shadow, bg.dark(116) );
+    newpalette.setColor( QColorGroup::Light, bg.light(180) );
+    if ( s_ppOffset )
+        newpalette.setColor( QColorGroup::Dark, bg.dark(200) );
+    else
+        newpalette.setColor( QColorGroup::Dark, bg.dark(108) );
+    setPalette( newpalette );
+
+    // set the text color
+    m_editor->setTextColor( fg );
+
+    // set the background color or gradient
+    updateBackground();
+
+    // set darker value for the hide button...
+    QPalette darker = palette();
+    darker.setColor( QColorGroup::Button, bg.dark(116) );
+    m_button->setPalette( darker );
+
+    // update the icon color
+    KIconEffect effect;
+    QPixmap icon = effect.apply( kapp->icon(), KIconEffect::Colorize, 1, bg, false );
+    QPixmap miniIcon = effect.apply( kapp->miniIcon(), KIconEffect::Colorize, 1, bg, false );
+    KWin::setIcons( winId(), icon, miniIcon );
+
+    // set the color for the selection used to highlight the find stuff
+    QColor sel = palette().color( QPalette::Active, QColorGroup::Base ).dark();
+    if ( sel == Qt::black )
+        sel = palette().color( QPalette::Active, QColorGroup::Base ).light();
+
+    m_editor->setSelectionAttributes( 1, sel, true );
+
+    // update the color of the fold
+    createFold();
+
+    // update the color of the title
+    updateFocus();
+    emit sigColorChanged();
+}
+
 void KNote::find( const QString& pattern, long options )
 {
     delete m_find;
@@ -926,61 +1006,6 @@ void KNote::toDesktop( int desktop )
         KWin::setOnDesktop( winId(), desktop );
 }
 
-void KNote::setColor( const QColor &fg, const QColor &bg )
-{
-    QPalette newpalette = palette();
-    newpalette.setColor( QColorGroup::Background, bg );
-    newpalette.setColor( QColorGroup::Foreground, fg );
-    newpalette.setColor( QColorGroup::Base,       bg ); // text background
-    newpalette.setColor( QColorGroup::Text,       fg ); // text color
-    newpalette.setColor( QColorGroup::Button,     bg );
-    newpalette.setColor( QColorGroup::ButtonText, fg );
-    
-//    newpalette.setColor( QColorGroup::Highlight,  bg );
-//    newpalette.setColor( QColorGroup::HighlightedText, fg );
-
-    // the shadow
-    newpalette.setColor( QColorGroup::Midlight, bg.light(150) );
-    newpalette.setColor( QColorGroup::Shadow, bg.dark(116) );
-    newpalette.setColor( QColorGroup::Light, bg.light(180) );
-    if ( s_ppOffset )
-        newpalette.setColor( QColorGroup::Dark, bg.dark(200) );
-    else
-        newpalette.setColor( QColorGroup::Dark, bg.dark(108) );
-    setPalette( newpalette );
-
-    // set the text color
-    m_editor->setTextColor( fg );
-
-    // set the background color or gradient
-    updateBackground();
-
-    // set darker value for the hide button...
-    QPalette darker = palette();
-    darker.setColor( QColorGroup::Button, bg.dark(116) );
-    m_button->setPalette( darker );
-
-    // update the icon color
-    KIconEffect effect;
-    QPixmap icon = effect.apply( kapp->icon(), KIconEffect::Colorize, 1, bg, false );
-    QPixmap miniIcon = effect.apply( kapp->miniIcon(), KIconEffect::Colorize, 1, bg, false );
-    KWin::setIcons( winId(), icon, miniIcon );
-
-    // set the color for the selection used to highlight the find stuff
-    QColor sel = palette().color( QPalette::Active, QColorGroup::Base ).dark();
-    if ( sel == Qt::black )
-        sel = palette().color( QPalette::Active, QColorGroup::Base ).light();
-
-    m_editor->setSelectionAttributes( 1, sel, true );
-
-    // update the color of the fold
-    createFold();
-
-    // update the color of the title
-    updateFocus();
-    emit sigColorChanged();
-}
-
 void KNote::createFold()
 {
     QPixmap fold( 15, 15 );
@@ -1014,13 +1039,13 @@ void KNote::updateFocus()
 
         if ( !m_editor->isReadOnly() )
         {
-            if ( m_tool->isHidden() && m_editor->textFormat() == QTextEdit::RichText )
+            if ( m_tool && m_tool->isHidden() && m_editor->textFormat() == QTextEdit::RichText )
             {
                 m_tool->show();
                 setGeometry( x(), y(), width(), height() + m_tool->height() );
             }
         }
-        else if ( !m_tool->isHidden() )
+        else if ( m_tool && !m_tool->isHidden() )
         {
             m_tool->hide();
             setGeometry( x(), y(), width(), height() - m_tool->height() );
@@ -1034,7 +1059,7 @@ void KNote::updateFocus()
         m_button->hide();
         m_editor->cornerWidget()->hide();
 
-        if ( !m_tool->isHidden() )
+        if ( m_tool && !m_tool->isHidden() )
         {
             m_tool->hide();
             setGeometry( x(), y(), width(), height() - m_tool->height() );
@@ -1170,22 +1195,24 @@ void KNote::updateLayout()
         QPoint( contentsRect().x(),
                 contentsRect().y() + headerHeight + s_ppOffset ),
         QPoint( contentsRect().right(),
-                contentsRect().bottom() - (m_tool->isHidden() ? 0 : m_tool->height()) )
+                contentsRect().bottom() - ( m_tool ? (m_tool->isHidden() ? 0 : m_tool->height()) : 0 ) )
     ) );
 
-    m_tool->setGeometry(
-        contentsRect().x(),
-        contentsRect().bottom() - m_tool->height() + 1,
-        contentsRect().width(),
-        m_tool->height()
-    );
+    if( m_tool ) {
+      m_tool->setGeometry(
+          contentsRect().x(),
+          contentsRect().bottom() - m_tool->height() + 1,
+          contentsRect().width(),
+          m_tool->height()
+      );
+    }
 
     if ( s_ppOffset )
         m_fold->move( width() - 15, height() - 15 );
 
     setMinimumSize(
         m_editor->cornerWidget()->width() + margin*2,
-        headerHeight + s_ppOffset + (m_tool->isHidden() ? 0 : m_tool->height()) +
+        headerHeight + s_ppOffset + ( m_tool ? (m_tool->isHidden() ? 0 : m_tool->height() ) : 0 ) +
                 m_editor->cornerWidget()->height() + margin*2
     );
 
@@ -1243,11 +1270,7 @@ void KNote::dropEvent( QDropEvent *e )
 
     QColor bg;
     if ( KColorDrag::decode( e, bg ) )
-    {
         setColor( paletteForegroundColor(), bg );
-        m_journal->setCustomProperty( "KNotes", "BgColor", bg.name() );
-        m_config->setBgColor( bg );
-    }
 }
 
 bool KNote::focusNextPrevChild( bool )
