@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef NEWSTICKER_PLUGIN_H
@@ -33,9 +33,8 @@ class NewsTickerPlugin : public Kontact::Plugin
 
     virtual Kontact::Summary *createSummaryWidget( QWidget* parentWidget );
 
-    virtual bool showInSideBar() const { return false; }
   protected:
-    virtual KParts::Part* createPart() { return 0L; }
+    virtual KParts::ReadOnlyPart* createPart() { return 0L; }
 };
 
 #endif
