@@ -8,7 +8,6 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -16,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -25,6 +24,7 @@
 
 #include <qtooltip.h>
 #include <qframe.h>
+#include <qguardedptr.h>
 #include <qpixmap.h>
 #include <qlayout.h>
 #include <qwidgetstack.h>
@@ -37,8 +37,8 @@
 #include <kmessagebox.h>
 #include <kinputdialog.h>
 #include <kio/netaccess.h>
+#include <kabc/addressee.h>
 
-#include <libkdepim/categoryselectdialog.h>
 #include <libkdepim/designerfields.h>
 #include <libkdepim/embeddedurlpage.h>
 
@@ -52,14 +52,14 @@
 #include "koeditorattachments.h"
 #include "koeditoralarms.h"
 #include "urihandler.h"
-
 #include "koincidenceeditor.h"
+#include "templatemanagementdialog.h"
 
 KOIncidenceEditor::KOIncidenceEditor( const QString &caption,
                                       Calendar *calendar, QWidget *parent )
-  : KDialogBase( Tabbed, caption, Ok | Apply | Cancel | Default | User1, Ok,
+  : KDialogBase( Tabbed, caption, Ok | Apply | Cancel | Default, Ok,
                  parent, 0, false, false ),
-    mDetails( 0 ), mAttachments( 0 ), mAlarms( 0 )
+    mDetails( 0 ), mAttachments( 0 )
 {
   // Set this to be the group leader for all subdialogs - this means
   // modal subdialogs will only affect this dialog, not the other windows
@@ -67,39 +67,19 @@ KOIncidenceEditor::KOIncidenceEditor( const QString &caption,
 
   mCalendar = calendar;
 
-  setButtonText( Default, i18n("Load &Template...") );
-  setButtonWhatsThis( Default,
-                      i18n("Allows you to load a pre-saved "
-                           "template for the event. You "
-                           "can save this event or to-do as a "
-                           "template by clicking 'Save as Template...'.") );
-
-  QString saveTemplateText;
   if ( KOPrefs::instance()->mCompactDialogs ) {
-    showButton( User1, false );
     showButton( Apply, false );
+    showButton( Default, false );
   } else {
-    saveTemplateText = i18n("&Save as Template...");
+    setButtonText( Default, i18n("&Templates...") );
   }
-  setButtonText( User1, saveTemplateText );
-  setButtonWhatsThis( User1,
-                      i18n("Allows you to save the current settings as a template "
-                           "which can later be loaded for other events.") );
 
-  mCategoryDialog = new KPIM::CategorySelectDialog( KOPrefs::instance(), this );
-  KOGlobals::fitDialogToScreen( mCategoryDialog );
-
-  connect( mCategoryDialog, SIGNAL( editCategories() ),
-           SIGNAL( editCategories() ) );
-
-  connect( this, SIGNAL( defaultClicked() ), SLOT( slotLoadTemplate() ) );
-  connect( this, SIGNAL( user1Clicked() ), SLOT( slotSaveTemplate() ) );
+  connect( this, SIGNAL( defaultClicked() ), SLOT( slotManageTemplates() ) );
   connect( this, SIGNAL( finished() ), SLOT( delayedDestruct() ) );
 }
 
 KOIncidenceEditor::~KOIncidenceEditor()
 {
-  delete mCategoryDialog;
 }
 
 void KOIncidenceEditor::setupAttendeesTab()
@@ -131,16 +111,6 @@ void KOIncidenceEditor::setupAttachmentsTab()
   topLayout->addWidget( mAttachments );
 }
 
-void KOIncidenceEditor::setupAlarmsTab()
-{
-  QFrame *topFrame = addPage( i18n("Re&minders") );
-
-  QBoxLayout *topLayout = new QVBoxLayout( topFrame );
-
-  mAlarms = new KOEditorAlarms( spacingHint(), topFrame );
-  topLayout->addWidget( mAlarms );
-}
-
 void KOIncidenceEditor::slotApply()
 {
   processInput();
@@ -148,12 +118,15 @@ void KOIncidenceEditor::slotApply()
 
 void KOIncidenceEditor::slotOk()
 {
-  if ( processInput() ) accept();
+  // "this" can be deleted before processInput() returns (processInput() opens 
+  // a non-modal dialog when Kolab is used). So accept should only be executed
+  // when "this" is still valid
+  QGuardedPtr<QWidget> ptr( this );
+  if ( processInput() && ptr ) accept();
 }
 
 void KOIncidenceEditor::updateCategoryConfig()
 {
-  mCategoryDialog->updateCategoryConfig();
 }
 
 void KOIncidenceEditor::slotCancel()
@@ -180,60 +153,19 @@ void KOIncidenceEditor::cancelRemovedAttendees( Incidence *incidence )
 
 }
 
-void KOIncidenceEditor::slotLoadTemplate()
+void KOIncidenceEditor::slotManageTemplates()
 {
-  kdDebug(5850) << "KOIncidenceEditor::loadTemplate()" << endl;
-}
+  kdDebug(5850) << "KOIncidenceEditor::manageTemplates()" << endl;
 
-void KOIncidenceEditor::slotSaveTemplate()
-{
-  kdDebug(5850) << "KOIncidenceEditor::saveTemplate()" << endl;
-  QString tp = type();
-  QStringList templates;
-
-  if ( tp == "Event" ) {
-    templates = KOPrefs::instance()->mEventTemplates;
-  } else if( tp == "ToDo" ) {
-    templates = KOPrefs::instance()->mTodoTemplates;
-  } else if ( tp == "Journal" ) {
-    templates = KOPrefs::instance()->mJournalTemplates;
-  }
-  bool ok = false;
-  QString templateName = KInputDialog::getItem( i18n("Save Template"),
-      i18n("Please enter a name for the template:"), templates,
-      -1, true, &ok, this );
-  if ( ok && templateName.isEmpty() ) {
-    KMessageBox::error( this, i18n("You did not give a valid template name, "
-                                   "no template will be saved") );
-    ok = false;
-  }
-
-  if ( ok && templates.contains( templateName ) ) {
-    int res = KMessageBox::warningYesNo( this,
-                                         i18n("The selected template "
-                                              "already exists. Overwrite it?"),
-                                         i18n("Template Already Exists") );
-    if ( res == KMessageBox::No ) {
-      ok = false;
-    }
-  }
-
-  if ( ok ) {
-    saveTemplate( templateName );
-
-    // Add template to list of existing templates
-    if ( !templates.contains( templateName ) ) {
-      templates.append( templateName );
-      if ( tp == "Event" ) {
-        KOPrefs::instance()->mEventTemplates = templates;
-      } else if ( tp == "ToDo" ) {
-        KOPrefs::instance()->mTodoTemplates = templates;
-      } else if ( tp == "Journal" ) {
-        KOPrefs::instance()->mJournalTemplates = templates;
-      }
-    }
-
-  }
+  TemplateManagementDialog * const d = new TemplateManagementDialog( this, templates() );
+  connect( d, SIGNAL( loadTemplate( const QString& ) ),
+           this, SLOT( slotLoadTemplate( const QString& ) ) );
+  connect( d, SIGNAL( templatesChanged( const QStringList& ) ),
+           this, SLOT( slotTemplatesChanged( const QStringList& ) ) );
+  connect( d, SIGNAL( saveTemplate( const QString& ) ),
+           this, SLOT( slotSaveTemplate( const QString& ) ) );
+  d->exec();
+  return;
 }
 
 void KOIncidenceEditor::saveAsTemplate( Incidence *incidence,
@@ -251,32 +183,29 @@ void KOIncidenceEditor::saveAsTemplate( Incidence *incidence,
   format.save( &cal, fileName );
 }
 
-QString KOIncidenceEditor::loadTemplate( Calendar *cal, const QString &type,
-                                         const QStringList &templates )
+void KOIncidenceEditor::slotLoadTemplate( const QString& templateName )
 {
-  bool ok = false;
-  QString templateName = KInputDialog::getItem( i18n("Load Template"),
-      i18n("Select a template to load:"), templates, 0, false, &ok, this );
-
-  if ( !ok || templateName.isEmpty() ) return QString::null;
-
-  QString fileName = locateLocal( "data", "korganizer/templates/" + type + "/" +
-                                  templateName );
+  CalendarLocal cal( KOPrefs::instance()->mTimeZoneId );
+  QString fileName = locateLocal( "data", "korganizer/templates/" + type() + "/" +
+      templateName );
 
   if ( fileName.isEmpty() ) {
     KMessageBox::error( this, i18n("Unable to find template '%1'.")
-                              .arg( fileName ) );
-    return QString::null;
+        .arg( fileName ) );
   } else {
     ICalFormat format;
-    if ( !format.load( cal, fileName ) ) {
+    if ( !format.load( &cal, fileName ) ) {
       KMessageBox::error( this, i18n("Error loading template file '%1'.")
-                                .arg( fileName ) );
-      return QString::null;
+          .arg( fileName ) );
+      return;
     }
   }
+  loadTemplate( cal );
+}
 
-  return templateName;
+void KOIncidenceEditor::slotTemplatesChanged( const QStringList& newTemplates )
+{
+  templates() = newTemplates;
 }
 
 void KOIncidenceEditor::setupDesignerTabs( const QString &type )
@@ -295,7 +224,7 @@ void KOIncidenceEditor::setupDesignerTabs( const QString &type )
 
 QWidget *KOIncidenceEditor::addDesignerTab( const QString &uifile )
 {
-  kdDebug() << "Designer tab: " << uifile << endl;
+  kdDebug(5850) << "Designer tab: " << uifile << endl;
 
   KPIM::DesignerFields *wid = new KPIM::DesignerFields( uifile, 0 );
   mDesignerFields.append( wid );
@@ -362,13 +291,13 @@ void KOIncidenceEditor::readDesignerFields( Incidence *i )
 
 void KOIncidenceEditor::writeDesignerFields( Incidence *i )
 {
-  kdDebug() << "KOIncidenceEditor::writeDesignerFields()" << endl;
+  kdDebug(5850) << "KOIncidenceEditor::writeDesignerFields()" << endl;
 
   KCalStorage storage( i );
   KPIM::DesignerFields *fields;
   for( fields = mDesignerFields.first(); fields;
        fields = mDesignerFields.next() ) {
-    kdDebug() << "Write Field " << fields->title() << endl;
+    kdDebug(5850) << "Write Field " << fields->title() << endl;
     fields->save( &storage );
   }
 }
@@ -377,8 +306,8 @@ void KOIncidenceEditor::writeDesignerFields( Incidence *i )
 void KOIncidenceEditor::setupEmbeddedURLPage( const QString &label,
                                  const QString &url, const QString &mimetype )
 {
-  kdDebug() << "KOIncidenceEditor::setupEmbeddedURLPage()" << endl;
-  kdDebug() << "label=" << label << ", url=" << url << ", mimetype=" << mimetype << endl;
+  kdDebug(5850) << "KOIncidenceEditor::setupEmbeddedURLPage()" << endl;
+  kdDebug(5850) << "label=" << label << ", url=" << url << ", mimetype=" << mimetype << endl;
   QFrame *topFrame = addPage( label );
   QBoxLayout *topLayout = new QVBoxLayout( topFrame );
 
@@ -394,11 +323,11 @@ void KOIncidenceEditor::setupEmbeddedURLPage( const QString &label,
 
 void KOIncidenceEditor::createEmbeddedURLPages( Incidence *i )
 {
-  kdDebug() << "KOIncidenceEditor::createEmbeddedURLPages()" << endl;
+  kdDebug(5850) << "KOIncidenceEditor::createEmbeddedURLPages()" << endl;
 
   if ( !i ) return;
   if ( !mEmbeddedURLPages.isEmpty() ) {
-kdDebug() << "mEmbeddedURLPages are not empty, clearing it!" << endl;
+    kdDebug(5850) << "mEmbeddedURLPages are not empty, clearing it!" << endl;
     mEmbeddedURLPages.setAutoDelete( true );
     mEmbeddedURLPages.clear();
     mEmbeddedURLPages.setAutoDelete( false );
@@ -418,8 +347,8 @@ kdDebug() << "mEmbeddedURLPages are not empty, clearing it!" << endl;
   Attachment::List att = i->attachments();
   for ( Attachment::List::Iterator it = att.begin(); it != att.end(); ++it ) {
     Attachment *a = (*it);
-    kdDebug() << "Iterating over the attachments " << endl;
-    kdDebug() << "label=" << a->label() << ", url=" << a->uri() << ", mimetype=" << a->mimeType() << endl;
+    kdDebug(5850) << "Iterating over the attachments " << endl;
+    kdDebug(5850) << "label=" << a->label() << ", url=" << a->uri() << ", mimetype=" << a->mimeType() << endl;
     if ( a && a->showInline() && a->isUri() ) {
       // TODO: Allow more mime-types, but add security checks!
 /*      if ( a->mimeType() == "application/x-designer" ) {
@@ -444,4 +373,24 @@ void KOIncidenceEditor::openURL( const KURL &url )
   UriHandler::process( uri );
 }
 
+void KOIncidenceEditor::addAttachments( const QStringList &attachments )
+{
+  QStringList::ConstIterator it;
+  for ( it = attachments.begin(); it != attachments.end(); ++it ) {
+    mAttachments->addAttachment( *it );
+  }
+}
+
+void KOIncidenceEditor::addAttendees( const QStringList &attendees )
+{
+  QStringList::ConstIterator it;
+  for ( it = attendees.begin(); it != attendees.end(); ++it ) {
+    QString name, email;
+    KABC::Addressee::parseEmailAddress( *it, name, email );
+    mDetails->insertAttendee( new Attendee( name, email ) );
+  }
+}
+
+
+
 #include "koincidenceeditor.moc"
