@@ -33,6 +33,7 @@
 #include <qdatastream.h>
 
 #include <kapplication.h>
+#include <kiconloader.h>
 #include <dcopclient.h>
 #include <klocale.h>
 #include <kprocess.h>
@@ -58,6 +59,8 @@ AlarmDialog::AlarmDialog( QWidget *parent, const char *name )
                  false, i18n("Suspend"), i18n("Edit...") ),
                  mSuspendTimer(this)
 {
+  KGlobal::iconLoader()->addAppDir( "kdepim" );
+
   QWidget *topBox = plainPage();
   QBoxLayout *topLayout = new QVBoxLayout( topBox );
   topLayout->setSpacing( spacingHint() );
@@ -73,9 +76,10 @@ AlarmDialog::AlarmDialog( QWidget *parent, const char *name )
   suspendBox->setSpacing( spacingHint() );
   topLayout->addWidget( suspendBox );
 
-  new QLabel( i18n("Suspend duration:"), suspendBox );
+  QLabel *l = new QLabel( i18n("Suspend &duration:"), suspendBox );
   mSuspendSpin = new QSpinBox( 1, 9999, 1, suspendBox );
   mSuspendSpin->setValue( 5 );  // default suspend duration
+  l->setBuddy( mSuspendSpin );
 
   mSuspendUnit = new KComboBox( suspendBox );
   mSuspendUnit->insertItem( i18n("minute(s)") );
@@ -83,10 +87,6 @@ AlarmDialog::AlarmDialog( QWidget *parent, const char *name )
   mSuspendUnit->insertItem( i18n("day(s)") );
   mSuspendUnit->insertItem( i18n("week(s)") );
 
-  connect( mSuspendSpin, SIGNAL( valueChanged(int) ), actionButton(User1), SLOT( setFocus() ) );
-  connect( mSuspendUnit, SIGNAL( activated(int) ), actionButton(User1), SLOT( setFocus() ) );
-  connect( mSuspendUnit, SIGNAL( activated(int) ), actionButton(User2), SLOT( setFocus() ) );
-
   // showButton( User2/*3*/, false );
 
   setMinimumSize( 300, 200 );
