@@ -42,7 +42,6 @@
 #include <libkcal/resourcecalendar.h>
 #include <libkcal/calfilter.h>
 #include <libkcal/incidenceformatter.h>
-#include <libkcal/journal.h>
 
 #include <libkdepim/clicklineedit.h>
 #include <libkdepim/kdatepickerpopup.h>
@@ -59,7 +58,10 @@
 using namespace KOrg;
 #include "kotodoviewitem.h"
 #include "kotodoview.moc"
-
+#ifndef KORG_NOPRINTER
+#include "kocorehelper.h"
+#include "calprinter.h"
+#endif
 
 KOTodoListViewToolTip::KOTodoListViewToolTip (QWidget* parent,
                                               KOTodoListView* lv )
@@ -234,7 +236,7 @@ void KOTodoListView::contentsDropEvent( QDropEvent *e )
     } else {
 //      kdDebug(5850) << "Drop new Todo" << endl;
       todo->setRelatedTo(destinationEvent);
-      if ( !mChanger->addIncidence( todo ) ) {
+      if ( !mChanger->addIncidence( todo, this ) ) {
         KODialogManager::errorSaveIncidence( this, todo );
         delete todo;
         return;
@@ -452,6 +454,9 @@ KOTodoView::KOTodoView( Calendar *calendar, QWidget *parent, const char* name)
                              SLOT (showTodo()));
   mItemPopupMenu->insertItem(i18n("&Edit..."), this,
                              SLOT (editTodo()), 0, ePopupEdit );
+#ifndef KORG_NOPRINTER
+  mItemPopupMenu->insertItem(KOGlobals::self()->smallIcon("printer1"), i18n("&Print..."), this, SLOT( printTodo() ) );
+#endif
   mItemPopupMenu->insertItem(KOGlobals::self()->smallIconSet("editdelete"), i18n("&Delete"), this,
                              SLOT (deleteTodo()), 0, ePopupDelete );
   mItemPopupMenu->insertSeparator();
@@ -590,6 +595,9 @@ QMap<Todo *,KOTodoViewItem *>::ConstIterator
     // Use dynamic_cast, because in the future the related item might also be an event
     Todo *relatedTodo = dynamic_cast<Todo *>(incidence);
 
+    // just make sure we know we have this item already to avoid endless recursion (Bug 101696)
+    mTodoMap.insert(todo,0);
+
 //    kdDebug(5850) << "  has Related" << endl;
     QMap<Todo *,KOTodoViewItem *>::ConstIterator itemIterator;
     itemIterator = mTodoMap.find(relatedTodo);
@@ -599,7 +607,17 @@ QMap<Todo *,KOTodoViewItem *>::ConstIterator
     }
     // isn't this pretty stupid? We give one Todo  to the KOTodoViewItem
     // and one into the map. Sure finding is more easy but why? -zecke
-    KOTodoViewItem *todoItem = new KOTodoViewItem(*itemIterator,todo,this);
+    KOTodoViewItem *todoItem;
+
+    // in case we found a related parent, which has no KOTodoViewItem yet, this must
+    // be the case where 2 items refer to each other, therefore simply create item as root item
+    if ( *itemIterator == 0 ) {
+      todo->setRelatedTo(0);  // break the recursion, else we will have troubles later
+      todoItem = new KOTodoViewItem(mTodoListView,todo,this);
+    }
+    else
+      todoItem = new KOTodoViewItem(*itemIterator,todo,this);
+
     return mTodoMap.insert(todo,todoItem);
   } else {
 //    kdDebug(5850) << "  no Related" << endl;
@@ -729,9 +747,13 @@ void KOTodoView::showIncidences( const Incidence::List & )
   kdDebug(5850) << "KOTodoView::showIncidences( const Incidence::List & ): not yet implemented" << endl;
 }
 
-CalPrinter::PrintType KOTodoView::printType()
+CalPrinterBase::PrintType KOTodoView::printType()
 {
-  return CalPrinter::Todolist;
+  if ( mTodoListView->selectedItem() ) {
+    return CalPrinterBase::Incidence;
+  } else {
+    return CalPrinterBase::Todolist;
+  }
 }
 
 void KOTodoView::editItem( QListViewItem *item )
@@ -807,6 +829,7 @@ void KOTodoView::popupMenu( QListViewItem *item, const QPoint &, int column )
 
 void KOTodoView::newTodo()
 {
+  kdDebug() << k_funcinfo << endl;
   emit newTodoSignal( QDate::currentDate().addDays(7) );
 }
 
@@ -827,6 +850,22 @@ void KOTodoView::showTodo()
   showItem( mActiveItem );
 }
 
+void KOTodoView::printTodo()
+{
+#ifndef KORG_NOPRINTER
+  Calendar *cal;
+  KOCoreHelper helper;
+  CalPrinter printer( this, cal, &helper );
+  connect( this, SIGNAL(configChanged()), &printer, SLOT(updateConfig()) );
+
+  Incidence::List selectedIncidences;
+  selectedIncidences.append( mActiveItem->todo() );
+
+  printer.print( KOrg::CalPrinterBase::Incidence,
+                 QDate(), QDate(), selectedIncidences );
+#endif
+}
+
 void KOTodoView::deleteTodo()
 {
   if (mActiveItem) {
@@ -879,7 +918,10 @@ void KOTodoView::setNewPercentage( KOTodoViewItem *item, int percentage )
       todo->setPercentComplete( percentage );
     }
     item->construct();
-    mChanger->changeIncidence( oldTodo, todo, KOGlobals::COMPLETION_MODIFIED );
+    if ( todo->doesRecur() && percentage == 100 )
+      mChanger->changeIncidence( oldTodo, todo, KOGlobals::COMPLETION_MODIFIED_WITH_RECURRENCE );
+    else
+      mChanger->changeIncidence( oldTodo, todo, KOGlobals::COMPLETION_MODIFIED );
     mChanger->endChange( todo );
     delete oldTodo;
   } else {
@@ -925,15 +967,13 @@ void KOTodoView::setNewDate( QDate date )
 
 void KOTodoView::copyTodoToDate( QDate date )
 {
-  QDateTime dt;
-  dt.setDate( date );
+  QDateTime dt( date );
 
   if ( mActiveItem && mChanger ) {
     Todo *newTodo = mActiveItem->todo()->clone();
     newTodo->recreate();
 
-   if ( date.isNull() )
-     newTodo->setHasDueDate( false );
+   newTodo->setHasDueDate( !date.isNull() );
    newTodo->setDtDue( dt );
    newTodo->setPercentComplete( 0 );
 
@@ -941,7 +981,7 @@ void KOTodoView::copyTodoToDate( QDate date )
    if ( newTodo->doesRecur() )
      newTodo->recurrence()->unsetRecurs();
 
-   mChanger->addIncidence( newTodo );
+   mChanger->addIncidence( newTodo, this );
  }
 }
 
@@ -1066,7 +1106,7 @@ void KOTodoView::addQuickTodo()
     todo->setSummary( mQuickAdd->text() );
     todo->setOrganizer( Person( KOPrefs::instance()->fullName(),
                         KOPrefs::instance()->email() ) );
-    if ( !mChanger->addIncidence( todo ) ) {
+    if ( !mChanger->addIncidence( todo, this ) ) {
       KODialogManager::errorSaveIncidence( this, todo );
       delete todo;
       return;
