@@ -21,8 +21,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 **
 **
 ** Specific permission is granted for this code to be linked to libmal
@@ -37,18 +37,15 @@
 
 class MALWidget;
 
-class MALWidgetSetup : public ConduitConfig
+class MALWidgetSetup : public ConduitConfigBase
 {
 Q_OBJECT
 public:
-	MALWidgetSetup(QWidget *,const char *,const QStringList &);
+	MALWidgetSetup(QWidget *,const char *);
 	virtual ~MALWidgetSetup();
-
-	virtual void readSettings();
-
-protected:
-	virtual void commitChanges();
-
+	virtual void load();
+	virtual void commit();
+	static ConduitConfigBase *create(QWidget *, const char *);
 private:
 	MALWidget *fConfigWidget;
 } ;
