@@ -19,7 +19,7 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 ** MA 02110-1301, USA.
 */
 
@@ -32,22 +32,22 @@
 
 #include <kdialogbase.h>
 
-class QLineEdit;
-class PilotAddress;
-struct AddressAppInfo;
+#include "pilotAddress.h"
 
-class AddressEditor : public KDialogBase 
+class QLineEdit;
+
+class AddressEditor : public KDialogBase
 {
 	Q_OBJECT
 
 
 public:
 	AddressEditor(PilotAddress *address,
-		struct AddressAppInfo *appInfo,
+		PilotAddressInfo *appInfo,
 		QWidget *parent, const char *name=0L);
 	~AddressEditor();
 
- 
+
 signals:
 	void recordChangeComplete ( PilotAddress* );
 
@@ -60,7 +60,7 @@ private:
 	bool fDeleteOnCancel;
 
 	PilotAddress* fAddress;
-	struct AddressAppInfo *fAppInfo;
+	PilotAddressInfo *fAppInfo;
 	// entry fields
 	QLineEdit *fCustom4Field;
 	QLineEdit *fCustom3Field;
@@ -78,10 +78,10 @@ private:
 	QLineEdit *fLastNameField;
 	// phone labels (changing!)
 	QLabel    *m_phoneLabel[5];
-	
+
 	void initLayout();
 	void fillFields();
-	QString phoneLabelText(PilotAddress *, int i);
+	QString phoneLabelText(PilotAddress *, const PhoneSlot &i);
 };
 #endif
 
