@@ -26,9 +26,6 @@
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
-static const char *todowidget_id =
-	"$Id: todoWidget.cc 444649 2005-08-10 13:21:07Z mlaurent $";
-
 
 #include "options.h"
 
@@ -79,8 +76,6 @@ TodoWidget::TodoWidget(QWidget * parent,
 	setupWidget();
 	fTodoList.setAutoDelete(true);
 
-	/* NOTREACHED */
-	(void) todowidget_id;
 }
 
 TodoWidget::~TodoWidget()
@@ -106,11 +101,10 @@ int TodoWidget::getAllTodos(PilotDatabase * todoDB)
 		if (!(pilotRec->isDeleted()) &&
 			(!(pilotRec->isSecret()) || KPilotSettings::showSecrets()))
 		{
-			todo = new PilotTodoEntry(*(fTodoAppInfo->info()), pilotRec);
+			todo = new PilotTodoEntry(pilotRec);
 			if (todo == 0L)
 			{
-				kdWarning() << k_funcinfo
-					<< ": Couldn't allocate record "
+				WARNINGKPILOT << "Couldn't allocate record "
 					<< currentRecord++
 					<< endl;
 				break;
@@ -144,7 +138,7 @@ void TodoWidget::showComponent()
 
 	fTodoList.clear();
 
-	if (fTodoDB->isDBOpen())
+	if (fTodoDB->isOpen())
 	{
 		KPILOT_DELETE(fTodoAppInfo);
 		fTodoAppInfo = new PilotToDoInfo(fTodoDB);
@@ -155,8 +149,7 @@ void TodoWidget::showComponent()
 	else
 	{
 		populateCategories(fCatList, 0L);
-		kdWarning() << k_funcinfo
-			<< ": Could not open local TodoDB" << endl;
+		WARNINGKPILOT << "Could not open local TodoDB" << endl;
 	}
 
 	KPILOT_DELETE( fTodoDB );
@@ -397,7 +390,7 @@ void TodoWidget::slotCreateNewRecord()
 	//
 	PilotDatabase *myDB = new PilotLocalDatabase(dbPath(), CSL1("ToDoDB"));
 
-	if (!myDB || !myDB->isDBOpen())
+	if (!myDB || !myDB->isOpen())
 	{
 #ifdef DEBUG
 		DEBUGKPILOT << fname
@@ -407,7 +400,7 @@ void TodoWidget::slotCreateNewRecord()
 			<< " and got pointer @"
 			<< (void *) myDB
 			<< " with status "
-			<< ( myDB ? myDB->isDBOpen() : false )
+			<< ( myDB ? myDB->isOpen() : false )
 			<< endl;
 #endif
 
@@ -444,7 +437,7 @@ void TodoWidget::slotAddRecord(PilotTodoEntry * todo)
 		fTodoAppInfo->categoryInfo(), true);
 
 
-	todo->PilotAppCategory::setCategory(currentCatID);
+	todo->PilotRecordBase::setCategory(currentCatID);
 	fTodoList.append(todo);
 	writeTodo(todo);
 	// TODO: Just add the new record to the lists
@@ -533,7 +526,7 @@ void TodoWidget::slotShowTodo(QListViewItem*item)
 #endif
 
 	QString text(CSL1("<qt>"));
-	text += todo->getTextRepresentation(true);
+	text += todo->getTextRepresentation(Qt::RichText);
 	text += CSL1("</qt>\n");
 	fTodoInfo->setText(text);
 
@@ -555,7 +548,7 @@ void TodoWidget::writeTodo(PilotTodoEntry * which,
 	PilotDatabase *myDB = todoDB;
 	bool usemyDB = false;
 
-	if (myDB == 0L || !myDB->isDBOpen())
+	if (myDB == 0L || !myDB->isOpen())
 	{
 		myDB = new PilotLocalDatabase(dbPath(), CSL1("ToDoDB"));
 		usemyDB = true;
@@ -564,7 +557,7 @@ void TodoWidget::writeTodo(PilotTodoEntry * which,
 	// Still no valid todo database...
 	//
 	//
-	if (!myDB->isDBOpen())
+	if (!myDB->isOpen())
 	{
 #ifdef DEBUG
 		DEBUGKPILOT << fname << ": Todo database is not open" <<
