@@ -107,7 +107,8 @@ public:
 
   // Listen to KMail changes in the amount of sub resources
   void fromKMailAddSubresource( const QString& type, const QString& id,
-                                const QString& label, bool writable );
+                                const QString& label, bool writable,
+                                bool alarmRelevant );
   void fromKMailDelSubresource( const QString& type, const QString& id );
 
   bool fromKMailAddIncidence( const QString& type, const QString& resource,
