@@ -139,9 +139,10 @@ bool Journal::loadXML( const QDomDocument& document )
       continue;
     if ( n.isElement() ) {
       QDomElement e = n.toElement();
-      if ( !loadAttribute( e ) )
+      if ( !loadAttribute( e ) ) {
         // Unhandled tag - save for later storage
-        ;//qDebug( "Unhandled tag: %s", e.toCString().data() );
+        //qDebug( "Unhandled tag: %s", e.toCString().data() );
+      }
     } else
       qDebug( "Node is not a comment or an element???" );
   }
