@@ -67,7 +67,8 @@ static const char* incidenceInlineMimeType = "text/calendar";
 
 ResourceKolab::ResourceKolab( const KConfig *config )
   : ResourceCalendar( config ), ResourceKolabBase( "ResourceKolab-libkcal" ),
-    mCalendar( QString::fromLatin1("UTC") ), mOpen( false )
+    mCalendar( QString::fromLatin1("UTC") ), mOpen( false ),mResourceChangedTimer( 0,
+        "mResourceChangedTimer" )
 {
   setType( "imap" );
   connect( &mResourceChangedTimer, SIGNAL( timeout() ),
@@ -87,11 +88,13 @@ void ResourceKolab::loadSubResourceConfig( KConfig& config,
                                            const QString& name,
                                            const QString& label,
                                            bool writable,
+                                           bool alarmRelevant,
                                            ResourceMap& subResource )
 {
   KConfigGroup group( &config, name );
   bool active = group.readBoolEntry( "Active", true );
-  subResource.insert( name, Kolab::SubResource( active, writable, label ) );
+  subResource.insert( name, Kolab::SubResource( active, writable,
+                                                alarmRelevant, label ) );
 }
 
 bool ResourceKolab::openResource( KConfig& config, const char* contentType,
@@ -104,7 +107,8 @@ bool ResourceKolab::openResource( KConfig& config, const char* contentType,
   map.clear();
   QValueList<KMailICalIface::SubResource>::ConstIterator it;
   for ( it = subResources.begin(); it != subResources.end(); ++it )
-    loadSubResourceConfig( config, (*it).location, (*it).label, (*it).writable, map );
+    loadSubResourceConfig( config, (*it).location, (*it).label, (*it).writable, 
+                           (*it).alarmRelevant, map );
   return true;
 }
 
@@ -249,7 +253,10 @@ bool ResourceKolab::loadAllJournals()
 {
   removeIncidences( "Journal" );
   mCalendar.deleteAllJournals();
-  return doLoadAll( mJournalSubResources, journalAttachmentMimeType );
+  bool kolabStyle = doLoadAll( mJournalSubResources, journalAttachmentMimeType );
+  bool icalStyle = doLoadAll( mJournalSubResources, incidenceInlineMimeType );
+
+  return kolabStyle && icalStyle;
 }
 
 void ResourceKolab::removeIncidences( const QCString& incidenceType )
@@ -489,18 +496,18 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
       }
     }
   } else { /* KMail told us */
-    bool ourOwnUpdate = false;
+    bool ourOwnUpdate = mUidsPendingUpdate.contains(  uid );
     /* Check if we updated this one, which means kmail deleted and added it.
      * We know the new state, so lets just not do much at all. The old incidence
      * in the calendar remains valid, but the serial number changed, so we need to
      * update that */
-    if ( ourOwnUpdate = mUidsPendingUpdate.contains( uid ) ) {
+    if ( ourOwnUpdate ) {
       mUidsPendingUpdate.remove( uid );
       mUidMap.remove( uid );
       mUidMap[ uid ] = StorageReference( subResource, sernum );
     } else {
       /* This is a real add, from KMail, we didn't trigger this ourselves.
-       * If this uid already exists in this folder, do conflict resolution, 
+       * If this uid already exists in this folder, do conflict resolution,
        * unless the folder is read-only, in which case the user should not be
        * offered a means of putting mails in a folder she'll later be unable to
        * upload. Skip the incidence, in this case. */
@@ -548,7 +555,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const QString& _su
 
 bool ResourceKolab::addEvent( KCal::Event* event )
 {
-  if ( mUidMap.contains( event->uid() ) ) 
+  if ( mUidMap.contains( event->uid() ) )
     return true; //noop
   else
     return addIncidence( event, QString::null, 0 );
@@ -620,7 +627,7 @@ KCal::Event::List ResourceKolab::rawEvents( const QDate& start,
 
 bool ResourceKolab::addTodo( KCal::Todo* todo )
 {
-  if ( mUidMap.contains( todo->uid() ) ) 
+  if ( mUidMap.contains( todo->uid() ) )
     return true; //noop
   else
     return addIncidence( todo, QString::null, 0 );
@@ -657,7 +664,7 @@ KCal::Todo::List ResourceKolab::rawTodosForDate( const QDate& date )
 
 bool ResourceKolab::addJournal( KCal::Journal* journal )
 {
-  if ( mUidMap.contains( journal->uid() ) ) 
+  if ( mUidMap.contains( journal->uid() ) )
     return true; //noop
   else
     return addIncidence( journal, QString::null, 0 );
@@ -694,15 +701,41 @@ KCal::Journal::List ResourceKolab::rawJournalsForDate( const QDate &date )
   return mCalendar.rawJournalsForDate( date );
 }
 
+KCal::Alarm::List ResourceKolab::relevantAlarms( const KCal::Alarm::List &alarms )
+{
+  KCal::Alarm::List relevantAlarms;
+  KCal::Alarm::List::ConstIterator it( alarms.begin() );
+  while ( it != alarms.end() ) {
+    KCal::Alarm *a = (*it);
+    ++it;
+    const QString &uid = a->parent()->uid();
+     if ( mUidMap.contains( uid ) ) {
+       const QString &sr = mUidMap[ uid ].resource();
+       Kolab::SubResource *subResource = 0;
+       if ( mEventSubResources.contains( sr ) )
+          subResource = &( mEventSubResources[ sr ] );
+       else if ( mTodoSubResources.contains( sr ) )
+          subResource = &( mTodoSubResources[ sr ] );
+       assert( subResource );
+       if ( subResource->alarmRelevant() )
+           relevantAlarms.append ( a );
+       else {
+         kdDebug(5650) << "Alarm skipped, not relevant." << endl;
+       }
+     }
+  }
+  return relevantAlarms;
+}
+
 KCal::Alarm::List ResourceKolab::alarms( const QDateTime& from,
                                          const QDateTime& to )
 {
-  return mCalendar.alarms( from, to );
+  return relevantAlarms( mCalendar.alarms( from, to ) );
 }
 
 KCal::Alarm::List ResourceKolab::alarmsTo( const QDateTime& to )
 {
-  return mCalendar.alarmsTo(to);
+  return relevantAlarms( mCalendar.alarmsTo(to) );
 }
 
 void ResourceKolab::setTimeZoneId( const QString& tzid )
@@ -791,7 +824,7 @@ void ResourceKolab::fromKMailRefresh( const QString& type,
 void ResourceKolab::fromKMailAddSubresource( const QString& type,
                                              const QString& subResource,
                                              const QString& label,
-                                             bool writable )
+                                             bool writable, bool alarmRelevant )
 {
   ResourceMap* map = 0;
   const char* mimetype = 0;
@@ -816,7 +849,8 @@ void ResourceKolab::fromKMailAddSubresource( const QString& type,
   config.setGroup( subResource );
 
   bool active = config.readBoolEntry( subResource, true );
-  (*map)[ subResource ] = Kolab::SubResource( active, writable, label );
+  (*map)[ subResource ] = Kolab::SubResource( active, writable, 
+                                              alarmRelevant, label );
   loadSubResource( subResource, mimetype );
   emit signalSubresourceAdded( this, type, subResource, label );
 }
