@@ -98,8 +98,8 @@ bool KMailConnection::connectToKMail()
     if ( !connectKMailSignal( "signalRefresh(QString,QString)",
                               "fromKMailRefresh(QString,QString)" ) )
       kdError(5650) << "DCOP connection to signalRefresh failed" << endl;
-    if ( !connectKMailSignal( "subresourceAdded( QString, QString, QString )",
-                              "fromKMailAddSubresource( QString, QString, QString )" ) )
+    if ( !connectKMailSignal( "subresourceAdded( QString, QString, QString, bool, bool )",
+                              "fromKMailAddSubresource( QString, QString, QString, bool, bool )" ) )
       kdError(5650) << "DCOP connection to subresourceAdded failed" << endl;
     if ( !connectKMailSignal( "subresourceDeleted(QString,QString)",
                               "fromKMailDelSubresource(QString,QString)" ) )
@@ -118,7 +118,7 @@ bool KMailConnection::fromKMailAddIncidence( const QString& type,
                                              int format,
                                              const QString& data )
 {
-  if ( format != KMailICalIface::StorageXML 
+  if ( format != KMailICalIface::StorageXML
       && format != KMailICalIface::StorageIcalVcard )
     return false;
 //   kdDebug(5650) << "KMailConnection::fromKMailAddIncidence( " << type << ", "
@@ -144,17 +144,14 @@ void KMailConnection::fromKMailRefresh( const QString& type, const QString& fold
 
 void KMailConnection::fromKMailAddSubresource( const QString& type,
                                                const QString& resource,
-                                               const QString& label )
+                                               const QString& label,
+                                               bool writable,
+                                               bool alarmRelevant )
 {
 //   kdDebug(5650) << "KMailConnection::fromKMailAddSubresource( " << type << ", "
 //                 << resource << " )\n";
-  bool writable = true;
-
-  // TODO: This should be told by KMail right away
-  if ( connectToKMail() )
-    writable = mKMailIcalIfaceStub->isWritableFolder( type, resource );
-
-  mResource->fromKMailAddSubresource( type, resource, label, writable );
+  mResource->fromKMailAddSubresource( type, resource, label, 
+                                      writable, alarmRelevant );
 }
 
 void KMailConnection::fromKMailDelSubresource( const QString& type,
@@ -244,7 +241,7 @@ bool KMailConnection::kmailUpdate( const QString& resource,
                                    const QStringList& attachmentNames,
                                    const QStringList& deletedAttachments )
 {
-  kdDebug(5006) << kdBacktrace() << endl;
+  //kdDebug(5006) << kdBacktrace() << endl;
   if ( connectToKMail() ) {
     sernum = mKMailIcalIfaceStub->update( resource, sernum, subject, plainTextBody, customHeaders,
                                           attachmentURLs, attachmentMimetypes, attachmentNames,
@@ -254,7 +251,7 @@ bool KMailConnection::kmailUpdate( const QString& resource,
     return false;
 }
 
-bool KMailConnection::kmailStorageFormat( KMailICalIface::StorageFormat& type, 
+bool KMailConnection::kmailStorageFormat( KMailICalIface::StorageFormat& type,
                                           const QString& folder )
 {
   bool ok = connectToKMail();
