@@ -12,7 +12,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include "config.h"
@@ -148,7 +148,7 @@ int lzfu_decompress(QIODevice *input, QIODevice *output)
 			else
 			{
 				// uncompressed chunk (char)
-				char c = (char)input->getch();
+				signed char c = (char)input->getch();
 				if (c == -1)
 				{
 					if (!input->atEnd())
