@@ -18,7 +18,6 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-
 #include "email.h"
 
 #include <kdebug.h>
@@ -614,27 +613,26 @@ bool KPIM::getNameAndMail(const QString& aStr, QString& name, QString& mail)
   const int len=aStr.length();
   const char cQuotes = '"';
 
-  bool bInComment, bInQuotesOutsideOfEmail;
+  bool bInComment = false;
+  bool bInQuotesOutsideOfEmail = false;
   int i=0, iAd=0, iMailStart=0, iMailEnd=0;
   QChar c;
+  unsigned int commentstack = 0;
 
   // Find the '@' of the email address
   // skipping all '@' inside "(...)" comments:
-  bInComment = false;
   while( i < len ){
     c = aStr[i];
-    if( !bInComment ){
-      if( '(' == c ){
-        bInComment = true;
-      }else{
-        if( '@' == c ){
-          iAd = i;
-          break; // found it
-        }
-      }
-    }else{
-      if( ')' == c ){
-        bInComment = false;
+    if( '(' == c ) commentstack++;
+    if( ')' == c ) commentstack--;
+    bInComment = commentstack != 0;
+    if( '"' == c && !bInComment ) 
+        bInQuotesOutsideOfEmail = !bInQuotesOutsideOfEmail;
+
+    if( !bInComment && !bInQuotesOutsideOfEmail ){
+      if( '@' == c ){
+        iAd = i;
+        break; // found it
       }
     }
     ++i;
