@@ -1479,6 +1479,7 @@ void ICalFormatImpl::readIncidenceBase(icalcomponent *parent,IncidenceBase *inci
 void ICalFormatImpl::readCustomProperties(icalcomponent *parent,CustomProperties *properties)
 {
   QMap<QCString, QString> customProperties;
+  QString lastProperty;
 
   icalproperty *p = icalcomponent_get_first_property(parent,ICAL_X_PROPERTY);
 
@@ -1486,9 +1487,14 @@ void ICalFormatImpl::readCustomProperties(icalcomponent *parent,CustomProperties
 
     QString value = QString::fromUtf8(icalproperty_get_x(p));
     const char *name = icalproperty_get_x_name(p);
-    customProperties[name] = value;
+    if ( lastProperty != name ) {
+      customProperties[name] = value;
+    } else {
+      customProperties[name] = customProperties[name].append( "," ).append( value );
+    }
     // kdDebug(5800) << "Set custom property [" << name << '=' << value << ']' << endl;
     p = icalcomponent_get_next_property(parent,ICAL_X_PROPERTY);
+    lastProperty = name;
   }
 
   properties->setCustomProperties(customProperties);
@@ -1982,7 +1988,14 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Todo found" << endl;
     Todo *todo = readTodo(c);
-    if (todo && !cal->todo(todo->uid())) cal->addTodo(todo);
+    if (todo) {
+      if (!cal->todo(todo->uid())) {
+        cal->addTodo(todo);
+      } else {
+        delete todo;
+        mTodosRelate.remove( todo );
+      }
+    }
     c = icalcomponent_get_next_component(calendar,ICAL_VTODO_COMPONENT);
   }
 
@@ -1991,7 +2004,14 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Event found" << endl;
     Event *event = readEvent(c, ctz);
-    if (event && !cal->event(event->uid())) cal->addEvent(event);
+    if (event) {
+      if (!cal->event(event->uid())) {
+        cal->addEvent(event);
+      } else {
+        delete event;
+        mEventsRelate.remove( event );
+      }
+    }
     c = icalcomponent_get_next_component(calendar,ICAL_VEVENT_COMPONENT);
   }
 
@@ -2000,7 +2020,13 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Journal found" << endl;
     Journal *journal = readJournal(c);
-    if (journal && !cal->journal(journal->uid())) cal->addJournal(journal);
+    if (journal) {
+      if (!cal->journal(journal->uid())) {
+        cal->addJournal(journal);
+      } else {
+        delete journal;
+      }
+    }
     c = icalcomponent_get_next_component(calendar,ICAL_VJOURNAL_COMPONENT);
   }
 
