@@ -4,12 +4,11 @@
   CREATOR: eric 20 March 1999
 
 
-  $Id: icalparameter.h 405592 2005-04-14 19:28:51Z dfaure $
-  $Locker:  $
 
   
 
- (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of either: 
@@ -53,7 +52,7 @@ icalparameter_kind icalparameter_isa(icalparameter* parameter);
 
 int icalparameter_isa_parameter(void* param);
 
-/* Acess the name of an X parameer */
+/* Access the name of an X parameer */
 void icalparameter_set_xname (icalparameter* param, const char* v);
 const char* icalparameter_get_xname(icalparameter* param);
 void icalparameter_set_xvalue (icalparameter* param, const char* v);
