@@ -1,7 +1,7 @@
 /*
     This file is part of libkcal.
 
-    Copyright (c) 1998 Preston Brwon
+    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
     Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <qapplication.h>
@@ -38,6 +38,7 @@
 #include "vobject.h"
 extern "C" {
 #include "icaltime.h"
+#include "icaltimezone.h"
 }
 #include "vcaldrag.h"
 #include "calendar.h"
@@ -181,7 +182,10 @@ QString VCalFormat::toString( Calendar *calendar )
   // TODO: Use all data.
   Event::List events = calendar->events();
   Event *event = events.first();
-  if ( !event ) return QString::null;
+  if ( !event ) {
+    cleanVObject( vcal );
+    return QString::null;
+  }
 
   VObject *vevent = eventToVEvent( event );
 
@@ -423,100 +427,93 @@ VObject* VCalFormat::eventToVEvent(const Event *anEvent)
   }
 
   // recurrence rule stuff
-  if (anEvent->recurrence()->doesRecur()) {
-    // some more variables
-    QPtrList<Recurrence::rMonthPos> tmpPositions;
-    QPtrList<int> tmpDays;
-    int *tmpDay;
-    Recurrence::rMonthPos *tmpPos;
+  const Recurrence *recur = anEvent->recurrence();
+  if ( recur->doesRecur() ) {
+    bool validRecur = true;
     QString tmpStr2;
-    int i;
-
-    switch(anEvent->recurrence()->doesRecur()) {
+    switch ( recur->recurrenceType() ) {
     case Recurrence::rDaily:
-      tmpStr.sprintf("D%i ",anEvent->recurrence()->frequency());
-//      if (anEvent->rDuration > 0)
-//        tmpStr += "#";
+      tmpStr.sprintf("D%i ",recur->frequency());
       break;
     case Recurrence::rWeekly:
-      tmpStr.sprintf("W%i ",anEvent->recurrence()->frequency());
-      for (i = 0; i < 7; i++) {
-        if (anEvent->recurrence()->days().testBit(i))
+      tmpStr.sprintf("W%i ",recur->frequency());
+      for (int i = 0; i < 7; i++ ) {
+        QBitArray days ( recur->days() );
+        if ( days.testBit(i) )
           tmpStr += dayFromNum(i);
       }
       break;
-    case Recurrence::rMonthlyPos:
-      tmpStr.sprintf("MP%i ", anEvent->recurrence()->frequency());
+    case Recurrence::rMonthlyPos: {
+      tmpStr.sprintf("MP%i ", recur->frequency());
       // write out all rMonthPos's
-      tmpPositions = anEvent->recurrence()->monthPositions();
-      for (tmpPos = tmpPositions.first();
-           tmpPos;
-           tmpPos = tmpPositions.next()) {
-
-        tmpStr2.sprintf("%i", tmpPos->rPos);
-        if (tmpPos->negative)
+      QValueList<RecurrenceRule::WDayPos> tmpPositions = recur->monthPositions();
+      for ( QValueListConstIterator<RecurrenceRule::WDayPos> posit = tmpPositions.begin();
+            posit != tmpPositions.end(); ++posit ) {
+        int pos = (*posit).pos();
+        tmpStr2.sprintf("%i", (pos>0) ? pos : (-pos) );
+        if ( pos < 0)
           tmpStr2 += "- ";
         else
           tmpStr2 += "+ ";
         tmpStr += tmpStr2;
-        for (i = 0; i < 7; i++) {
-          if (tmpPos->rDays.testBit(i))
-            tmpStr += dayFromNum(i);
-        }
-      } // loop for all rMonthPos's
-      break;
-    case Recurrence::rMonthlyDay:
-      tmpStr.sprintf("MD%i ", anEvent->recurrence()->frequency());
+        tmpStr += dayFromNum( (*posit).day() - 1 );
+      }
+      break; }
+    case Recurrence::rMonthlyDay: {
+      tmpStr.sprintf("MD%i ", recur->frequency());
       // write out all rMonthDays;
-      tmpDays = anEvent->recurrence()->monthDays();
-      for (tmpDay = tmpDays.first();
-           tmpDay;
-           tmpDay = tmpDays.next()) {
-        tmpStr2.sprintf("%i ", *tmpDay);
+      QValueList<int> tmpDays = recur->monthDays();
+      for ( QValueListIterator<int> tmpDay = tmpDays.begin();
+            tmpDay != tmpDays.end(); ++tmpDay ) {
+        tmpStr2.sprintf( "%i ", *tmpDay );
         tmpStr += tmpStr2;
       }
-      break;
-    case Recurrence::rYearlyMonth:
-      tmpStr.sprintf("YM%i ", anEvent->recurrence()->frequency());
+      break; }
+    case Recurrence::rYearlyMonth: {
+      tmpStr.sprintf("YM%i ", recur->frequency());
+      // write out all the months;'
+      // TODO: Any way to write out the day within the month???
+      QValueList<int> months = recur->yearMonths();
+      for ( QValueListIterator<int> mit = months.begin();
+            mit != months.end(); ++mit ) {
+        tmpStr2.sprintf( "%i ", *mit );
+        tmpStr += tmpStr2;
+      }
+      break; }
+    case Recurrence::rYearlyDay: {
+      tmpStr.sprintf("YD%i ", recur->frequency());
       // write out all the rYearNums;
-      tmpDays = anEvent->recurrence()->yearNums();
-      for (tmpDay = tmpDays.first();
-           tmpDay;
-           tmpDay = tmpDays.next()) {
-        tmpStr2.sprintf("%i ", *tmpDay);
+      QValueList<int> tmpDays = recur->yearDays();
+      for ( QValueListIterator<int> tmpDay = tmpDays.begin();
+            tmpDay != tmpDays.end(); ++tmpDay ) {
+        tmpStr2.sprintf( "%i ", *tmpDay );
         tmpStr += tmpStr2;
       }
-      break;
-    case Recurrence::rYearlyDay:
-      tmpStr.sprintf("YD%i ", anEvent->recurrence()->frequency());
-      // write out all the rYearNums;
-      tmpDays = anEvent->recurrence()->yearNums();
-      for (tmpDay = tmpDays.first();
-           tmpDay;
-           tmpDay = tmpDays.next()) {
-        tmpStr2.sprintf("%i ", *tmpDay);
-        tmpStr += tmpStr2;
-      }
-      break;
+      break; }
     default:
+      // TODO: Write rYearlyPos and arbitrary rules!
       kdDebug(5800) << "ERROR, it should never get here in eventToVEvent!" << endl;
+      validRecur = false;
       break;
     } // switch
 
-    if (anEvent->recurrence()->duration() > 0) {
-      tmpStr2.sprintf("#%i",anEvent->recurrence()->duration());
+    if (recur->duration() > 0) {
+      tmpStr2.sprintf("#%i",recur->duration());
       tmpStr += tmpStr2;
-    } else if (anEvent->recurrence()->duration() == -1) {
+    } else if (recur->duration() == -1) {
       tmpStr += "#0"; // defined as repeat forever
     } else {
-      tmpStr += qDateTimeToISO(anEvent->recurrence()->endDate(), FALSE);
+      tmpStr += qDateTimeToISO(recur->endDateTime(), FALSE);
     }
-    addPropValue(vevent,VCRRuleProp, tmpStr.local8Bit());
+    // Only write out the rrule if we have a valid recurrence (i.e. a known
+    // type in thee switch above)
+    if ( validRecur )
+      addPropValue(vevent,VCRRuleProp, tmpStr.local8Bit());
 
   } // event repeats
 
   // exceptions to recurrence
-  DateList dateList = anEvent->exDates();
+  DateList dateList = recur->exDates();
   DateList::ConstIterator it;
   QString tmpStr2;
 
@@ -715,7 +712,7 @@ Todo *VCalFormat::VTodoToEvent(VObject *vtodo)
         a = new Attendee(0, tmpStr);
       } else {
         // just a name
-				// WTF??? Replacing the spaces of a name and using this as email?
+        // WTF??? Replacing the spaces of a name and using this as email?
         QString email = tmpStr.replace( ' ', '.' );
         a = new Attendee(tmpStr,email);
       }
@@ -989,216 +986,175 @@ Event* VCalFormat::VEventToEvent(VObject *vevent)
     deleteStr(s);
     tmpStr.simplifyWhiteSpace();
     tmpStr = tmpStr.upper();
+// kdDebug() <<" We have a recurrence rule: " << tmpStr<< endl;
 
-    /********************************* DAILY ******************************/
-    if (tmpStr.left(1) == "D") {
-      int index = tmpStr.find(' ');
-      int rFreq = tmpStr.mid(1, (index-1)).toInt();
-      index = tmpStr.findRev(' ') + 1; // advance to last field
-      if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
-        anEvent->recurrence()->setDaily(rFreq, rEndDate);
-      } else {
-        int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0) // VEvents set this to 0 forever, we use -1
-          anEvent->recurrence()->setDaily(rFreq, -1);
-        else
-          anEvent->recurrence()->setDaily(rFreq, rDuration);
-      }
-    }
-    /********************************* WEEKLY ******************************/
-    else if (tmpStr.left(1) == "W") {
-      int index = tmpStr.find(' ');
-      int last = tmpStr.findRev(' ') + 1;
-      int rFreq = tmpStr.mid(1, (index-1)).toInt();
-      index += 1; // advance to beginning of stuff after freq
-      QBitArray qba(7);
-      QString dayStr;
-      if( index == last ) {
-        // e.g. W1 #0
-        qba.setBit(anEvent->dtStart().date().dayOfWeek() - 1);
-      }
-      else {
-        // e.g. W1 SU #0
-        while (index < last) {
-          dayStr = tmpStr.mid(index, 3);
-          int dayNum = numFromDay(dayStr);
-          qba.setBit(dayNum);
-          index += 3; // advance to next day, or possibly "#"
-        }
-      }
-      index = last; if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
-        anEvent->recurrence()->setWeekly(rFreq, qba, rEndDate);
-      } else {
-        int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0)
-          anEvent->recurrence()->setWeekly(rFreq, qba, -1);
-        else
-          anEvent->recurrence()->setWeekly(rFreq, qba, rDuration);
-      }
-    }
-    /**************************** MONTHLY-BY-POS ***************************/
-    else if (tmpStr.left(2) == "MP") {
-      int index = tmpStr.find(' ');
-      int last = tmpStr.findRev(' ') + 1;
-      int rFreq = tmpStr.mid(2, (index-1)).toInt();
-      index += 1; // advance to beginning of stuff after freq
-      QBitArray qba(7);
-      short tmpPos;
-      if( index == last ) {
-        // e.g. MP1 #0
-        tmpPos = anEvent->dtStart().date().day()/7 + 1;
-        if( tmpPos == 5 )
-          tmpPos = -1;
-        qba.setBit(anEvent->dtStart().date().dayOfWeek() - 1);
-        anEvent->recurrence()->addMonthlyPos(tmpPos, qba);
-      }
-      else {
-        // e.g. MP1 1+ SU #0
-        while (index < last) {
-          tmpPos = tmpStr.mid(index,1).toShort();
-          index += 1;
-          if (tmpStr.mid(index,1) == "-")
-            // convert tmpPos to negative
-            tmpPos = 0 - tmpPos;
-          index += 2; // advance to day(s)
-          while (numFromDay(tmpStr.mid(index,3)) >= 0) {
-            int dayNum = numFromDay(tmpStr.mid(index,3));
-            qba.setBit(dayNum);
-            index += 3; // advance to next day, or possibly pos or "#"
-          }
-          anEvent->recurrence()->addMonthlyPos(tmpPos, qba);
-          qba.detach();
-          qba.fill(FALSE); // clear out
-        } // while != "#"
-      }
-      index = last; if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length() -
-                                                    index))).date();
-        anEvent->recurrence()->setMonthly(Recurrence::rMonthlyPos, rFreq, rEndDate);
-      } else {
-        int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0)
-          anEvent->recurrence()->setMonthly(Recurrence::rMonthlyPos, rFreq, -1);
-        else
-          anEvent->recurrence()->setMonthly(Recurrence::rMonthlyPos, rFreq, rDuration);
+    // first, read the type of the recurrence
+    int typelen = 1;
+    uint type = Recurrence::rNone;
+    if ( tmpStr.left(1) == "D") {
+      type = Recurrence::rDaily;
+    } else if ( tmpStr.left(1) == "W") {
+      type = Recurrence::rWeekly;
+    } else {
+      typelen = 2;
+      if ( tmpStr.left(2) == "MP") {
+        type = Recurrence::rMonthlyPos;
+      } else if ( tmpStr.left(2) == "MD" ) {
+        type = Recurrence::rMonthlyDay;
+      } else if ( tmpStr.left(2) == "YM" ) {
+        type = Recurrence::rYearlyMonth;
+      } else if ( tmpStr.left(2) == "YD" ) {
+        type = Recurrence::rYearlyDay;
       }
     }
 
-    /**************************** MONTHLY-BY-DAY ***************************/
-    else if (tmpStr.left(2) == "MD") {
-      int index = tmpStr.find(' ');
-      int last = tmpStr.findRev(' ') + 1;
-      int rFreq = tmpStr.mid(2, (index-1)).toInt();
-      index += 1;
-      short tmpDay;
-      // We have to set monthly by day now (using dummy values), because the
-      // addMonthlyDay calls check for that type of recurrence, and if the
-      // recurrence isn't yet set to monthly, addMonthlyDay doesn't do anything
-      anEvent->recurrence()->setMonthly( Recurrence::rMonthlyDay, rFreq, -1 );
-      if( index == last ) {
-        // e.g. MD1 #0
-        tmpDay = anEvent->dtStart().date().day();
-        anEvent->recurrence()->addMonthlyDay(tmpDay);
-      }
-      else {
-        // e.g. MD1 3 #0
-        while (index < last) {
-          int index2 = tmpStr.find(' ', index);
-          tmpDay = tmpStr.mid(index, (index2-index)).toShort();
-          index = index2-1;
-          if (tmpStr.mid(index, 1) == "-")
-            tmpDay = 0 - tmpDay;
-          index += 2; // advance the index;
-          anEvent->recurrence()->addMonthlyDay(tmpDay);
-        } // while != #
-      }
-      index = last; if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
-        anEvent->recurrence()->setMonthly(Recurrence::rMonthlyDay, rFreq, rEndDate);
-      } else {
-        int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0)
-          anEvent->recurrence()->setMonthly(Recurrence::rMonthlyDay, rFreq, -1);
-        else
-          anEvent->recurrence()->setMonthly(Recurrence::rMonthlyDay, rFreq, rDuration);
-      }
-    }
+    if ( type != Recurrence::rNone ) {
+// kdDebug() << " It's a supported type " << endl;
 
-    /*********************** YEARLY-BY-MONTH *******************************/
-    else if (tmpStr.left(2) == "YM") {
+      // Immediately after the type is the frequency
       int index = tmpStr.find(' ');
-      int last = tmpStr.findRev(' ') + 1;
-      int rFreq = tmpStr.mid(2, (index-1)).toInt();
-      index += 1;
-      short tmpMonth;
-      if( index == last ) {
-        // e.g. YM1 #0
-        tmpMonth = anEvent->dtStart().date().month();
-        anEvent->recurrence()->addYearlyNum(tmpMonth);
-      }
-      else {
-        // e.g. YM1 3 #0
-        while (index < last) {
-          int index2 = tmpStr.find(' ', index);
-          tmpMonth = tmpStr.mid(index, (index2-index)).toShort();
-          index = index2+1;
-          anEvent->recurrence()->addYearlyNum(tmpMonth);
-        } // while != #
-      }
-      index = last; if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
-        anEvent->recurrence()->setYearly(Recurrence::rYearlyMonth, rFreq, rEndDate);
-      } else {
-        int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0)
-          anEvent->recurrence()->setYearly(Recurrence::rYearlyMonth, rFreq, -1);
-        else
-          anEvent->recurrence()->setYearly(Recurrence::rYearlyMonth, rFreq, rDuration);
-      }
-    }
+      int last = tmpStr.findRev(' ') + 1; // find last entry
+      int rFreq = tmpStr.mid(typelen, (index-1)).toInt();
+      ++index; // advance to beginning of stuff after freq
 
-    /*********************** YEARLY-BY-DAY *********************************/
-    else if (tmpStr.left(2) == "YD") {
-      int index = tmpStr.find(' ');
-      int last = tmpStr.findRev(' ') + 1;
-      int rFreq = tmpStr.mid(2, (index-1)).toInt();
-      index += 1;
-      short tmpDay;
-      if( index == last ) {
-        // e.g. YD1 #0
-        tmpDay = anEvent->dtStart().date().dayOfYear();
-        anEvent->recurrence()->addYearlyNum(tmpDay);
+      // Read the type-specific settings
+      switch ( type ) {
+        case Recurrence::rDaily:
+               anEvent->recurrence()->setDaily(rFreq);
+               break;
+
+        case Recurrence::rWeekly: {
+               QBitArray qba(7);
+               QString dayStr;
+               if( index == last ) {
+                 // e.g. W1 #0
+                 qba.setBit(anEvent->dtStart().date().dayOfWeek() - 1);
+               }
+               else {
+                 // e.g. W1 SU #0
+                 while (index < last) {
+                   dayStr = tmpStr.mid(index, 3);
+                   int dayNum = numFromDay(dayStr);
+                   qba.setBit(dayNum);
+                   index += 3; // advance to next day, or possibly "#"
+                 }
+               }
+               anEvent->recurrence()->setWeekly( rFreq, qba );
+               break; }
+
+        case Recurrence::rMonthlyPos: {
+               anEvent->recurrence()->setMonthly( rFreq );
+
+               QBitArray qba(7);
+               short tmpPos;
+               if( index == last ) {
+                 // e.g. MP1 #0
+                 tmpPos = anEvent->dtStart().date().day()/7 + 1;
+                 if( tmpPos == 5 )
+                   tmpPos = -1;
+                 qba.setBit(anEvent->dtStart().date().dayOfWeek() - 1);
+                 anEvent->recurrence()->addMonthlyPos( tmpPos, qba );
+               }
+               else {
+                 // e.g. MP1 1+ SU #0
+                 while (index < last) {
+                   tmpPos = tmpStr.mid(index,1).toShort();
+                   index += 1;
+                   if (tmpStr.mid(index,1) == "-")
+                     // convert tmpPos to negative
+                     tmpPos = 0 - tmpPos;
+                   index += 2; // advance to day(s)
+                   while (numFromDay(tmpStr.mid(index,3)) >= 0) {
+                     int dayNum = numFromDay(tmpStr.mid(index,3));
+                     qba.setBit(dayNum);
+                     index += 3; // advance to next day, or possibly pos or "#"
+                   }
+                   anEvent->recurrence()->addMonthlyPos( tmpPos, qba );
+                   qba.detach();
+                   qba.fill(FALSE); // clear out
+                 } // while != "#"
+               }
+             break;}
+
+        case Recurrence::rMonthlyDay:
+             anEvent->recurrence()->setMonthly( rFreq );
+             if( index == last ) {
+               // e.g. MD1 #0
+               short tmpDay = anEvent->dtStart().date().day();
+               anEvent->recurrence()->addMonthlyDate( tmpDay );
+             }
+             else {
+               // e.g. MD1 3 #0
+               while (index < last) {
+                 int index2 = tmpStr.find(' ', index);
+                 short tmpDay = tmpStr.mid(index, (index2-index)).toShort();
+                 index = index2-1;
+                 if (tmpStr.mid(index, 1) == "-")
+                   tmpDay = 0 - tmpDay;
+                 index += 2; // advance the index;
+                 anEvent->recurrence()->addMonthlyDate( tmpDay );
+               } // while != #
+             }
+             break;
+
+        case Recurrence::rYearlyMonth:
+             anEvent->recurrence()->setYearly( rFreq );
+
+             if( index == last ) {
+               // e.g. YM1 #0
+               short tmpMonth = anEvent->dtStart().date().month();
+               anEvent->recurrence()->addYearlyMonth( tmpMonth );
+             }
+             else {
+               // e.g. YM1 3 #0
+               while (index < last) {
+                 int index2 = tmpStr.find(' ', index);
+                 short tmpMonth = tmpStr.mid(index, (index2-index)).toShort();
+                 index = index2 + 1;
+                 anEvent->recurrence()->addYearlyMonth( tmpMonth );
+               } // while != #
+             }
+             break;
+
+        case Recurrence::rYearlyDay:
+             anEvent->recurrence()->setYearly( rFreq );
+
+             if( index == last ) {
+               // e.g. YD1 #0
+               short tmpDay = anEvent->dtStart().date().dayOfYear();
+               anEvent->recurrence()->addYearlyDay( tmpDay );
+             }
+             else {
+               // e.g. YD1 123 #0
+               while (index < last) {
+                 int index2 = tmpStr.find(' ', index);
+                 short tmpDay = tmpStr.mid(index, (index2-index)).toShort();
+                 index = index2+1;
+                 anEvent->recurrence()->addYearlyDay( tmpDay );
+               } // while != #
+             }
+             break;
+
+        default: break;
       }
-      else {
-        // e.g. YD1 123 #0
-        while (index < last) {
-          int index2 = tmpStr.find(' ', index);
-          tmpDay = tmpStr.mid(index, (index2-index)).toShort();
-          index = index2+1;
-          anEvent->recurrence()->addYearlyNum(tmpDay);
-        } // while != #
-      }
-      index = last; if (tmpStr.mid(index,1) == "#") index++;
-      if (tmpStr.find('T', index) != -1) {
-        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
-        anEvent->recurrence()->setYearly(Recurrence::rYearlyDay, rFreq, rEndDate);
-      } else {
+
+      // find the last field, which is either the duration or the end date
+      index = last;
+      if ( tmpStr.mid(index,1) == "#") {
+        // Nr of occurrences
+        index++;
         int rDuration = tmpStr.mid(index, tmpStr.length()-index).toInt();
-        if (rDuration == 0)
-          anEvent->recurrence()->setYearly(Recurrence::rYearlyDay, rFreq, -1);
-        else
-          anEvent->recurrence()->setYearly(Recurrence::rYearlyDay, rFreq, rDuration);
+        if ( rDuration > 0 )
+          anEvent->recurrence()->setDuration( rDuration );
+      } else if ( tmpStr.find('T', index) != -1 ) {
+        QDate rEndDate = (ISOToQDateTime(tmpStr.mid(index, tmpStr.length()-index))).date();
+        anEvent->recurrence()->setEndDateTime( rEndDate );
       }
+// anEvent->recurrence()->dump();
+
     } else {
       kdDebug(5800) << "we don't understand this type of recurrence!" << endl;
-    } // if
+    } // if known recurrence type
   } // repeats
 
 
@@ -1208,7 +1164,7 @@ Event* VCalFormat::VEventToEvent(VObject *vevent)
     QStringList exDates = QStringList::split(",",s);
     QStringList::ConstIterator it;
     for(it = exDates.begin(); it != exDates.end(); ++it ) {
-      anEvent->addExDate(ISOToQDate(*it));
+      anEvent->recurrence()->addExDate(ISOToQDate(*it));
     }
     deleteStr(s);
   }
@@ -1381,8 +1337,16 @@ QString VCalFormat::qDateToISO(const QDate &qd)
    indicating the date for which you want the offset */
 int vcaltime_utc_offset( QDateTime ictt, QString tzid )
 {
+  // libical-0.23 stuff:
+  //  struct icaltimetype tt = icaltime_from_timet( ictt.toTime_t(), false );
+  //  return icaltime_utc_offset( tt, tzid.latin1() );
+  int daylight;
   struct icaltimetype tt = icaltime_from_timet( ictt.toTime_t(), false );
-  return icaltime_utc_offset( tt, tzid.latin1() );
+  //source says this is DEPRECATED, but it doesn't say what to use instead
+  //how to handle failure from icaltimezone_get_builtin_timezone_from_tzid()?
+  return icaltimezone_get_utc_offset(
+    icaltimezone_get_builtin_timezone( tzid.latin1() ),
+    &tt, &daylight );
 }
 
 QString VCalFormat::qDateTimeToISO(const QDateTime &qdt, bool zulu)
