@@ -1,5 +1,5 @@
 /* key.cpp - wraps a gpgme key
-   Copyright (C) 2003 Klarlvdalens Datakonsult AB
+   Copyright (C) 2003 Klarälvdalens Datakonsult AB
 
    This file is part of GPGME++.
  
@@ -15,7 +15,7 @@
 
    You should have received a copy of the GNU General Public License
    along with GPGME; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307 USA.  */
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -379,11 +379,15 @@ namespace GpgME {
   bool Subkey::canCertify() const {
     return d->subkey && d->subkey->can_certify;
   }
-  
+
   bool Subkey::canAuthenticate() const {
     return d->subkey && d->subkey->can_authenticate;
   }
 
+  bool Subkey::isSecret() const {
+    return d->subkey && d->subkey->secret;
+  }
+
   unsigned int Subkey::length() const {
     return d->subkey ? d->subkey->length : 0 ;
   }
@@ -732,7 +736,8 @@ namespace GpgME {
   UserID::Signature::Status UserID::Signature::status() const {
     if ( !d->sig )
       return GeneralError;
-    switch ( d->sig->status ) {
+
+    switch ( gpgme_err_code(d->sig->status) ) {
     case GPG_ERR_NO_ERROR:      return NoError;
     case GPG_ERR_SIG_EXPIRED:   return SigExpired;
     case GPG_ERR_KEY_EXPIRED:   return KeyExpired;
